/*******************************************************************************
Description:		Wealth tax modelling: master code.
					This code runs through all of the individual do-files used in Advani, Hughson and Tarrant (2020) "Revenue and distributional modelling for a UK wealth tax"
					
First created: 20/08/2020
Authors: Arun Advani, Helen Hughson, Hannah Tarrant

Uses:				Raw Wealth and Assets Survey data (round 6), and Sunday Times Rich List for 2020

See accompanying documentation for information on how to structure the data files and folders.

Also requires: 		
					strl_2020_clean_byindividual.dta (cleaned 2020 STRL, one row per individual)
					strl_info_by_bucket (2020 STRL by bucket (5%))
*******************************************************************************/

******************
******SETUP*******
******************
clear all
set mo off, perm
set seed 623945731

*! remove own paths
*HT
local user = "" //Set to user name

if "`user'" == "" { //Define globals 
cd ""
global code "" //directory containing code files
global rawwas "" //directory containing RAW was data
global cleanwas "" //directory containing clean WAS data for round 6
global cleanstrl "" //directory containing clean STRL data *!list required datasets
global tempdata "" //directory for storing temporary datasets generated by the code
global output "" //directory for saving results/output
global spidata "" //directory containing raw SPI data
}


*******************************
***Set options globals*********
*******************************

*Note: Switching between different definitions of wealth for the revenue analysis (e.g. individual versus equal split) is done by updating the globals defined below

*Choose wealth variable for revenue analysis. Options: 
	*rf_totwlth_ch_pareto = Total chargeable wealth 
	*rf_lesspenhome_ch_pareto = Chargeable wealth excluding pensions and main residence
	*eq_totwlth_ch_pareto = Equal split chargeable wealth
	*rf_totwlth_contents_ch_pareto = Total wealth including 40% of the value of household contents
global wealth_var rf_totwlth_ch_pareto // (DEFAULT SPEC = rf_totwlth_ch_pareto)

*Base flag is set for labelling the excel sheets containing results
*This should be set to be in line with $wealth_var above, i.e.
	*If wealth_var is rf_totwlth_ch_pareto, set base_flag = "Total wealth"
	*If wealth_var is rf_lesspenhome_ch_pareto, set base_flag = "Less Pen Home"
	*If wealth_var is eq_totwlth_ch_pareto, set base_flag = "Equal split"
	*If wealth_var is rf_totwlth_contents_ch_pareto, set base_flag = "Including contents"
global base_flag = "Total wealth" // (DEFAULT SPEC = "Total wealth")

*Using info on age, residence and nationality in the STRL? (requires linking to Companies House)
global using_companies_house = 1 //default is 1, set to 0 otherwise

*Choose whether to drop residents or foreign nationals
global drop_nonres  = 1 //1 if want to drop non-residents, 0 if keep (DEFAULT SPEC = 1)
global drop_foreign = 0 //1 if want to drop foreign nationals, 0 if keep (DEFAULT SPEC = 0)

*Set rates (make sure all analysis uses same tax rates) - can work out which rates to use for different revenue targets using the do-file "automating_revtarget.do"
*Flat rate, annual, targetting £10bn before admin costs: 
global frate_an_250 = 0.00116 //threshold £250k
global frate_an_500 = 0.00173 //threshold £500k
global frate_an_1m = 0.00313 //threshold £1m
global frate_an_2m = 0.00572 //threshold £2m
global frate_an_5m = 0.00904 //threshold £5m
global frate_an_10m = 0.0112 //threshold £10m
*Flat rate, one-off, targetting £250bn before admin costs: 
global frate_one_250 = 0.03201 //threshold £250k
global frate_one_500 = 0.04755 //threshold £500k
global frate_one_1m = 0.08496 //threshold £1m
global frate_one_2m = 0.1526 //threshold £2m
global frate_one_5m = 0.2353 //threshold £5m
global frate_one_10m = 0.2866 //threshold £10m
*Progressive, annual, starting at £1m, targetting £10bn before admin costs:
global prate_an_1m  = 0.001 //rate above £1m
global prate_an_2m = 0.0025 //rate above £2m
global prate_an_5m = 0.005 //rate above £5m
global prate_an_10m = 0.0065 //rate above £10m
*Progressive, one-off, starting at £1m, targetting £250bn before admin costs: 
global prate_one_500 = 0 //rate above £500k
global prate_one_1m = 0.04 //rate above £1m
global prate_one_2m = 0.08 //rate above £2m
global prate_one_5m = 0.12 //rate above £5m
global prate_one_10m = 0.15 //rate above £10m
*Progressive, one-off, starting at £500k, targetting £250bn before admin costs: 
global prate2_one_500 = 0.03 //rate above £500k
global prate2_one_1m = 0.05 //rate above £1m
global prate2_one_2m = 0.06 //rate above £2m
global prate2_one_5m = 0.07 //rate above £5m
global prate2_one_10m = 0.08 //rate above £10m


****************
* Prep of STRL *
****************

*Code for creating bucket-level averages in the STRL (for subsequent imputation of missing values)
do "$code\STRL-1-bucket_rank_level_averages.do"

*Code for imputing missing info in the STRL 
do "$code\STRL-2-impute_missing_info_byindividual.do"

*************************************
* Prep of data for revenue analysis *
*************************************
set seed 623945731

*Step 1: clean WAS data
do "$code\1.round_6_alt.do" 

*Step 2: Implement Pareto adjustment (individual level)
do "$code\2.pareto_adjustment.do"

*Step 3: Define sample (remove non-residents etc.)
do "$code\3.define_sample.do"

//data now ready for analysis (sample_for_analysis.dta)

*To run revenue analysis on WAS sample only (without STRL and without Pareto):
/*
use "$cleanwas\r6_alt.dta", clear 
g double rf_totwlth_ch_pareto = rf_totwlth_ch
save "$tempdata\sample_for_analysis.dta", replace
*This defines an alternative sample_for_analysis from the one created in step 3.
*/

*Step 4: Produce population counts
do "$code\4.population_counts.do"

**********************
*WEALTH TAX MODELLING*
**********************

*Step 5: Model flat annual wealth tax
do "$code\5.model_flat_tax_annual.do"

*Step 6: Model flat annual wealth tax with banding
do "$code\6.model_flat_tax_annual_banded.do"

*Step 7: Model flat one-off wealth tax
do "$code\7.model_flat_tax_oneoff.do"

*Step 8: Model flat one-off wealth tax with banding
do "$code\8.model_flat_tax_oneoff_banded.do"

*Step 9: Model progressive annual wealth tax
do "$code\9.model_progressive_tax_annual.do"

*Step 10: Model progressive one-off wealth tax
do "$code\10.model_progressive_tax_oneoff.do"



***************************
*ALTERNATIVE TAX MODELLING*
***************************

*Step 11: Model IHT reforms
do "$code\11.model_iht_reforms.do"

*Step 12: Council tax reform
do "$code\12.council_tax_analysis.do"

*Step 13: Dividend reform
do "$code\13.dividend_reform.do"

**********
*ANALYSIS*
**********

*Step 14: Liquidity analysis
do "$code\14.liquidity_analysis.do"

*Step 15: Who pays? analysis
do "$code\15.who_pays.do"

*Step 16: Valuation cost analysis
do "$code\16.valuation_cost_analysis.do"

*Step 17: IHT reform distributional analysis
do "$code\17.iht_distributional_analysis.do"



************
*Additional*
************

*Code for automating the calculation of tax rates generating £Xbn in revenue (fixed point problem with behavioural responses)
do "$code\automating_revtarget.do" //need to set preferences within script

*Revenue effect of exempting different asset classes from wealth tax base
do "$code\different_bases.do" 

*Produce data to graph functional relationship between wealth and tax paid
do "$code\tax_by_wealth_graph.do"




