/**************************************************************************
Description:		Cleans round 6 of the Wealth and Assets Survey 
					Creates an individual-level dataset (r6_alt.dta) and household-level dataset (r6_hh.dta)

Uses:				WAS data (round 6 and wave 5) raw files, saved in $rawwas					
**************************************************************************/

********************
*******SETUP*******
********************
clear all
set maxvar 10000

************
********DATA********
********************
*N.b. we are using the 13th edition of the WAS (released September 2020)

*Extract annuity factors for wave 5 (these are missing for round 6 individuals who were interviewed in wave 5)
*Person file for wave 5
use "$rawwas\was_wave_5_person_eul_dec_19_final", clear
rename *, lower
keep casew5 personw5 ageasafw5
tempfile annuityw5
save `annuityw5', replace


*Person file for round 6
use "$rawwas\was_round_6_person_eul_mar_20.dta", clear

*Merge in household file for round 6
merge m:1 CASER6 using "$rawwas\was_round_6_hhold_eul_mar_20.dta", nolabel
drop _merge

rename *, lower


*Other cleaning bits
rename dvage8r6 agegroup
rename dvage17r6 agegroup_detail
rename gorr6 gor
rename sexr6 sex

********************
****IDENTIFIERS****
********************

g xs_pers = r6xsperswgt 
g xs_hh = r6xshhwgt //for checks

*Wave identifiers (some variables only recorded in w6 not w5)
g wave = 5 if yearr6 == 2016 & inrange(monthr6,4,6)
replace wave = 6 if wave != 5

*******************
* Annuity factors *
*******************
*Merge annuity factors for wave 5 observations
merge m:1 casew5 personw5 using `annuityw5', keep(1 3)

*For individuals not matched, back out annuity factor using formula from the derived variables documentation provided with the WAS data
replace ageasafw5 = 0 if dvpinpvalr6 == pincinpr6 & wave == 5 & missing(ageasafw5) // annuity factor can be 0 if over 90
replace ageasafw5 = dvpinpvalr6/pincinpr6 if dvpinpvalr6!= pincinpr6 & wave == 5 & missing(ageasafw5)
sum ageasafw5 if wave == 5
sum ageasafw5 if wave == 5 & _merge == 1 & ageasafw5 > 0 
drop _merge

/*Replace wave 5 annuity factors as missing for wave 6 individuals (these are the annuity factors for last time they are interviewed), 
we only want to keep annuity factors for wave 5 individuals that become part of round 6. */
replace ageasafw5 = . if wave == 6
********************

*Number of adults in BU // Using traditional BU definition (i.e. only dependent kids)
*Combine HRP flags for w5 and w6 to one HRP flag variable
g ishrp = ishrpw6
replace ishrp = ishrpw5 if ishrp == .
_crcslbl ishrp ishrpw6
lab values ishrp IsHRPW6
drop ishrpw5 ishrpw6
			
* Combine HRP partner flags for w5 and w6 to one HRP partner flag variable			
g ishrppart = ishrppartw6
replace ishrppart = ishrppartw5 if ishrppart == .
_crcslbl ishrppart ishrppartw6
lab values ishrppart IsHRPPartW6
drop ishrppartw5 ishrppartw6

*Can't be both HRP & partner
replace ishrppart = 2 if ishrp == 1

*Combine 'is dependent child' flag' for w5 and w6 to one flag variable (1=yes)
g isdep = isdepw6 
replace isdep = isdepw5 if isdep == .
_crcslbl isdep isdepw6
lab values isdep IsDepW6
drop isdepw5 isdepw6

* Main adults (adults in main benefit unit). N.B. this assumes adults not in main BU are all single adults (1=yes)
gen mainadultsflag =0
replace mainadultsflag =1 if ishrp ==1 | ishrppart ==1

sort caser6 mainadultsflag isdep
bysort caser6 mainadultsflag isdep : gen ranking =_n

*Assign mainadultsnumber = 1 if main adult, or 2, 3, 4, etc if other adult in HH
gen mainadultsnumber =0 if mainadultsflag ==1
	replace mainadultsnumber = ranking if mainadultsflag ==0 & isdep !=1 
	replace mainadultsnumber = mainadultsnumber + 1 if isdep !=1
drop ranking

* Main BU, with only dependent kids included. N.B. this assumes adults not in main BU are all single adults 
*Flag individuals in main benefit unit (=1 if ind is part of main BU, =0 otherwise)
gen mainbuflag_depkids =0
	replace mainbuflag_depkids =1 if mainadultsflag ==1
	replace mainbuflag_depkids =1 if isdep ==1

*Number benefit units within household (=1 if in main benefit unit, 2,3,4 etc. otherwise (this is where single adults assumption comes in, assumes all other adults are individual benefit units))
sort caser6 mainbuflag_depkids
bysort caser6 mainbuflag_depkids: gen ranking =_n
gen bunumber_depkids =0 if mainbuflag_depkids ==1
replace bunumber_depkids = ranking if mainbuflag_depkids ==0
replace bunumber_depkids = bunumber_depkids + 1
drop ranking

*Number of adults in each benefit unit (including non-main benefit units)
bysort caser6: egen numadults = sum(mainadultsflag)
replace numadults =1 if bunumber_depkids !=1 & mainadultsnumber !=.

********************
****SUMMARY VARS****
********************

*Wealth variables are first created at the individual (prefix ind_) and household level (prefix hh_).
*The wealth of children is then assigned to parents, producing the wealth variables used in our revenue analysis (prefix rf_)
*We also define equal split wealth (prefix eq_) where household wealth other than pensions is divided equally among couples

*Recode to avoid carrying through missings
recode totpenr6 totpenr6_aggr allendw hfinlr6_sum hfinw_excendwr6_sum hfinwntr6_sum hpropwr6 dvhvaluer6 dvhsevalr6_sum dvbltvalr6_sum dvbldvalr6_sum dvlukvalr6_sum dvlosvalr6_sum dvoprvalr6_sum totmortr6 (. = 0)

************************************************************************************************************
* Pensions *
************

*Total pension wealth
g double ind_pen = totpenr6 //person level 
lab var ind_pen "Individual pension wealth"
g double hh_pen = totpenr6_aggr // household level
lab var hh_pen "Household pension wealth"

*Chargeable pension wealth ( = pension wealth if > £3000)
g double ind_pen_ch = ind_pen if ind_pen > 3000
recode ind_pen_ch (.=0)

*Whether has occupational DB pension
g ind_hasdb = dvhasdbr6
*Whether has occupational DC pension
g ind_hasdc = dvhasdcr6
*Whether has personal pension
g ind_haspp = dvhasppr6

*******************************
**Value of pensions at death***
*******************************
*These variables are used to approximate the pension wealth that could be passed on at death, which we use to estimate the effect of including pensions in the IHT base

*Pension variables
//DVValDBTW6 = total value of defined benefit occupational scheme. Not yet in payment. Assume worth 50% when inherited.
//DVValDCosW6 = total value of current defined contribution pension wealth. Not yet in payment. Assume passed on in full.
//DVPAVCUVW6 = total value of AVCs scheme. Not yet in payment. Assume passed on in full.
//DVPPValW6 = total value of current personal pension scheme. Not yet in payment, under 75s only. Assume passed on in full.
//DVDBrWealthValW6 = total value of retained DB pension wealth (lump sum and payments not yet in payment). Assume worth 50% when inherited.
//DVPFCurValW6 = total value of retained rights in DC scheme. Assume passed on in full.
//DVPFDDvW6 = total value of retained rights for drawdown. Assume passed on in full. 
//DVPInPValW6 = value of pensions in payment  (discounted income stream). Assume occupational pensions in payment are worth 50% when inherited.
//DVSPenW6 = value of pensions expected from former spouse/partner. Assume these cease. Under some circumstances they are then paid to dependent children, but most cases will just cease

recode dvvaldbtr6 dvvaldcosr6 dvpavcuvr6 dvppvalr6 dvpfcurvalr6 dvpfddvr6 dvpinpvalr6 dvspenr6 dvoigoeannualr6_i dvdbrwealthvalr6 dvvalpblumr6(.=0)

g ind_retained_drawdown = dvpfddvr6
lab var ind_retained_drawdown "Value of retained rights for drawdown"

g ind_retained_dc = dvpfcurvalr6
lab var ind_retained_dc "Value of retained rights in DC"

g ind_current_dc = dvvaldcosr6
lab var ind_current_dc "Value of current DC"

g ind_current_db = dvvaldbtr6
lab var ind_current_db "Value of current DB"

g ind_current_avc = dvpavcuvr6 
lab var ind_current_avc "Value of current AVCs to DB scheme"

g ind_personal = dvppvalr6
lab var ind_personal "Value of personal pension pot, under 75 NIP"

g ind_retained_db = dvdbrwealthvalr6
lab var ind_retained_db "Value of retained rights in DC"

g ind_pen_in_payment = dvpinpvalr6
lab var ind_pen_in_payment "Value of pensions in payment"

g ind_pen_spouse = dvspenr6
lab var ind_pen_spouse "Value of pension expected from former spouse"

*Separate DB lump sums not yet claimed to treat this as liquid wealth for those > SPA
g ind_retained_db_lumpsum = dvvalpblumr6 if agegroup >= 7
lab var ind_retained_db_lumpsum "Retained DB lump sum if over age 65"

*Lump sum benefit from current DB pensions
g pblumv1 = pblumv1w6_i
replace pblumv1 = pblumv1w5_i if missing(pblumv1w6_i)
g pblumv2 = pblumv2w6_i
replace pblumv2 = pblumv2w5_i if missing(pblumv2w6_i)
recode pblumv1 pblumv2 (-7 = .)

g lumpsum1 = pblumv1 if frstschr6 == 1 & ((agegroup_detail == 12 & rsr6 <= 55 & rsr6!=0) | (agegroup_detail == 13 & rsr6 > 55 & rsr6 <= 60) | (agegroup_detail == 14 & rsr6 > 60 & rsr6 <= 64) | (agegroup_detail >= 14))
g lumpsum2 = pblumv2 if scndschr6 == 1 & ((agegroup_detail == 12 & rsr6 <= 55 & rsr6!=0) | (agegroup_detail == 13 & rsr6 > 55 & rsr6 <= 60) | (agegroup_detail == 14 & rsr6 > 60 & rsr6 <= 64) | (agegroup_detail >= 14))
egen ind_current_db_lumpsum = rowtotal(lumpsum1 lumpsum2)
lab var ind_current_db_lumpsum "Current DB lump sum if over 65 or entitlement age"

*Pensions in payment on death
egen double ageasaf = rowtotal(ageasafw5 ageasafw6)
g inc_ondeath = 0.5*dvoigoeannualr6_i
g valinc_ondeath = ageasaf*inc_ondeath
replace valinc_ondeath = inc_ondeath if ageasaf == 0 & valinc_ondeath == 0 & inc_ondeath > 0

recode valinc_ondeath (.=0)

*Value of pension wealth on death
g ind_pen_ondeath = ind_retained_drawdown + ind_retained_dc + 0.5*ind_retained_db + ind_current_dc + 0.5*ind_current_db + ind_current_avc + ind_personal + valinc_ondeath
lab var ind_pen_ondeath "Value of pension wealth on death"


*Split out value of DB pensions (including pensions in payments)
g ind_db_pensions = ind_current_db + ind_retained_db + ind_pen_in_payment
g ind_non_db = ind_pen - ind_db_pensions
*Chargeable 
g ind_db_pensions_ch = ind_db_pensions if ind_db_pensions > 3000
g ind_non_db_ch = ind_non_db if ind_non_db > 3000
recode ind_db_pensions_ch ind_non_db_ch (.=0)
***************************************************************************************************************


***************************************************************************************************************
* Financial wealth *
********************

*Financial = total financial wealth excluding endowments, plus endowments
*Financial wealth and liabilities are individualised, but endowments is only at HH level so this needs to be allocated

*Assume endowments sit with main BU only
replace allendw = 0 if mainadultsflag!=1 
g double ind_allen = allendw / numadults //endowments divided equally among main BU adults
lab var ind_allen "Individual endowments"

*Redefine liabilities to exclude student loans and informal loans (from family/friends etc.)
*Financial liabilities = formal loans excluding loans from SLC 
recode t_lnsr6 totcscr6_sum totmor6_sum tothpr6_sum totarr_excmortr6_sum dvcaodvalr6_sum t_flnsr6 (.=0)
recode t_lnsr6_aggr totcscr6_aggr totmor6_aggr tothpr6_aggr totarr_excmortr6_aggr dvcaodvalr6_aggr t_flnsr6_aggr (.=0)
g double ind_hfinl = t_lnsr6 + totcscr6_sum + totmor6_sum + tothpr6_sum + totarr_excmortr6_sum + dvcaodvalr6_sum 
g double hh_hfinl = t_lnsr6_aggr + totcscr6_aggr + totmor6_aggr + tothpr6_aggr + totarr_excmortr6_aggr + dvcaodvalr6_aggr 

*Gross financial wealth = gross financial wealth in the WAS (inc. endowments) - value of money loaned to others (informal)
g double ind_fin_grs = hfinw_excendwr6_sum + ind_allen - dvfinflvr6
lab var ind_fin_grs "Individual gross financial wealth"
*Net financial wealth 
g double ind_fin_net = ind_fin_grs - ind_hfinl
lab var ind_fin_net "Individual net financial wealth"
g double hh_fin_net = hfinw_excendwr6_aggr + allendwr6 - dvfinflvr6_aggr - hh_hfinl
lab var hh_fin_net "Household net financial wealth"

*Equal split financial wealth owned by main BU adults
gegen bu_fin_net = sum(ind_fin_net), by(caser6 mainadultsflag)
g double eq_fin_net = ind_fin_net if !mainadultsflag
replace eq_fin_net = bu_fin_net/numadults if mainadultsflag
lab var eq_fin_net "Equal split net financial wealth"

*Separate out shares (should not be added to total income below as included in ind_fin_net already)
*includes, UK shares, overseas shares, employee shares and employee options, all recorded at person level 
egen double ind_shares = rowtotal(dvfshukvr6 dvfshosvr6 dvfesharesr6_sum)
egen double hh_shares = rowtotal(dvfshukvr6_aggr dvfshosvr6_aggr dvfesharesr6_aggr)
recode ind_shares hh_shares (.=0)
lab var ind_shares "Individual shares"
lab var hh_shares "Household shares"

g ind_ukshares = dvfshukvr6
lab var ind_ukshares "UK listed and unlisted shares"
g ind_foreign_shares = dvfshosvr6
lab var ind_foreign_shares "Overseas shares"
g ind_employee_shares_options = dvfesharesr6_sum
lab var ind_employee_shares_options "Employee shares and options"


*Types of share
foreach i in 1 2 3 {
g fshare`i' = fshare`i'w6_i
replace fshare`i' = fshare1w5_i if missing(fshare1w6_i)
recode fshare`i' (-7=.)
}

*Indicator for whether individual owns listed UK shares
g own_listed_uk_shares = 1 if (fshare1 == 1 | fshare2 == 1 | fshare3 == 1)
*Indicator for whether individual owns unlisted UK shares
g own_unlisted_uk_shares = 1 if (fshare1 == 2 | fshare2 == 2 | fshare3 == 2)

*Classify uk shares as unlisted if the individual owns unlisted shares only
g ind_unlisted = ind_ukshares if own_unlisted_uk_shares == 1 & own_listed_uk_shares != 1
g ind_listed = ind_ukshares if own_listed_uk_shares == 1 | (own_unlisted_uk_shares == . & own_listed_uk_shares == . & ind_ukshares > 0)
lab var ind_unlisted "Individual unlisted UK shares"
lab var ind_listed "Individual listed UK shares"
*********************************************************************************************************


*********************************************************************************************************
* Property *
************

*Net property wealth:
*UK housing wealth variables (household level): 
	*dvhvaluer6 (main home) 
	*dvhsevalr6_sum (other houses) 
	*dvbltvalr6_sum (buy to let houses) 
	*dvbldvalr6_sum (buildings)
	*dvlukvalr6_sum (UK land)
	*dvlosvalr6_sum (overseas land) 
	*dvoprvalr6_sum (other property) 
	*hmortgr6 (mortgages)
g double hh_prop_net = (dvhvaluer6 + dvhsevalr6_sum + dvbltvalr6_sum) + dvbldvalr6_sum + dvlukvalr6_sum + dvlosvalr6_sum + dvoprvalr6_sum - hmortgr6
lab var hh_prop_net "Household net property wealth"

*Chargeable main residence (exclude if < 3000)
g double dvhvaluer6_ch = dvhvaluer6 if dvhvaluer6 >= 3000
recode dvhvaluer6_ch (.=0)

*Individualise main residence (divide equally among main benefit unit adults)
foreach var in dvhvaluer6 dvhvaluer6_ch {
g td_`var' = `var'
replace td_`var' = 0 if mainadultsflag!=1
g double ind_`var' = td_`var'/numadults
drop td_`var'
}
*Individualise mortgage on main residence (divide equally among main benefit unit adults)
g mortmain = totmortr6
replace mortmain = 0 if mainadultsflag!=1
g double ind_mortmain = mortmain/numadults
drop mortmain 

*Individual property wealth (othmortr6 is individual-level mortgages on all property other than main residence)
recode dvhsevalr6 dvbltvalr6 dvbldvalr6 dvlukvalr6 dvlosvalr6 dvoprvalr6 othmortr6 (.=0)
g double ind_prop_net = ind_dvhvaluer6 + dvhsevalr6 + dvbltvalr6 + dvbldvalr6 + dvlukvalr6 + dvlosvalr6 + dvoprvalr6 - othmortr6 - ind_mortmain
lab var ind_prop_net "Individual net property wealth"

*Counts of properties owned by individual
recode unumhsw5_i unumhsw6_i ubuyletw5_i ubuyletw6_i unumbdw5_i unumbdw6_i unumlaw5_i unumlaw6_i unumovw5_i unumovw6_i unumrew5_i unumrew6_i (-9/-1 = 0)
egen int ind_dvhsevalr6_count = rowtotal(unumhsw5_i unumhsw6_i) //num second homes
egen int ind_dvbltvalr6_count = rowtotal(ubuyletw5_i ubuyletw6_i) //num buy to let
egen int ind_dvbldvalr6_count = rowtotal(unumbdw5_i unumbdw6_i) //num other buildings
egen int ind_dvlukvalr6_count = rowtotal(unumlaw5_i unumlaw6_i) //num parcels of land
egen int ind_dvlosvalr6_count = rowtotal(unumovw5_i unumovw6_i) //num of overseas properties/parcels of land
egen int ind_dvoprvalr6_count = rowtotal(unumrew5_i unumrew6_i) //number of other properties

*Individual property components 
g double ind_dvhsevalr6_sum = dvhsevalr6
g double ind_dvbltvalr6_sum = dvbltvalr6
g double ind_dvbldvalr6_sum = dvbldvalr6
g double ind_dvlukvalr6_sum = dvlukvalr6
g double ind_dvlosvalr6_sum = dvlosvalr6
g double ind_dvoprvalr6_sum = dvoprvalr6
g double ind_mortgage = othmortr6 + ind_mortmain //individual mortgages on all property

*Chargeable property wealth (value of each property type if average > 3000)
g double ind_dvhsevalr6_sum_ch = ind_dvhsevalr6_sum if ind_dvhsevalr6_sum/ind_dvhsevalr6_count >= 3000 & ind_dvhsevalr6_count > 0
g double ind_dvbltvalr6_sum_ch = ind_dvbltvalr6_sum if ind_dvbltvalr6_sum/ind_dvbltvalr6_count >= 3000 & ind_dvbltvalr6_count > 0
g double ind_dvbldvalr6_sum_ch = ind_dvbldvalr6_sum if ind_dvbldvalr6_sum/ind_dvbldvalr6_count >= 3000 & ind_dvbldvalr6_count > 0
g double ind_dvlukvalr6_sum_ch = ind_dvlukvalr6_sum if ind_dvlukvalr6_sum/ind_dvlukvalr6_count >= 3000 & ind_dvlukvalr6_count > 0
g double ind_dvlosvalr6_sum_ch = ind_dvlosvalr6_sum if ind_dvlosvalr6_sum/ind_dvlosvalr6_count >= 3000 & ind_dvlosvalr6_count > 0
g double ind_dvoprvalr6_sum_ch = ind_dvoprvalr6_sum if ind_dvoprvalr6_sum/ind_dvoprvalr6_count >= 3000 & ind_dvoprvalr6_count > 0
drop *_count
recode ind_dvhsevalr6_sum_ch ind_dvbltvalr6_sum_ch ind_dvbldvalr6_sum_ch ind_dvlukvalr6_sum_ch ind_dvlosvalr6_sum_ch ind_dvoprvalr6_sum_ch (.=0)

*Individual property wealth, chargeable
g ind_prop_net_ch = ind_dvhvaluer6_ch + ind_dvhsevalr6_sum_ch + ind_dvbltvalr6_sum_ch + ind_dvbldvalr6_sum_ch + ind_dvlukvalr6_sum_ch + ind_dvlosvalr6_sum_ch + ind_dvoprvalr6_sum_ch - ind_mortgage
lab var ind_prop_net_ch "Individual net property wealth, chargeable"

*Equal split property wealth owned by main BU
foreach var in dvhvaluer6 dvhsevalr6_sum dvbltvalr6_sum dvbldvalr6_sum dvlukvalr6_sum dvlosvalr6_sum dvoprvalr6_sum mortgage dvhvaluer6_ch dvhsevalr6_sum_ch dvbltvalr6_sum_ch dvbldvalr6_sum_ch dvlukvalr6_sum_ch dvlosvalr6_sum_ch dvoprvalr6_sum_ch { 
gegen bu_`var' = sum(ind_`var'), by(caser6 mainadultsflag)
g double eq_`var' = ind_`var' if !mainadultsflag
replace eq_`var' = bu_`var'/numadults if mainadultsflag
drop bu_`var'
}
g double eq_prop_net = eq_dvhvaluer6 + eq_dvhsevalr6_sum + eq_dvbltvalr6_sum + eq_dvbldvalr6_sum + eq_dvlukvalr6_sum + eq_dvlosvalr6_sum + eq_dvoprvalr6_sum - eq_mortgage
g double eq_prop_net_ch = eq_dvhvaluer6_ch + eq_dvhsevalr6_sum_ch + eq_dvbltvalr6_sum_ch + eq_dvbldvalr6_sum_ch + eq_dvlukvalr6_sum_ch + eq_dvlosvalr6_sum_ch + eq_dvoprvalr6_sum_ch - eq_mortgage
lab var eq_prop_net_ch "Equal split chargeable property wealth"

*Main homes variables 
g double hh_mainhome_grs = dvhvaluer6
g hh_mainhome_net = dvhvaluer6 - totmortr6
g double ind_mainhome_grs = ind_dvhvaluer6
g double ind_mainhome_net = ind_dvhvaluer6 - ind_mortmain
g double ind_mainhome_net_ch = ind_dvhvaluer6_ch - ind_mortmain
lab var hh_mainhome_grs "Household main residence, gross"
lab var hh_mainhome_net "Household main residence, net"
lab var ind_mainhome_grs "Individual main residence, gross"
lab var ind_mainhome_net "Individual main residence, net"

*Generate gross UK housing wealth variable (for council tax calculations), i.e. exclude overseas property
g hh_ukhousing_grs = dvhvaluer6 + dvhsevalr6_sum + dvbltvalr6_sum 
lab var hh_ukhousing_grs "Gross value of UK housing"

*Part way
*recode summary variables to 0 if missing
recode ind_pen ind_fin_net ind_prop_net ind_mainhome_net ind_prop_net_ch (. = 0)
recode hh_pen hh_fin_net hh_prop_net (.=0)
recode eq_fin_net eq_prop_net (.=0)
***********************************************************************************************************

***********************************************************************************************************
* Business wealth *
*******************
*Actual values (assign w5 and w6 to one variable)
foreach i in bval1 bval2 bval3 bworth{
g double `i' = `i'w6
replace `i' = `i'w5 if missing(`i')
replace `i' = . if `i' <= -6
}

*Banded values (assign w5 and w6 to one variable)
foreach i in bvalb1 bvalb2 bvalb3 bworthb{
g double `i' = `i'w6
replace `i' = `i'w5 if missing(`i')
replace `i' = . if `i' <= -6
}

*Replace actual with midpoint of banded if actual missing 
foreach i in 1 2 3{
replace bval`i' = 0 if bvalb`i' == 1 & missing(bval`i')
replace bval`i' = 5000 if bvalb`i' == 2 & missing(bval`i')
replace bval`i' = 25000 if bvalb`i' == 3 & missing(bval`i')
replace bval`i' = 75000 if bvalb`i' == 4 & missing(bval`i')
replace bval`i' = 175000 if bvalb`i' == 5 & missing(bval`i')
replace bval`i' = 375000 if bvalb`i' == 6 & missing(bval`i')
replace bval`i' = 750000 if bvalb`i' == 7 & missing(bval`i')
replace bval`i' = 1500000 if bvalb`i' == 8 & missing(bval`i')
replace bval`i' = 3500000 if bvalb`i' == 9 & missing(bval`i')
replace bval`i' = 5000000 if bvalb`i' == 10 & missing(bval`i') //lower bound if report > £5m
}

replace bworth = 0 if bworthb == 1 & missing(bworth) 
replace bworth = 5000 if bworthb == 2 & missing(bworth) 
replace bworth = 17500 if bworthb == 3 & missing(bworth) 
replace bworth = 37500 if bworthb == 4 & missing(bworth) 
replace bworth = 75000 if bworthb == 5 & missing(bworth) 
replace bworth = 150000 if bworthb == 6 & missing(bworth) 
replace bworth = 250000 if bworthb == 7 & missing(bworth) 
replace bworth = 350000 if bworthb == 8 & missing(bworth) 
replace bworth = 450000 if bworthb == 9 & missing(bworth) 
replace bworth = 750000 if bworthb == 10 & missing(bworth) 

recode bval1 bval2 bval3 bworth (.=0)
egen double ind_businessassets = rowtotal(bval1 bval2 bval3 bworth)
total ind_businessassets [pw=xs_pers] //around £300bn higher than what RF told us (various reasons)
lab var ind_businessassets "Individual business assets"

*For allocating business assets
foreach var in bval1 bval2 bval3 bworth {
	g ind_`var' = `var'
}

*Chargeable business assets (equal to value of business if business > £3000)
foreach var in bval1 bval2 bval3 bworth {
	g double ind_`var'_ch = ind_`var' if ind_`var' > 3000
	recode ind_`var'_ch (.=0)
}
egen double ind_businessassets_ch = rowtotal(ind_bval1_ch ind_bval2_ch ind_bval3_ch ind_bworth_ch)
lab var ind_businessassets_ch "Individual business assets, chargeable"

*Size of businesses: how many employees?
*flag if has a business which employs none | one or two people
g bemp_1 = ((bsize1w5 == 1 | bsize1w6 == 1) | (bempn1w5 == 1 | bempn1w5 == 2 | bempn1w6 == 1 | bempn1w6 == 2)) //first business
g bemp_2 = ((bsize2w5 == 1 | bsize2w6 == 1) | (bempn2w5 == 1 | bempn2w5 == 2 | bempn2w6 == 1 | bempn2w6 == 2)) //second business 
g bemp_3 = ((bsize3w5 == 1 | bsize3w6 == 1) | (bempn3w5 == 1 | bempn3w5 == 2 | bempn3w6 == 1 | bempn3w6 == 2)) //third business

*Split business assets into those associated with large & small businesses
g ind_smallbus = bval1 if bemp_1 == 1
replace ind_smallbus = ind_smallbus + bval2 if bemp_2 == 1
replace ind_smallbus = ind_smallbus + bval3 if bemp_3 == 1
*no employment indicator for bworth
g ind_largebus = ind_businessassets - ind_smallbus
replace ind_largebus = ind_businessassets if ind_smallbus == .

*Chargeable version of ind_smallbus and ind_largebus
g double ind_smallbus_ch = ind_bval1_ch if bemp_1 == 1
replace ind_smallbus_ch = ind_smallbus_ch + ind_bval2_ch if bemp_2 == 1
replace ind_smallbus_ch = ind_smallbus_ch + ind_bval3_ch if bemp_3 == 1
g double ind_largebus_ch = ind_businessassets_ch - ind_smallbus_ch
replace ind_largebus_ch = ind_businessassets_ch if ind_smallbus_ch == .

*Household level business assets
bys caser6: egen hh_businessassets = total(ind_businessassets)
foreach var in bval1 bval2 bval3 bworth {
	bys caser6: egen hh_`var' = total(ind_`var')
}
lab var hh_businessassets "Household business assets"

*Equal split business assets (for revenue effect)
foreach var in businessassets bval1 bval2 bval3 bworth businessassets_ch smallbus largebus {
	gegen bu_`var' = sum(ind_`var'), by(caser6 mainadultsflag)
	g double eq_`var' = ind_`var' if !mainadultsflag
	replace eq_`var' = bu_`var'/numadults if mainadultsflag
}
lab var eq_businessassets_ch "Equal split chargeable business assets"
*******************************************************************************************************

*******************************************************************************************************
* Physical *
************
recode vcarnw5_i vcarnw6_i vovalw6_i vovalw5_i votyp1w5_i votyp1w6_i votyp2w5_i votyp2w6_i votyp3w5_i votyp3w6_i votyp4w5_i votyp4w6_i votyp5w5_i votyp5w6_i (-9/-1 = 0)

*Household contents variables
g double ind_contentssp = housgdstr6 //Contents in second homes, person level already
g double ind_contentsbtl = buylgdstr6 //Contents in buy-to-let properties, person level already
g double ind_contentsos = housgdsostr6 //Contents in overseas property, person level already
g double hh_contentsmp = gcontvlsr6 //Contents of main property, HH level

*Number of cars, vans, and motorbikes owned
egen double hh_carvehicles_count = rowtotal(vcarnw5_i vcarnw6_i)

*Types of other vehicle owned
lab define votyp 1 "Caravan/trailer" 2 "Boat" 3 "Plane" 4 "Bicycle" 5 "Other" 6 "None of these"
forval i = 1/5  {
egen double votyp`i' = rowtotal(votyp`i'w5_i votyp`i'w6_i)
lab values votyp`i' votyp
}

*How many other vehicles are owned by the household
egen double hh_othvehicles_count = anycount(votyp1 votyp2 votyp3 votyp4 votyp5), values(1/5)

*Collectibles and valuables, vehicles, and personalised number plates
g double hh_collectnvaluables = dvgcollvr6 //Collectibles and valuables, HH level
g double hh_carvehicles = dvtotcarvanmotbvalr6 //Cars, vans, motorbikes, HH level
egen double hh_othvehicles = rowtotal(vovalw6_i vovalw5_i) //Caravans, trailers, boats, planes, bicycles
g double hh_pnumberplate = dvtotpernpvalr6 //Personal number plates, HH level

*Calculate value of collectables over £3k (chargeable, at hh level)
g double hh_collectnvaluables_ch = hh_collectnvaluables if hh_collectnvaluables >= 3000

*Calculate value of personalised number plates over £3k (chargeable, at hh level)
g double hh_pnumberplate_ch = hh_pnumberplate if hh_pnumberplate >= 3000

*Calculate value of cars, vans, motorbikes where average > £3k (chargeable)
g double hh_carvehicles_ch = hh_carvehicles if hh_carvehicles/hh_carvehicles_count >= 3000 & hh_carvehicles_count > 0
drop hh_carvehicles_count

*Calculate value of other vehicles where average > £3k (chargeable)
g double hh_othvehicles_ch = hh_othvehicles if hh_othvehicles/hh_othvehicles_count >= 3000 & hh_othvehicles_count > 0
drop hh_othvehicles_count 

*Divide household level variables across main adults
foreach i in hh_collectnvaluables hh_carvehicles hh_othvehicles hh_pnumberplate hh_collectnvaluables_ch hh_pnumberplate_ch hh_carvehicles_ch hh_othvehicles_ch  hh_contentsmp {
replace `i' = 0 if mainadultsflag!=1 & !missing(`i') //assigns to main BU adults only
gen ind_`i' = `i'/numadults
rename ind_hh* ind*
}

foreach i in ind_collectnvaluables ind_carvehicles ind_othvehicles ind_pnumberplate hh_collectnvaluables hh_carvehicles hh_othvehicles hh_pnumberplate ind_collectnvaluables_ch hh_collectnvaluables_ch ind_pnumberplate_ch hh_pnumberplate_ch ind_othvehicles_ch hh_othvehicles_ch ind_carvehicles_ch hh_carvehicles_ch {
recode `i' (.=0)
}

*Total household contents (for alternative definition, reduce value of household contents to 40% of reported replacement value)
g double ind_contents = 0.4*(ind_contentsmp + ind_contentssp + ind_contentsbtl + ind_contentsos)
drop ind_contentsmp ind_contentssp ind_contentsbtl ind_contentsos hh_contentsmp

*Physical wealth (do not include household contents ind_contents)
g double ind_phys = ind_collectnvaluables + ind_carvehicles + ind_othvehicles + ind_pnumberplate
g double hh_phys  = hh_collectnvaluables + hh_carvehicles + hh_othvehicles + hh_pnumberplate
lab var ind_phys "Individual physical wealth"
lab var hh_phys "Household physical wealth"

*Charegeable physical wealth 
g double ind_phys_ch = ind_collectnvaluables_ch + ind_carvehicles_ch + ind_othvehicles_ch + ind_pnumberplate_ch
g double hh_phys_ch = hh_collectnvaluables_ch + hh_carvehicles_ch + hh_othvehicles_ch + hh_pnumberplate_ch
lab var ind_phys_ch "Individual physical wealth, chargeable"
lab var hh_phys_ch "Household physical wealth, chargeable"			

//Total (market value) wealth variables
g double ind_totwlth = ind_pen + ind_fin_net + ind_prop_net + ind_businessassets + ind_phys
g double hh_totwlth = hh_pen + hh_fin_net + hh_prop_net + hh_businessassets + hh_phys
g double eq_totwlth = ind_pen + eq_fin_net + eq_prop_net + eq_businessassets + ind_phys //don't equalise pensions as these aren't usually transferable. Physical assets are already equalised. 
lab var ind_totwlth "Individual net wealth"
lab var hh_totwlth "Household net wealth"
lab var eq_totwlth "Equal split net wealth"

********************
****CHILD WEALTH****
********************
	
*Create a variable equal to 1 if the household reference person has a partner 
bysort caser6: egen doespartnerexist = min(ishrppart)
replace doespartnerexist = . if doespartnerexist == 2 // (=. if ishrppart missing or ishrppart=2 for all HH members)

*Assign HRP partner's wealth to HRP and HRP wealth to HRP partner in dataaset
g double hrppartwealth = ind_totwlth if ishrppart == 1
bysort caser6: egen hrppart_totwlth = mean(hrppartwealth)

g double hrpwealth = ind_totwlth if ishrp == 1
bysort caser6: egen hrp_totwlth = mean(hrpwealth)

*Indicator for if HRP wealth exceeds wealth of HRP partner
g hrphigher = (hrp_totwlth > hrppart_totwlth) if !missing(hrp_totwlth) & !missing(hrppart_totwlth)
replace hrphigher = . if hrp_totwlth == hrppart_totwlth

*Redistribute child wealth (total wealth variable):
*- to HRP or HRP partner according to who has lower wealth (if HRP partner exists)
*- if child's wealth more than the difference between higher wealth partner and lower wealth partner, split the remainder equally (partners will have equal wealth in the end)
*- if HRP partner does not exist, allocate wealth to HRP

bysort caser6: egen childwealth_totwlth = total(ind_totwlth) if agegroup == 1 //children under 16
bysort caser6: egen child_totwlth = mean(childwealth_totwlth) //provide an observation for total household child wealth to all individuals within household
drop childwealth_totwlth
recode child_totwlth (.=0)

g hrppart_totwlth_adj = hrppart_totwlth + min(hrp_totwlth - hrppart_totwlth, child_totwlth) if hrphigher==1 & child_totwlth!=0
g diff = max(child_totwlth - (hrp_totwlth - hrppart_totwlth), 0) if  hrphigher == 1

*How often would allocating to HRP partner change the rank?
g wouldchangerank = (diff > 0) if hrphigher == 1
total hrphigher [pw=xs_hh] if ishrp == 1 //number of households where HRP wealth higher than HRP partner
total wouldchangerank [pw=xs_hh] if hrphigher == 1 & ishrp == 1 //number of households where allocating child wealth to lower wealth (HRP partner) would change the rank
drop wouldchangerank

*Split excess equally
g hrppartnew = hrppart_totwlth_adj + diff/2 if hrphigher==1
g hrpnew = hrp_totwlth + diff/2 if hrphigher==1
drop diff hrppart_totwlth_adj

*If HRP partner wealth higher than HRP
g hrp_totwlth_adj = hrp_totwlth + min(hrppart_totwlth - hrp_totwlth, child_totwlth) if hrphigher==0 & child_totwlth!=0
g diff = max(child_totwlth - (hrppart_totwlth - hrp_totwlth), 0) if hrphigher==0

*How often would allocating to HRP change the rank
g wouldchangerank = (diff > 0) if hrphigher == 0
total xs_hh if hrphigher == 0 & ishrp == 1 //number of households where HRP partner wealth higher than HRP 
total wouldchangerank [pw=xs_hh] if hrphigher == 0 & ishrp == 1 //number of households where allocating child wealth to lower wealth (HRP) would change the rank
drop wouldchangerank

*Split excess equally
replace hrpnew = hrp_totwlth_adj + diff/2 if hrphigher==0
replace hrppartnew = hrppart_totwlth + diff/2 if hrphigher==0
drop diff hrp_totwlth_adj

replace hrpnew = hrp_totwlth + child_totwlth/2 if hrp_totwlth == hrppart_totwlth
replace hrppartnew = hrppart_totwlth + child_totwlth/2 if hrp_totwlth == hrppart_totwlth

*How many households where HRP and HRP partner have equal wealth?
total xs_hh if hrp_totwlth == hrppart_totwlth & ishrp == 1

*Individual wealth with child wealth allocated to parents
g double rf_totwlth = ind_totwlth
replace rf_totwlth = hrpnew if ishrp == 1 & doespartnerexist == 1 & !missing(hrpnew)
replace rf_totwlth = hrppartnew if ishrppart == 1 & !missing(hrppartnew)
replace rf_totwlth = ind_totwlth + child_totwlth if ishrp == 1 & doespartnerexist !=1
lab var rf_totwlth "Individual net wealth (child wealth allocated to parents)"

replace rf_totwlth = 0 if agegroup == 1 
drop hrphigher hrppartwealth hrpwealth hrpnew hrppartnew



*Apply same procedure to key asset type components
*Allocation may not match the allocation of total child wealth as the wealth of each spouse is not taken into account in the assignment of each component. 
*n.b.Children shouldn't have pension or housing wealth so it shouldn't matter for when we exclude main homes and pensions from taxable wealth. 

foreach var in businessassets businessassets_ch pen pen_ch fin_net fin_grs prop_net prop_net_ch phys phys_ch shares mainhome_net mainhome_net_ch dvhvaluer6 dvhvaluer6_ch dvhsevalr6_sum dvhsevalr6_sum_ch dvbltvalr6_sum dvbltvalr6_sum_ch dvbldvalr6_sum dvbldvalr6_sum_ch dvlukvalr6_sum dvlukvalr6_sum_ch dvlosvalr6_sum dvlosvalr6_sum_ch dvoprvalr6_sum dvoprvalr6_sum_ch bval1 bval2 bval3 bworth collectnvaluables carvehicles othvehicles pnumberplate collectnvaluables_ch carvehicles_ch othvehicles_ch pnumberplate_ch mortgage mortmain hfinl listed unlisted smallbus largebus smallbus_ch largebus_ch db_pensions db_pensions_ch non_db non_db_ch contents {

	*HRP/partner comparison on an asset-by-asset basis:
	g double hrppartw_`var' = ind_`var' if ishrppart == 1
	bysort caser6: egen hrppart_tot_`var' = mean(hrppartw_`var')

	g double hrpw_`var' = ind_`var' if ishrp == 1
	bysort caser6: egen hrp_tot_`var' = mean(hrpw_`var')

	g hrphigher = (hrp_tot_`var' > hrppart_tot_`var') if !missing(hrp_tot_`var') & !missing(hrppart_tot_`var')
	replace hrphigher = . if (hrp_tot_`var' == hrppart_tot_`var')


	*Redistribute child wealth (total wealth variable):
	*- to HRP or HRP partner according to who has lower wealth (if HRP partner exists)
	*- if child's wealth more than the difference between higher wealth partner and lower wealth partner, split the remainder equally (partners will have equal wealth in the end)
	*- if HRP partner does not exist, allocate wealth to HRP

	bysort caser6: egen childwealth_`var' = total(ind_`var') if agegroup == 1 //children under 16
	bysort caser6: egen child_`var' = mean(childwealth_`var') //provide an observation for total household child wealth to all individuals within household
	drop childwealth_`var' 
	recode child_`var' (. = 0)

	g hrppart_`var'_adj = hrppart_tot_`var' + min(hrp_tot_`var' - hrppart_tot_`var', child_`var') if (hrphigher==1 & child_`var'!=0)
	g diff = max(child_`var' - (hrp_tot_`var' - hrppart_tot_`var'), 0) if hrphigher == 1

	*Split excess equally
	g hrppartnew_`var' = hrppart_`var'_adj + diff/2 if hrphigher==1
	g hrpnew_`var' = hrp_tot_`var' + diff/2 if hrphigher==1
	drop diff hrppart_`var'_adj 

	*If HRP partner wealth higher than HRP
	g hrp_`var'_adj = hrp_tot_`var' + min(hrppart_tot_`var' - hrp_tot_`var', child_`var') if (hrphigher==0 & child_`var'!=0)
	g diff = max(child_`var' - (hrppart_tot_`var' - hrp_tot_`var'), 0) if hrphigher==0

	*Split excess equally
	replace hrpnew = hrp_`var'_adj + diff/2 if hrphigher==0
	replace hrppartnew = hrppart_tot_`var' + diff/2 if hrphigher==0
	drop diff hrp_`var'_adj

	replace hrpnew = hrp_tot_`var' + child_`var'/2 if hrp_tot_`var' == hrppart_tot_`var' 
	replace hrppartnew = hrppart_tot_`var' + child_`var'/2 if hrp_tot_`var' == hrppart_tot_`var' 

	g double rf_`var' = ind_`var'
	replace rf_`var' = hrpnew if ishrp == 1 & doespartnerexist == 1 & !missing(hrpnew)
	replace rf_`var' = hrppartnew if ishrppart == 1 & !missing(hrppartnew)
	replace rf_`var' = ind_`var' + child_`var' if ishrp == 1 & doespartnerexist != 1
	replace rf_`var' = 0 if agegroup == 1 

		
	drop hrpnew hrppartnew hrphigher
	
}


*Business wealth plus shares (for Pareto, not to add to total wealth)
g rf_businessplusshares = rf_businessassets + rf_shares
g hh_businessplusshares = hh_businessassets + hh_shares


**********************
***CHARGEABLE WEALTH VARIABLES*
**********************
*Shares
g rf_shares_ch = rf_shares //no exemption applied to shares
lab var rf_shares_ch "Chargeable shares"

*Net financial wealth
g rf_fin_net_ch = rf_fin_net //no exemption applied to financial wealth 
lab var rf_fin_net_ch "Chargeable net financial wealth"

*Pension
lab var rf_pen_ch "Chargeable pension wealth"

*Property
lab var rf_prop_net_ch "Chargeable property wealth less debt"

*Physical
lab var rf_phys_ch "Chargeable physical wealth"

*Business assets 
lab var rf_businessassets_ch "Chargeable business assets"

*vehicles
g double rf_vehicles_ch = rf_othvehicles_ch + rf_carvehicles_ch
lab var rf_vehicles_ch "Chargeable vehicles"

*Total chargeable wealth variables
g double rf_totwlth_ch = rf_pen_ch + rf_fin_net_ch + rf_prop_net_ch + rf_businessassets_ch + rf_phys_ch
lab var rf_totwlth_ch "Total chargeable wealth"

*Chargeable business pluss shares (chargeable part applies to business assets, not applied it to shares as subcomponent of financial wealth)
g rf_businessplusshares_ch = rf_businessassets_ch + rf_shares_ch
lab var rf_businessplusshares_ch "Chargeable business assets plus shares"

*Total wealth including household contents
g double rf_totwlth_contents_ch = rf_totwlth_ch + rf_contents
lab var rf_totwlth_contents_ch "Total chargeable wealth including household contents"

*******************************
*Chargeable wealth: equal split
*******************************

*Total wealth
*Use rf_pen since this isn't split equally anyway. Use rf_phys_ch since this is already equal split
g double eq_totwlth_ch = rf_pen_ch + eq_prop_net_ch + eq_fin_net + rf_phys_ch + eq_businessassets_ch
lab var eq_totwlth_ch "Equalised total chargeable wealth"



**********************
***INCOME VARIABLES***
**********************


************
*GROSS INCOME*
************
*WAS main definition: 
//Total gross income = 
//gross employment income dvgiempr6 + 
//gross self-employment income dvgiser6 + 
//benefit payments dvbenefitannualr6_i + 
//gross pension income dvgippenr6 + 
//gross investment income dvgiinvr6 + 
//gross annual other regular income dvgiothrr6 = 
	//gross annual income from rent dvgrsrentamtannualr6
	//gross annual income from redundancy payments dvoigrrannualr6_i
	//gross annual income from govt training dvoiggtannualr6_i
	//gross annual income from friends or relatives dvoigfrrannualr6_i
	//gross annual income from maintenance dvoigmaannualr6_i
	//gross annual income from royalties dvoigroannualr6_i
	//gross annual income from overseas occ pension dvoigopannualr6_i
	//gross annual educational grant income dvoigegannualr6_i
	//gross annual income from equity release (lifetime) (would need to be individualised) 		dverecgrossannualr6 
	//gross annual income from equity release (home reversion) (would need to be individualised) dvervrecgrossannualr6
recode dvgiempr6 dvgiser6 dvbenefitannualr6_i dvgippenr6 dvgiinvr6 dvoigrrannualr6_i dvoigroannualr6_i dvgrsrentamtannualr6 dvoigopannualr6_i (.=0)
g ind_ti = dvgiempr6 + dvgiser6 + dvbenefitannualr6_i + dvgippenr6 + dvgiinvr6 + dvoigrrannualr6_i + dvoigroannualr6_i + dvgrsrentamtannualr6 + dvoigopannualr6_i



************
*NET INCOME*
************


*Net income variable used in Loutzenhiser and Mann (2021) "Liquidity issues: solutions for the asset-rich-cash-poor". Fiscal Studies, 42.
// NOTE: Equity release not currently included in the individual income calculation
// Total net other income = net annual income from redundancy payments + 
// net annual income frrom government training + 
// gross annual income from educational grants + 
// net annual income from friends or relatives + 
// net annual income from maintenance + 
// net annual income from royalties + 
// net annual income from overseas occ pensions + 
// net annual income from rent
egen dvniothr6 = rowtotal (dvoinrrannualr6_i dvoingtannualr6_i dvoinegannualr6_i dvoinfrannualr6_i dvoinmaannualr6_i dvoinroannualr6_i dvoinopannualr6_i dvnetrentamtannualr6) 
label var dvniothr6 "Total net other income - individual" 
		
		// HH net income BHC: 
		// Total net regular household annual income (before housing costs) 
		// DVTotInc_BHCW6 = DVNIEmpW6_aggr + DVNISeW6_aggr  + DVBenefitAnnualW6_aggr  + DVNIPPenW6_aggr  + DVNIInvW6_aggr  + DVNIOthRW6_aggr - DVCTAXamtAnnualW6
		// individual version calculated does not deduct Council Tax 
		
egen ind_netinc = rowtotal (dvniempr6 dvniser6 dvbenefitannualr6_i dvnippenr6 dvniinvr6 dvniothr6)
label var ind_netinc "Total net individual regular annual income"

**Household net income:
sum dvtotinc_netr6 // total net regular hosuehold annual income before housing costs
g hh_netinc = dvtotinc_netr6

*Council tax
sum dvctaxamtannualw6 if wave == 6
sum dvctaxamtannualw6 if wave == 5 // council tax only available for wave 6 not wave 5
g hh_ctax = dvctaxamtannualw6
sum hh_ctax

*Whether tends to have money left
g int oleft = oleftw6
replace oleft = oleftw5 if missing(oleft)
lab values oleft OLeftW6

*Marital status (for IHT)
g married = 1 if xmarstaw6 == 2 | xmarstaw5 == 2 //married (and not separated)
replace married = 1 if xmarstaw6 == 6 | xmarstaw5 == 3 //Civil partnership (and not separated)
lab var married "Married or in CP"

*Check marital status against whether HRP partner exists
preserve
bys caser6: g count = _n
keep if count == 1
tab married doespartnerexist, m
restore

*Save individual level dataset
preserve
keep rf_* ind_* xs_pers caser6 personw6 personw5 agegroup* gor sex married wave own* mainadultsflag numadults eq_* oleft
save "$cleanwas\r6_alt.dta", replace
restore


*Save household level dataset
preserve
keep xs_hh caser6 gor hh_* ishrp wave
keep if ishrp == 1
save "$cleanwas\r6_hh.dta", replace
restore


