/*******************************************************************************
Description:		Wealth tax modelling: IHT reform
					
Uses: data for analysis defined in step 3.define_sample.do (sample_for_analysis.dta)
*******************************************************************************/

use "$tempdata\sample_for_analysis.dta", clear


*************************************************************************
****IHT CALCULATIONS USING ADJUSTED WAS DATA (adding in unadjusted overlapping households and excluding STRL)
*************************************************************************

use "$cleanwas\r6_alt.dta", clear

append using "$tempdata\strl_2020_clean_imputed.dta"
replace worth = worth*690817/742613 if strl_flag == 1 //rescale to match 2017/18 aggregate wealth

sum worth if strl_flag == 1
g overlap_flag = 1 if rf_businessplusshares > r(min) & strl_flag ==.

keep if overlap_flag == 1
save "$tempdata\overlapping.dta", replace 

*Append overlapping individuals to Pareto adjusted data
use "$tempdata\pareto_adjusted_final.dta", clear
append using "$tempdata\overlapping.dta"
drop if strl_flag == 1

replace rf_totwlth_pareto = rf_totwlth if overlap_flag == 1
replace rf_businessassets_pareto = rf_businessassets if overlap_flag == 1

********************
***Modelling IHT**** 
********************

*Number of deaths: target number of deaths rather than using mortality multipliers, as this corrects for population coverage issues

*Data on deaths come from UK official death statistics published by the ONS for 2018
g deaths = .
if sex == 1 {
replace deaths = 1805	if agegroup_detail == 1
replace deaths = 155	if agegroup_detail == 2
replace deaths = 217	if agegroup_detail == 3
replace deaths = 659	if agegroup_detail == 4
replace deaths = 1146	if agegroup_detail == 5
replace deaths = 1512	if agegroup_detail == 6
replace deaths = 1964	if agegroup_detail == 7
replace deaths = 2684	if agegroup_detail == 8
replace deaths = 3764	if agegroup_detail == 9
replace deaths = 6152	if agegroup_detail == 10
replace deaths = 9116	if agegroup_detail == 11
replace deaths = 12512	if agegroup_detail == 12
replace deaths = 16673	if agegroup_detail == 13
replace deaths = 24451	if agegroup_detail == 14
replace deaths = 35684	if agegroup_detail == 15
replace deaths = 41227	if agegroup_detail == 16
replace deaths = 144652	if agegroup_detail == 17
}
if sex == 2 {
replace deaths = 1443	if agegroup_detail == 1
replace deaths = 150	if agegroup_detail == 2
replace deaths = 135	if agegroup_detail == 3
replace deaths = 319	if agegroup_detail == 4
replace deaths = 443	if agegroup_detail == 5
replace deaths = 673	if agegroup_detail == 6
replace deaths = 1025	if agegroup_detail == 7
replace deaths = 1597	if agegroup_detail == 8
replace deaths = 2164	if agegroup_detail == 9
replace deaths = 4000	if agegroup_detail == 10
replace deaths = 6000	if agegroup_detail == 11
replace deaths = 8657	if agegroup_detail == 12
replace deaths = 11624	if agegroup_detail == 13
replace deaths = 16954	if agegroup_detail == 14
replace deaths = 26415	if agegroup_detail == 15
replace deaths = 33835	if agegroup_detail == 16
replace deaths = 196207	if agegroup_detail == 17
}

*Implied mortality rates
g mortality = .
forval i = 1/17 {
qui total xs_pers if agegroup_detail == `i' & sex == 1
replace mortality = deaths/_b[xs_pers] if agegroup_detail == `i' & sex == 1
qui total xs_pers if agegroup_detail == `i' & sex == 2
replace mortality = deaths/_b[xs_pers] if agegroup_detail == `i' & sex == 2
}


*Define wealth variable for each taxbase
*IHT wealth (using current tax base)
recode rf_pen rf_businessassets_pareto rf_unlisted ind_pen_ondeath rf_unlisted (.=0) 
*Current tax base
g wealth_actual = rf_totwlth_pareto - rf_pen - rf_businessassets_pareto - rf_unlisted
*Adding business assets (including unlisted shares) and pension to the tax base (i.e. removing APR/BPR and pension exemption)
g wealth_reformed = wealth_actual + rf_businessassets_pareto + ind_pen_ondeath + rf_unlisted
*Adding business assets (including unlised shares) only (i.e. removing APR/BPR)
g wealth_reformed_incbusiness = wealth_actual + rf_businessassets_pareto + rf_unlisted
*Adding pensions only
g wealth_reformed_incpensions = wealth_actual + ind_pen_ondeath

local taxbase = "actual" //do not change this!

local rate = 0.4 //current tax rate

*Redefine weights to represent who dies (non-stochastic, but doesn't generate variation in revenue calcs)
*Simply multiply survey weight by mortality multiplier
g deathweight = xs_pers*mortality 

*Check - should be close to target number of deaths
total deathweight

*Define 4% of deaths (target number of estates to tax)
qui total deathweight
scalar targetestates = 0.04*_b[deathweight]

*Identify taxpayers
preserve
drop if married == 1
bys caser6 personw5 personw6 wealth_`taxbase': g random = runiform()
gsort - wealth_`taxbase' random
g cumweight = sum(deathweight)
g diff = abs(targetestates - cumweight)
egen mindiff = min(abs(targetestates - cumweight))
g threshold_wealth = wealth_`taxbase' if diff == mindiff
egen threshold = min(threshold_wealth)
g ihtpayer_ns = 1 if wealth_`taxbase' >= threshold
drop threshold threshold_wealth diff mindiff cumweight random
save "$tempdata\ihtpayer_ns.dta", replace
restore 

*Merge in IHT taxper indicator ihtpayer_ns
merge 1:1 caser6 personw6 personw5  using "$tempdata\ihtpayer_ns.dta", nogen 

total ihtpayer_ns [pw=deathweight] //should be close to target number of taxpaying estates
g ihtpayer_`taxbase' = ihtpayer_ns //to ensure correct indicator is used in BPR analysis

sum wealth_`taxbase' if ihtpayer_ns == 1
g thresholds = r(min)
g threshold_`taxbase' = thresholds
g taxable = wealth_`taxbase' - thresholds if ihtpayer_ns == 1
g taxdue = taxable*`rate' if ihtpayer_ns == 1
g netofatr_`taxbase' = 1-(taxdue/wealth_`taxbase')
g rate = `rate'
g inds = 1

*Statistics for revenue estimates, used in Table 6 of paper
preserve
replace taxable = taxable/1e9
replace taxdue = taxdue/1e9
collapse (sum) assets = taxable taxpayers = ihtpayer_ns revenue = taxdue deaths = inds  (mean) rate threshold = thresholds  [pw=deathweight] 
global actual_revenue = revenue
export excel using "$output\ihtoutputs.xlsx", sheet(IHT_ns_actual, modify) firstrow(var) cell(A2)
restore

g taxdue_actual = taxdue

drop taxable taxdue rate inds thresholds 
 
******************************
*REFORMED IHT (non-stochastic) 
******************************

*Cost of valuing businesses for IHT
g valuation_cost = min(0.005*(rf_businessassets_pareto + rf_unlisted), 25000) if rf_businessassets_pareto + rf_unlisted > 30000

*For each of the three reforms
foreach tb in 1 2 3 {
	*Set labels for excel sheets
	if `tb' == 1 local taxbase = "reformed"
	if `tb' == 2 local taxbase = "reformed_incpension"
	if `tb' == 3 local taxbase = "reformed_incbusiness"


	local rate = 0.4 //current tax rate


	*Identify taxpayers
	preserve
	drop if married == 1
	bys caser6 personw5 personw6 wealth_`taxbase': g random = runiform()
	gsort - wealth_`taxbase' random
	g cumweight = sum(deathweight)
	g diff = abs(targetestates - cumweight)
	egen mindiff = min(abs(targetestates - cumweight))
	g threshold_wealth = wealth_`taxbase' if diff == mindiff
	egen threshold = min(threshold_wealth)
	g ihtpayer_`taxbase' = 1 if wealth_`taxbase' >= threshold
	drop threshold threshold_wealth diff mindiff cumweight random
	save "$tempdata\ihtpayer_reformed.dta", replace
	restore 

	*Merge indicator for being a taxpayer under reformed IHT ihtpayer_`taxbase'
	merge 1:1 caser6 personw6 personw5  using "$tempdata\ihtpayer_reformed.dta", nogen 

	total ihtpayer_`taxbase' [pw=deathweight] //should be close to target number of taxpaying estates


	sum wealth_`taxbase' if ihtpayer_`taxbase' == 1
	g threshold_`taxbase' = r(min)

	g taxable_noavoidance = wealth_`taxbase' - threshold_`taxbase' if ihtpayer_`taxbase' == 1
	g taxdue_noavoidance = taxable_noavoidance*`rate' if ihtpayer_`taxbase' == 1
	if `tb' == 1 g taxdue_reformed = taxdue_noavoidance

	*Net of tax rate under current IHT system and net of tax rate under reformed IHT system
	g netofatr_`taxbase' = 1-(taxdue_noavoidance/wealth_`taxbase') if ihtpayer_`taxbase' == 1
	recode netofatr_`taxbase' netofatr_actual (.=1)


	*Percentage increase in net of atr from reform
	g pct_incr_netofatr = (netofatr_`taxbase' - netofatr_actual)*100/netofatr_actual

	*With old threshold
	g tp_`taxbase'_oldth = 1 if wealth_`taxbase' > threshold_actual & married!=1
	g taxsh_`taxbase'_oldth = wealth_`taxbase' - threshold_actual if tp_`taxbase'_oldth == 1
	g natr_`taxbase'_oldth = 1-((wealth_`taxbase' - threshold_actual)*`rate'/wealth_`taxbase')
	recode natr_`taxbase'_oldth (.=0)
	g pct_incr_natr_oldth = (natr_`taxbase'_oldth - netofatr_actual)*100/netofatr_actual

	*Compute revenue estimates with no avoidance (Table 6 in paper) and some avoidance (Table D1 in paper)
	foreach elasticity in 0 0.2 { //Avoidance rate 0.2 (informed by Kopczuk, 2013, Taxation of Intergenerational Transfers) 

		if `elasticity' == 0 local eflag = ""
		if `elasticity' == 0.2 local eflag = "_a"

		*Elasticity applied to % increase in net-of-tax rate (will reduce wealth of those now liable to IHT and increase wealth of those whose average tax liability falls)
		g arate = `elasticity'*pct_incr_netofatr/100
		sum arate

		g reportedwealth = wealth_`taxbase'*(1+arate)  if ihtpayer_`taxbase' == 1
		g taxable = reportedwealth - threshold_`taxbase' if ihtpayer_`taxbase' == 1
		g taxdue = (reportedwealth - threshold_`taxbase')*`rate' if ihtpayer_`taxbase' == 1
		g rate = `rate'
		g inds = 1
		g vc_`taxbase' = valuation_cost if ihtpayer_`taxbase' == 1

		preserve
		replace taxable = taxable/1e9
		replace taxdue = taxdue/1e9
		collapse (sum) assets = taxable taxpayers = ihtpayer_`taxbase' revenue = taxdue deaths = inds (mean) rate threshold = threshold_`taxbase' (sum) valuation_cost_businesses = vc_`taxbase'  [pw=deathweight] 
		export excel using "$output\ihtoutputs.xlsx", sheet(IHT_ns_`taxbase'`eflag', modify) firstrow(var) cell(A2)
		restore
		preserve
		replace taxable = taxable/1e9
		replace taxdue = taxdue/1e9
		replace reportedwealth = reportedwealth/1e9
		collapse (sum)taxbase = reportedwealth [pw=deathweight] 
		export excel using "$output\ihtoutputs.xlsx", sheet(IHT_ns_`taxbase'`eflag', modify) firstrow(var) cell(A8)
		restore


		*With old threshold
		g arate_oldth = `elasticity'*pct_incr_natr_oldth/100
		g reportedwealth_oldth = wealth_`taxbase'*(1+arate_oldth) if tp_`taxbase'_oldth == 1
		g taxable_oldth = reportedwealth_oldth - threshold_actual if tp_`taxbase'_oldth == 1
		g taxdue_oldth = taxable_oldth*`rate' if tp_`taxbase'_oldth == 1
		g rate_oldth = `rate'
		g vc_`taxbase'_oldth = valuation_cost if tp_`taxbase'_oldth == 1

		preserve
		replace taxable_oldth = taxable_oldth/1e9
		replace taxdue_oldth = taxdue_oldth/1e9
		collapse (sum) assets = taxable_oldth taxpayers = tp_`taxbase'_oldth revenue = taxdue_oldth deaths = inds (mean) rate = rate_oldth threshold = threshold_actual (sum) valuation_cost_businesses= vc_`taxbase'_oldth [pw=deathweight]
		export excel using "$output\ihtoutputs.xlsx", sheet(IHT_ns_`taxbase'`eflag', modify) firstrow(var) cell(A5)
		restore

		preserve
		replace reportedwealth_oldth = reportedwealth_oldth/1e9
		collapse (sum) taxbase = reportedwealth_oldth [pw=deathweight]
		export excel using "$output\ihtoutputs.xlsx", sheet(IHT_ns_`taxbase'`eflag', modify) firstrow(var) cell(A12)
		restore

		drop taxable taxdue taxable_oldth taxdue_oldth rate inds reportedwealth* arate* rate* vc*
	}

	drop pct* threshold_`taxbase' netofatr_`taxbase' *_noavoidance
}

******************************************************************************************************
* Reducing the rate for reformed IHT to target the same revenue as before 
*************************************************************************

local elasticity = 0

*Labels for excel sheets
if `elasticity' == 0 local eflag = ""
if `elasticity' == 0.2 local eflag = "_a"

*Taxable assets under reform
g ass_reformed = wealth_reformed - threshold_actual if tp_reformed_oldth == 1
total ass_reformed [pw=deathweight] if tp_reformed_oldth == 1
local rate = ${actual_revenue}*1e9/_b[ass_reformed] //rate to maintain same revenue

*Define key variables
g taxable = wealth_reformed - threshold_actual if tp_reformed_oldth == 1
g taxdue = taxable*`rate' if tp_reformed_oldth == 1
g rate = `rate'
g inds = 1
g vc_reformed = valuation_cost if tp_reformed_oldth == 1

g taxdue_reformed_lower = taxdue

*Stats used in Table 6
preserve
replace taxable = taxable/1e9
replace taxdue = taxdue/1e9
collapse (sum) assets = taxable taxpayers = tp_reformed_oldth revenue = taxdue deaths = inds (mean) rate threshold = threshold_actual (sum) valuation_cost_businesses = vc_reformed  [pw=deathweight] 
export excel using "$output\ihtoutputs.xlsx", sheet(IHT_ns_reformed`eflag'rv, modify) firstrow(var) cell(A2)
restore

drop taxable taxdue rate inds rate* vc*


*****ADDDING AVOIDANCE*****

local rate = `rate' - 0.005 // choose depending on what the no-avoidance scenario came out with 

local elasticity = 0.2  //Avoidance rate 0.2 (informed by Kopczuk, 2013, Taxation of Intergenerational Transfers) 

if `elasticity' == 0 local eflag = ""
if `elasticity' == 0.2 local eflag = "_a"

g taxable_noavoidance = wealth_reformed - threshold_actual if tp_reformed_oldth == 1
g taxdue_noavoidance = taxable_noavoidance*`rate' if tp_reformed_oldth == 1

*Net of tax rate under current IHT system and net of tax rate under reformed IHT system
g netofatr_reformed = 1-(taxdue_noavoidance/wealth_reformed) if tp_reformed_oldth == 1
recode netofatr_reformed netofatr_actual (.=1)

*Percentage increase in net of atr from reform
g pct_incr_netofatr = (netofatr_reformed - netofatr_actual)*100/netofatr_actual

*Elasticity applied to % increase in net-of-tax rate (will reduce wealth of those now liable to IHT and increase wealth of those whose average tax liability falls)
g arate = `elasticity'*pct_incr_netofatr/100

g reportedwealth = wealth_reformed*(1+arate)  if tp_reformed_oldth == 1
g taxable = reportedwealth - threshold_actual if tp_reformed_oldth == 1
g taxdue = (reportedwealth - threshold_actual)*`rate' if tp_reformed_oldth == 1
g rate = `rate'
g inds = 1
g vc_reformed = valuation_cost if tp_reformed_oldth == 1

*Stats for Table D1
preserve
replace taxable = taxable/1e9
replace taxdue = taxdue/1e9
collapse (sum) assets = taxable taxpayers = tp_reformed_oldth revenue = taxdue deaths = inds (mean) rate threshold = threshold_actual (sum) valuation_cost_businesses = vc_reformed  [pw=deathweight] 
export excel using "$output\ihtoutputs.xlsx", sheet(IHT_ns_reformed`eflag'rv, modify) firstrow(var) cell(A2)
restore

drop taxable taxdue  rate inds threshold_actual netofatr_reformed  pct* reportedwealth* arate* rate* vc* ihtpayer_ns 



****END OF IHT REFORM MODELLING

rename tp_reformed_oldth ihtpayer_reformed_oldth
rename tp_reformed_incpension_oldth ihtpayer_incpension_oldth
rename tp_reformed_incbusiness_oldth ihtpayer_incbusiness_oldth
rename taxsh_reformed_oldth taxdue_reformed_oldth
rename taxsh_reformed_incpension_oldth taxdue_incpension_oldth
rename taxsh_reformed_incbusiness_oldth taxdue_incbusiness_oldth
drop taxdue_noavoidance

save "$tempdata\iht_for_analysis.dta", replace


* switch back to using sample data (include STRL again, and excluding )
use "$tempdata\sample_for_analysis.dta", clear 

