/*******************************************************************************
Description:		Council tax analysis

Uses:				Clean household-level WAS data from step 1.round_6_alt.do (r6_hh.dta)
*******************************************************************************/


********************
*******SETUP*******
********************
clear all


use "$cleanwas\r6_hh", clear

*Key variables:
	*hh_ctax // annual council tax payment
	*hh_totwlth // HH level market value wealth
	*hh_prop_net // HH net property wealth
	*hh_ukhousing_grs // HH gross UK housing wealth
	*xs_hh //household weight

*Note: Council tax info only available in wave 6. Need to scale up weights to match total population 
total xs_hh
scalar pop_r6 = _b[xs_hh]
total xs_hh if wave == 6 
scalar pop_w6 = _b[xs_hh]
g xs_hh_scaled = xs_hh*(pop_r6/pop_w6)
total xs_hh_scaled if wave == 6 //use this scaled weight in council tax analysis

drop if wave == 5
count if hh_ctax == .

**How much council tax is paid?
total hh_ctax [pw=xs_hh_scaled] // Official stats suggest £28 billion for England in 2017-18, £1.5 billion in Wales, £2.4 billion in Scotland. We're getting £32 billion here for England, Scotland and Wales.

*Total council tax as share of UK gross housing wealth
total hh_ctax [pw=xs_hh_scaled]
scalar total_ctax = _b[hh_ctax]
total hh_ukhousing_grs [pw=xs_hh_scaled]
scalar total_ukhousing = _b[hh_ukhousing_grs]
di "Council tax as share of UK housing wealth = " total_ctax/total_ukhousing

*Proportional tax
di total_ukhousing*0.0083 - total_ctax
di total_ukhousing*0.0076 - total_ctax

*EATRS by wealth (council tax divided by total marketable wealth)
g eatr_wealth = (hh_ctax/hh_totwlth)*100

xtile wealth_ptle = hh_totwlth [pw=xs_hh_scaled], nq(100)

preserve
collapse (mean) mean_eatr = eatr_wealth (p10) pct10_eatr = eatr_wealth (p25) pct25_eatr = eatr_wealth (median) median_eatr = eatr_wealth (p75) pct75_eatr = eatr_wealth (p90) pct90_eatr = eatr_wealth (max) max_eatr = eatr_wealth [pw=xs_hh_scaled], by(wealth_ptle)
export excel "$output\council_tax_analysis.xlsx", sheet("EATR by wealth", modify) cell(A2) firstrow(var)
restore

*EATRs by wealth bucket
local steps = 200000
local top = 10000000 - `steps'
g bucket_wealth =.
g bucket_wealth_lb = .
forval t = 0(`steps')`top'{
replace bucket_wealth = (`t')/`steps' + 1 if hh_totwlth> = `t' & hh_totwlth < `t' + `steps' 
replace bucket_wealth_lb = `t' if hh_totwlth> = `t' & hh_totwlth < `t' + `steps' 
}

preserve
collapse (mean) bucket_lower = bucket_wealth_lb mean_eatr = eatr_wealth (p10) pct10_eatr = eatr_wealth (p25) pct25_eatr = eatr_wealth (median) median_eatr = eatr_wealth (p75) pct75_eatr = eatr_wealth (p90) pct90_eatr = eatr_wealth (max) max_eatr = eatr_wealth [pw=xs_hh_scaled], by(bucket_wealth)
export excel "$output\council_tax_analysis.xlsx", sheet("EATR by wealth bucket", modify) cell(A2) firstrow(var)
restore

*EATRS by income (council tax divided by household net income)
g eatr_income = (hh_ctax/hh_netinc)*100

xtile inc_ptle = hh_netinc [pw=xs_hh_scaled], nq(100)

preserve
collapse (mean) mean_eatr = eatr_income (p10) pct10_eatr = eatr_income (p25) pct25_eatr = eatr_income (median) median_eatr = eatr_income (p75) pct75_eatr = eatr_income (p90) pct90_eatr = eatr_income (max) max_eatr = eatr_income  [pw=xs_hh_scaled], by(inc_ptle)
export excel "$output\council_tax_analysis.xlsx", sheet("EATR by income", modify) cell(A2) firstrow(var)
restore
mean eatr_income if inc_ptle >= 75 [pw=xs_hh_scaled]

*EATRs by income bucket
local steps = 5000
local top = 2050000 - `steps'
g bucket_inc =.
g bucket_inc_lb = .
forval t = 0(`steps')`top'{
replace bucket_inc = (`t')/`steps' + 1 if hh_netinc> = `t' & hh_netinc< `t' + `steps' 
replace bucket_inc_lb = `t' if hh_netinc> = `t' & hh_netinc < `t' + `steps' 
}

preserve
collapse (mean) bucket_lower = bucket_inc_lb mean_eatr = eatr_income (p10) pct10_eatr = eatr_income (p25) pct25_eatr = eatr_income (median) median_eatr = eatr_income (p75) pct75_eatr = eatr_income (p90) pct90_eatr = eatr_income [pw=xs_hh_scaled], by(bucket_inc)
export excel "$output\council_tax_analysis.xlsx", sheet("EATR by income bucket", modify) cell(A2) firstrow(var)
restore



*Council tax liability by property value
clear all 
set obs 1001

g prop_val = (_n - 1)*10000

*Council tax band
g band = 1 if prop_val <= 142000
replace band = 2 if prop_val >= 142001 & prop_val <= 204560
replace band = 3 if prop_val >= 204561 & prop_val <= 301810
replace band = 4 if prop_val >= 301811 & prop_val <= 415120
replace band = 5 if prop_val >= 415121 & prop_val <= 571050
replace band = 6 if prop_val >= 571051 & prop_val <= 794420
replace band = 7 if prop_val >= 794421 & prop_val <= 1769840
replace band = 8 if prop_val >= 1769841

*Current average council tax payment (see Table 8)
g tax = 1173 if band == 1
replace tax = 1365 if band == 2
replace tax = 1558 if band == 3
replace tax = 1750 if band == 4
replace tax = 2135 if band == 5
replace tax = 2520 if band == 6
replace tax = 2923 if band == 7
replace tax = 3500 if band == 8

g current_atr = tax/prop_val
replace current_atr = 0 if prop_val == 0

*Tax under the two reforms
g tax_r1 = 0.0086*prop_val
g tax_r2 = 0.0076*prop_val

export excel using "$output\council_tax_analysis.xlsx", sheet("ATR by property value", modify) cell(A2) firstrow(var)






