/*******************************************************************************
Description:		Wealth tax modelling: liquidity analysis

Uses: data for analysis defined in step 3.define_sample.do (sample_for_analysis.dta)
*******************************************************************************/

********************
***ANALYSIS**
********************
use "$tempdata\sample_for_analysis.dta", clear

*Drop STRL individuals from liquidity analysis as we have no income information
drop if strl_flag == 1 //added a new "use dataset" line below so this doesn't get carried through beyond the liquidity analysis in this do-file


********************
***** LIQUIDITY ****
********************
*By implementing a Pareto adjustment, we break the link between income and wealth (wealth Pareto adjusted, income is not). 
*Solution implemented below is to scale up income by the ratio of adjusted wealth to unadjusted wealth.

*Generate net income variable that preserves the ratio between income and unadjusted wealth
g ind_netinc_adj = ind_netinc*rf_totwlth_ch_pareto/rf_totwlth_ch
replace ind_netinc_adj = max(0,ind_netinc_adj) if !missing(ind_netinc_adj) //censor few negatives

*Choose income variable ind_netinc or ind_netinc_adj on which to base liquidity analysis
global incvar ind_netinc_adj

*Generate chargeable pension wealth by setting each component equal to 0 if total pension wealth < £3k - don't want to use the chargeable variables for calculating liquid wealth though, because even if a pension pot is too small to be chargeable, it could still be used to pay the tax.
foreach var in ind_retained_dc ind_retained_drawdown ind_retained_db_lumpsum ind_current_db_lumpsum  ind_current_avc  ind_personal ind_pen_in_payment ind_retained_db ind_current_db {
	g `var'_ch = `var' 
	replace `var'_ch = 0 if rf_pen_ch == 0
}

*Value of pensions not in payment
g ind_pen_nip_ch = rf_pen_ch - ind_pen_in_payment_ch //will be 0 for individuals with pension wealth below the £3k rule

*Generate immediate tax liability: if individual is less than state pension age (66), deduct pensions not yet being drawn (pensions not in payment or not for drawdown)
g immediately_taxable_wealth = rf_totwlth_ch_pareto
replace immediately_taxable_wealth = immediately_taxable_wealth - ind_pen_nip_ch if agegroup <= 6 // have to go with <65 as not detailed enough age variable


*Define liquid pensions by age
	*if over 65, DC pots and DB lump sums become liquid 
	*if under 65, no liquid pension wealth - some individuals report being able to access DB pension early, but some also report access age over state pension age and I don't think any of this is consistently reported, so going to assume it's only accessible after SPA
g liquid_pension = ind_retained_dc + ind_retained_drawdown + ind_retained_db_lumpsum + ind_current_db_lumpsum + ind_current_avc + ind_personal if agegroup >= 7
replace liquid_pension = 0 if agegroup <= 6 
replace liquid_pension = . if strl_flag == 1

//not using chargeable pension here because whether or not is chargeable doesn't matter for being able to pay out of it
g potentially_illiquid_pension = rf_pen - liquid_pension if agegroup >= 7

*Generate liquid assets (gross financial wealth), censored at 0
g liquid_fin = max(0, rf_fin_grs_pareto) 
replace liquid_fin = . if strl_flag == 1
g liquid_wealth = liquid_fin + liquid_pension
replace liquid_wealth = . if strl_flag == 1

*Property excluding main home
g rf_prop_oth_ch = rf_prop_net_ch - rf_mainhome_net_ch

*Components of immediately taxable wealth:
	*if over age 65: rf_pen rf_prop_net rf_phys_ch rf_businessassets_pareto rf_fin_net_pareto
	*if under age 65: ind_pen_in_payment rf_prop_net rf_businessassets_pareto rf_fin_net_pareto
*Largest component: 
egen maxvalue_old = rowmax(liquid_pension potentially_illiquid_pension rf_mainhome_net_ch rf_prop_oth_ch rf_phys_ch rf_businessassets_ch_pareto rf_fin_net_ch_pareto) if agegroup >= 7
egen maxvalue_young = rowmax(ind_pen_in_payment_ch rf_mainhome_net_ch rf_prop_oth_ch rf_phys_ch rf_businessassets_ch_pareto rf_fin_net_ch_pareto) if agegroup <= 6

*Identify lagest component of wealth
g mainasset = 1 if rf_mainhome_net_ch == maxvalue_young | rf_mainhome_net_ch == maxvalue_old
replace mainasset = 2 if rf_prop_oth_ch == maxvalue_young | rf_prop_oth_ch == maxvalue_old
replace mainasset = 3 if rf_fin_net_ch_pareto == maxvalue_young | rf_fin_net_ch_pareto == maxvalue_old
replace mainasset = 4 if rf_phys_ch == maxvalue_young | rf_phys_ch == maxvalue_old
replace mainasset = 5 if rf_businessassets_ch_pareto == maxvalue_young | rf_businessassets_ch_pareto == maxvalue_old
replace mainasset = 6 if ind_pen_in_payment_ch == maxvalue_young & agegroup <= 6
replace mainasset = 7 if liquid_pension == maxvalue_old & agegroup >= 7
replace mainasset = 8 if potentially_illiquid_pension == maxvalue_old  & agegroup >= 7
replace mainasset = 0 if maxvalue_old <= 0 | maxvalue_young <= 0 // people with no positive assets
replace mainasset = . if strl_flag == 1

lab define mainasset 0 "No positive assets" 1 "Main residence" 2 "Other property" 3 "Financial wealth" 4 "Chargeable physical wealth" 5 "Business assets" 6 "Pensions in payment" 7 "Liquid pension wealth" 8 "Illiquid pensions"
lab values mainasset mainasset

*Indicator for whether pension age or not
g oldyoung = 1 if agegroup >= 7
replace oldyoung = 0 if agegroup <= 6
lab define oldyoung 0 "Age under 65" 1 "Age over 65"
lab values oldyoung oldyoung

*Taxpayer bands
g band_lb = 250000 if rf_totwlth_ch_pareto >= 250000 & rf_totwlth_ch_pareto < 500000
replace band_lb = 500000 if rf_totwlth_ch_pareto >= 500000 & rf_totwlth_ch_pareto < 1000000 
replace band_lb = 1000000 if rf_totwlth_ch_pareto >= 1000000 & rf_totwlth_ch_pareto < 2000000 
replace band_lb = 2000000 if rf_totwlth_ch_pareto >= 2000000 & rf_totwlth_ch_pareto < 5000000 
replace band_lb = 5000000 if rf_totwlth_ch_pareto >= 5000000 

***********************************************
* Liquidity analysis for a one-off wealth tax *
***********************************************

*Generate immediate tax liability under different thresholds and define taxpaying population (based on tax supposed to pay: no avoidance) 
foreach flat_threshold in $thresholds {

	*Rates for one off flat tax (annualised) - target £250bn before admin costs (after evasion)
	if `flat_threshold' == 250000 local rate = $frate_one_250/5
	if `flat_threshold' == 500000 local rate = $frate_one_500/5
	if `flat_threshold' == 1000000 local rate = $frate_one_1m/5
	if `flat_threshold' == 2000000 local rate = $frate_one_2m/5
	if `flat_threshold' == 5000000 local rate = $frate_one_5m/5

	*Indicator for whether taxpayer for given threshold
	g taxpayer_`flat_threshold' = (rf_totwlth_ch_pareto > `flat_threshold') //define whether a taxpayer not based on total chargeable wealth including pensions (still a taxpayer even if no tax due immediately)

	*Immediate tax to pay
	g immediate_tax_`flat_threshold' = (immediately_taxable_wealth - `flat_threshold')*`rate' if immediately_taxable_wealth > `flat_threshold'
	replace immediate_tax_`flat_threshold' = 0 if taxpayer_`flat_threshold' == 1 & immediately_taxable_wealth < `flat_threshold' // if only taxed on pension wealth

	*Indicator for whether has tax to pay immediately
	g have_cash2pay_`flat_threshold' = (immediate_tax_`flat_threshold' > 0) if taxpayer_`flat_threshold' == 1

	*Tax rate
	g rate_`flat_threshold' = `rate' if taxpayer_`flat_threshold' == 1
}


*Generate immediate tax liability under progressive taxes (tax supposed to pay - no avoidance)
foreach rates in 1 2 {

local oneoff = 1

*Rates - these are annualised by tax liability by 5
if `rates' == 1 scalar rate_500k = $prate_one_500
if `rates' == 1 scalar rate_1m = $prate_one_1m
if `rates' == 1 scalar rate_2m = $prate_one_2m
if `rates' == 1 scalar rate_5m = $prate_one_5m
if `rates' == 1 scalar rate_10m = $prate_one_10m

if `rates' == 2 scalar rate_500k = $prate2_one_500
if `rates' == 2 scalar rate_1m = $prate2_one_1m
if `rates' == 2 scalar rate_2m = $prate2_one_2m
if `rates' == 2 scalar rate_5m = $prate2_one_5m
if `rates' == 2 scalar rate_10m = $prate2_one_10m

*Tax due on wealth between £500k and £1m
if `rates' == 1 {
	g tax_due_500k = 0
}

if `rates' == 2 {
	g tax_due_500k = .
	replace tax_due_500k = 0 if immediately_taxable_wealth < 500000
	replace tax_due_500k = (immediately_taxable_wealth - 500000)*rate_500k if immediately_taxable_wealth >= 500000
	replace tax_due_500k = 500000*rate_500k if immediately_taxable_wealth > 1000000
}

*Tax due on wealth between £1m and £2m
g tax_due_1m = .
replace tax_due_1m = 0 if immediately_taxable_wealth < 1000000
replace tax_due_1m = (immediately_taxable_wealth - 1000000)*rate_1m if immediately_taxable_wealth >= 1000000
replace tax_due_1m = 1000000*rate_1m if immediately_taxable_wealth > 2000000

*Tax due on wealth between £2m and £5m
g tax_due_2m = .
replace tax_due_2m = 0 if immediately_taxable_wealth < 2000000
replace tax_due_2m = (immediately_taxable_wealth - 2000000)*rate_2m if immediately_taxable_wealth >= 2000000
replace tax_due_2m = 3000000*rate_2m if immediately_taxable_wealth > 5000000

*Tax due on wealth between £5m and £10m
g tax_due_5m = .
replace tax_due_5m = 0 if immediately_taxable_wealth < 5000000
replace tax_due_5m = (immediately_taxable_wealth - 5000000)*rate_5m if immediately_taxable_wealth >= 5000000
replace tax_due_5m = 5000000*rate_5m if immediately_taxable_wealth > 10000000

*Tax due on wealth above £10m
g tax_due_10m = .
replace tax_due_10m = 0 if immediately_taxable_wealth < 10000000
replace tax_due_10m = (immediately_taxable_wealth - 10000000)*rate_10m if immediately_taxable_wealth >= 10000000

*Immediate tax due
g immediate_tax_`rates' = tax_due_500k + tax_due_1m + tax_due_2m + tax_due_5m + tax_due_10m
if `rates' == 1 {
	*Whether a taxpayer
	g taxpayer_`rates' = taxpayer_1000000 
	replace immediate_tax_`rates' = 0 if taxpayer_`rates' == 1 & immediately_taxable_wealth < 1000000 // if only taxed on pension wealth
}
if `rates' == 2 {
	*Whether a taxpayer
	g taxpayer_`rates' = taxpayer_500000 
	replace immediate_tax_`rates' = 0 if taxpayer_`rates' == 1 & immediately_taxable_wealth < 500000 // if only taxed on pension wealth
}

if `oneoff' == 1 replace immediate_tax_`rates' = immediate_tax_`rates'/5

drop tax_due_*
}

*Set liquidity constrained definition (main: tax > 20% of net income or 10% of net income plus liquid wealth)
foreach def in 3 2 1 {
di "one off, £250bn target, definition " `def'
	if `def' == 1 {
		global c1 0.2 //criteria 1: if tax > x% of net income (MAIN SPEC = 0.2, 20%)
		global c2 0.1 //criteria 2: if tax > x% of net income plus liquid wealth (MAIN SPEC = 0.1, 10%)
	}
	if `def' == 2 {
		global c1 0.4 
		global c2 0.2
	}
	if `def' == 3 {
		global c1 0.1
		global c2 0.05
	}

	*Generate whether liquidity constrained under different flat taxes
	foreach flat_threshold in $thresholds { 
		*First criteria: immediate tax > 20% net income (main spec)
		g criteria1_`flat_threshold' = ((immediate_tax_`flat_threshold'/${incvar}) > $c1) if taxpayer_`flat_threshold' == 1 & !missing($incvar)
		replace criteria1_`flat_threshold' = 0 if immediate_tax_`flat_threshold' == 0 //otherwise set to 1 when income = 0

		*Second criteria: immediate tax > 10% net income plus liquid wealth (main spec)
		g criteria2_`flat_threshold' = ((immediate_tax_`flat_threshold'/(${incvar} + liquid_wealth)) > $c2) if taxpayer_`flat_threshold' == 1 & !missing(${incvar}) & !missing(liquid_wealth)
		replace criteria2_`flat_threshold' = 0 if immediate_tax_`flat_threshold' == 0 

		*Indicator for whether liquidity constrained (both criteria met)
		g liq_constrained_flat_`flat_threshold' = (criteria1_`flat_threshold' == 1 & criteria2_`flat_threshold' == 1) if taxpayer_`flat_threshold' == 1 & !missing(criteria1_`flat_threshold') & !missing(criteria2_`flat_threshold')
	}


	*Generate whether liquidity constrained under different progressive taxes
	foreach rates in 1 2 {
		*First criteria
		g criteria1_`rates' = ((immediate_tax_`rates'/${incvar}) > $c1) if taxpayer_`rates' == 1 & !missing(${incvar})
		replace criteria1_`rates' = 0 if immediate_tax_`rates' == 0
		*Second criteria
		g criteria2_`rates' = ((immediate_tax_`rates'/(${incvar} + liquid_wealth)) > $c2) if taxpayer_`rates' == 1 & !missing(${incvar}) & !missing(liquid_wealth)
		replace criteria2_`rates' = 0 if immediate_tax_`rates' == 0
		*Indicator for whether liquidity constrained (both criteria met)
		g liq_constrained_prog_`rates' = (criteria1_`rates' == 1 & criteria2_`rates' == 1)  if taxpayer_`rates' == 1 & !missing(criteria1_`rates') & !missing(criteria2_`rates')
	}

	*Percent and number of taxpayers liquidity constrained by band - flat tax
	preserve 
		collapse (mean) pct_constrained_250k = liq_constrained_flat_250000 ///
		pct_constrained_500k = liq_constrained_flat_500000 ///
		pct_constrained_1m = liq_constrained_flat_1000000 ///
		pct_constrained_2m = liq_constrained_flat_2000000 ///
		pct_constrained_5m = liq_constrained_flat_5000000 ///
		(sum) num_constrained_250k = liq_constrained_flat_250000 ///
		num_constrained_500k = liq_constrained_flat_500000 ///
		num_constrained_1m = liq_constrained_flat_1000000 ///
		num_constrained_2m = liq_constrained_flat_2000000 ///
		num_constrained_5m = liq_constrained_flat_5000000 [pw=xs_pers], by(band_lb)
		foreach var of varlist num_constrained_* {
			replace `var' = `var'/1000
		}
		if `def' == 1 {
			export excel "$output\analysis.xlsx", sheet("Liquidity constrained, flat", modify) firstrow(var) cell(A2)
		}
		if `def' == 2 | `def' == 3 {
			export excel "$output\analysis.xlsx", sheet("Liquidity constrained, flat`def'", modify) firstrow(var) cell(A2)
		}
	restore

	*Percent and number of taxpayers liquidity constrained (all taxpayers) - flat tax
	preserve 
		collapse (mean) pct_constrained_250k = liq_constrained_flat_250000 ///
		pct_constrained_500k = liq_constrained_flat_500000 ///
		pct_constrained_1m = liq_constrained_flat_1000000 ///
		pct_constrained_2m = liq_constrained_flat_2000000 ///
		pct_constrained_5m = liq_constrained_flat_5000000 ///
		(sum) num_constrained_250k = liq_constrained_flat_250000 ///
		num_constrained_500k = liq_constrained_flat_500000 ///
		num_constrained_1m = liq_constrained_flat_1000000 ///
		num_constrained_2m = liq_constrained_flat_2000000 ///
		num_constrained_5m = liq_constrained_flat_5000000 [pw=xs_pers]
		foreach var of varlist num_constrained_* {
			replace `var' = `var'/1000
		}
		if `def' == 1 {
			export excel "$output\analysis.xlsx", sheet("Liquidity constrained, flat", modify) firstrow(var) cell(A10)
		}
		if `def' == 2 | `def' == 3 {
			export excel "$output\analysis.xlsx", sheet("Liquidity constrained, flat`def'", modify) firstrow(var) cell(A10)
		}
	restore

	if `def' == 1 {
		*Percent and number of taxpayers liquidity constrained by band - progressive tax
		preserve
			collapse (mean) pct_constrained_1 = liq_constrained_prog_1 ///
			pct_constrained_2 = liq_constrained_prog_2 ///
			(sum) num_constrained_1 = liq_constrained_prog_1 ///
			num_constrained_2 = liq_constrained_prog_2 [pw=xs_pers], by(band_lb)
			foreach var of varlist num_constrained_* {
				replace `var' = `var'/1000
			}
			export excel "$output\analysis.xlsx", sheet ("Liquidity constrained, prog", modify) firstrow(var) cell(A2)
		restore

		*Percent and number of taxpayers liquidity constrained (all taxpayers) - progressive tax
		preserve
			collapse (mean) pct_constrained_1 = liq_constrained_prog_1 ///
			pct_constrained_2 = liq_constrained_prog_2 ///
			(sum) num_constrained_1 = liq_constrained_prog_1 ///
			num_constrained_2 = liq_constrained_prog_2 [pw=xs_pers]
			foreach var of varlist num_constrained_* {
				replace `var' = `var'/1000
			}
			export excel "$output\analysis.xlsx", sheet ("Liquidity constrained, prog", modify) firstrow(var) cell(A10)
		restore
	}

*Number of taxpayers total
	preserve
		collapse (sum) num_taxpayers_250k = taxpayer_250000 ///
		num_taxpayers_500k = taxpayer_500000 ///
		num_taxpayers_1m = taxpayer_1000000 ///
		num_taxpayers_2m = taxpayer_2000000 ///
		num_taxpayers_5m = taxpayer_5000000 [pw=xs_pers]
		foreach var of varlist num_tax* {
			replace `var' = `var'/1000
		}
		if `def' == 1 {
			export excel "$output\analysis.xlsx", sheet("Liquidity constrained, flat", modify) firstrow(var) cell(A13)
			export excel "$output\analysis.xlsx", sheet("Have cash to pay, flat", modify) firstrow(var) cell(A13)
		}
		if `def' == 2 | `def' == 3 {
			export excel "$output\analysis.xlsx", sheet("Liquidity constrained, flat`def'", modify) firstrow(var) cell(A13)
		}
	restore
	
	*Export tax rates
	preserve
		collapse (max) rate_250000 rate_500000 rate_1000000 rate_2000000 rate_5000000 
		if `def' == 1 {
			export excel "$output\analysis.xlsx", sheet("Liquidity constrained, flat", modify) firstrow(var) cell(A16)
		}
		if `def' == 2 | `def' == 3 {
			export excel "$output\analysis.xlsx", sheet("Liquidity constrained, flat`def'", modify) firstrow(var) cell(A16)
		}
	restore
	
	if `def' == 1 {
		*Percent and number of taxpayers that have cash to pay (tax due on non-pension wealth), by band - flat tax
		preserve
			collapse (mean) pct_cash2pay_250k = have_cash2pay_250000 pct_cash2pay_500k = have_cash2pay_500000 pct_cash2pay_1m = have_cash2pay_1000000 pct_cash2pay_2m = have_cash2pay_2000000 pct_cash2pay_5m = have_cash2pay_5000000 (sum) num_cash2pay_250k = have_cash2pay_250000 num_cash2pay_500k = have_cash2pay_500000 num_cash2pay_1m = have_cash2pay_1000000 num_cash2pay_2m = have_cash2pay_2000000 num_cash2pay_5m = have_cash2pay_5000000 [pw=xs_pers], by(band_lb)
			export excel "$output\analysis.xlsx", sheet("Have cash to pay, flat", modify) firstrow(var) cell(A2)
		restore

		*Percent and number of taxpayers that have cash to pay (tax due on non-pension wealth) of all taxpayers - flat tax
		preserve
			collapse (mean) pct_cash2pay_250k = have_cash2pay_250000 pct_cash2pay_500k = have_cash2pay_500000 pct_cash2pay_1m = have_cash2pay_1000000 pct_cash2pay_2m = have_cash2pay_2000000 pct_cash2pay_5m = have_cash2pay_5000000 (sum) num_cash2pay_250k = have_cash2pay_250000 num_cash2pay_500k = have_cash2pay_500000 num_cash2pay_1m = have_cash2pay_1000000 num_cash2pay_2m = have_cash2pay_2000000 num_cash2pay_5m = have_cash2pay_5000000 [pw=xs_pers]
			export excel "$output\analysis.xlsx", sheet("Have cash to pay, flat", modify) firstrow(var) cell(A10)
		restore
	}

	if `def' == 2 | `def' == 3 {
		drop crit* liq_const*
	}
}

****************
*Main spec only*
****************

*Of those liquidity constrained, what is the largest asset?

*Liquidity constraine by main asset - flat threshold
foreach flat_threshold in $thresholds {
	preserve
		keep if liq_constrained_flat_`flat_threshold' == 1
		g ones = 1
		collapse (sum) ones [pw=xs_pers], by(mainasset)
		export excel "$output\analysis.xlsx", sheet("Comp of liq con, `flat_threshold'", modify) firstrow(var) cell(A2)
	restore
	preserve
		keep if liq_constrained_flat_`flat_threshold' == 1
		g ones = 1
		collapse(sum) ones [pw=xs_pers]
		export excel "$output\analysis.xlsx", sheet("Comp of liq con, `flat_threshold'", modify) firstrow(var) cell(A12)
	restore
}
*Liquidity constrained by main asset - progressive
foreach rates in 1 2 { 
	preserve
		keep if liq_constrained_prog_`rates' == 1
		g ones = 1
		collapse (sum) ones [pw=xs_pers], by(mainasset)
		export excel "$output\analysis.xlsx", sheet("Comp of liq con, prog`rates'", modify) firstrow(var) cell(A2)
	restore
	preserve
		keep if liq_constrained_prog_`rates' == 1
		g ones = 1
		collapse (sum) ones [pw=xs_pers]
		export excel "$output\analysis.xlsx", sheet("Comp of liq con, prog`rates'", modify) firstrow(var) cell(A12)
	restore
}

*Age profile of those owing tax on pensions
g havepension = (rf_pen_ch > 0)
replace havepension = . if strl_flag == 1
g havepension_nip = (ind_pen_nip_ch > 0)
replace havepension_nip = . if strl_flag == 1
g havedb = (ind_retained_db_ch > 0 | ind_current_db_ch > 0)
replace havedb = . if strl_flag == 1
foreach flat_threshold in 250000 500000 1000000 2000000 5000000 {
	preserve
		keep if taxpayer_`flat_threshold' == 1 
		collapse (sum) havepension havepension_nip havedb rf_pen_ch ind_pen_nip_ch  [pw=xs_pers], by(agegroup)
		export excel "$output\BusinessPensionStats.xlsx", sheet("With pen, `flat_threshold'", modify) firstrow(var)
	restore
}

drop immediate_tax*  liq_con* crit* have* rate_*


************************
*WITH ALTERNATIVE SPECS*
************************

*Liquidity constraints with 5% tax
foreach def in 3 2 1 {
	if `def' == 1 {
		global c1 0.2 //criteria 1: if tax > x% of net income (MAIN SPEC = 0.2, 20%)
		global c2 0.1 //criteria 2: if tax > x% of net income plus liquid wealth (MAIN SPEC = 0.1, 10%)
	}
	if `def' == 2 {
		global c1 0.4
		global c2 0.2
	}
	if `def' == 3 {
		global c1 0.1
		global c2 0.05
	}

	*Liquidity constraints with 5% tax
	foreach flat_threshold in $thresholds {

		local rate = 0.01

		g immediate_tax_`flat_threshold' = (immediately_taxable_wealth - `flat_threshold')*`rate' if immediately_taxable_wealth > `flat_threshold'
		replace immediate_tax_`flat_threshold' = 0 if taxpayer_`flat_threshold' == 1 & immediately_taxable_wealth < `flat_threshold' // if only taxed on pension wealth

		g rate_`flat_threshold' = `rate' if taxpayer_`flat_threshold' == 1

		*First criteria
		g criteria1_`flat_threshold' = ((immediate_tax_`flat_threshold'/${incvar}) > $c1) if taxpayer_`flat_threshold' == 1 & !missing($incvar)
		replace criteria1_`flat_threshold' = 0 if immediate_tax_`flat_threshold' == 0 //otherwise set to 1 when income = 0

		*Second criteria
		g criteria2_`flat_threshold' = ((immediate_tax_`flat_threshold'/(${incvar} + liquid_wealth)) > $c2) if taxpayer_`flat_threshold' == 1 & !missing(${incvar}) & !missing(liquid_wealth)
		replace criteria2_`flat_threshold' = 0 if immediate_tax_`flat_threshold' == 0 
		*Indicator for whether liquidity constrained (both criteria met)
		g liq_constrained_flat_`flat_threshold' = (criteria1_`flat_threshold' == 1 & criteria2_`flat_threshold' == 1) if taxpayer_`flat_threshold' == 1 & !missing(criteria1_`flat_threshold') & !missing(criteria2_`flat_threshold')
	}

	*Percent and number of taxpayers liquidity constrained by band - flat tax
	preserve 
		collapse (mean) pct_constrained_250k = liq_constrained_flat_250000 ///
		pct_constrained_500k = liq_constrained_flat_500000 ///
		pct_constrained_1m = liq_constrained_flat_1000000 ///
		pct_constrained_2m = liq_constrained_flat_2000000 ///
		pct_constrained_5m = liq_constrained_flat_5000000 ///
		(sum) num_constrained_250k = liq_constrained_flat_250000 ///
		num_constrained_500k = liq_constrained_flat_500000 ///
		num_constrained_1m = liq_constrained_flat_1000000 ///
		num_constrained_2m = liq_constrained_flat_2000000 ///
		num_constrained_5m = liq_constrained_flat_5000000 [pw=xs_pers], by(band_lb)
		foreach var of varlist num_constrained_* {
			replace `var' = `var'/1000
		}
		if `def' == 1 {
			export excel "$output\analysis.xlsx", sheet("Liquidity con 5per, flat", modify) firstrow(var) cell(A2)
		}
		if `def' == 2 | `def' == 3 {
			export excel "$output\analysis.xlsx", sheet("Liquidity con 5per, flat`def'", modify) firstrow(var) cell(A2)
		}
	restore

	*Percent and number of taxpayers liquidity constrained (all taxpayers) - flat tax
	preserve 
		collapse (mean) pct_constrained_250k = liq_constrained_flat_250000 ///
		pct_constrained_500k = liq_constrained_flat_500000 ///
		pct_constrained_1m = liq_constrained_flat_1000000 ///
		pct_constrained_2m = liq_constrained_flat_2000000 ///
		pct_constrained_5m = liq_constrained_flat_5000000 ///
		(sum) num_constrained_250k = liq_constrained_flat_250000 ///
		num_constrained_500k = liq_constrained_flat_500000 ///
		num_constrained_1m = liq_constrained_flat_1000000 ///
		num_constrained_2m = liq_constrained_flat_2000000 ///
		num_constrained_5m = liq_constrained_flat_5000000 [pw=xs_pers]
		foreach var of varlist num_constrained_* {
			replace `var' = `var'/1000
		}
		if `def' == 1 {
			export excel "$output\analysis.xlsx", sheet("Liquidity con 5per, flat", modify) firstrow(var) cell(A10)
		}
		if `def' == 2 | `def' == 3 {
			export excel "$output\analysis.xlsx", sheet("Liquidity con 5per, flat`def'", modify) firstrow(var) cell(A10)
		}
	restore

	*Number of taxpayers total
	preserve
		collapse (sum) num_taxpayers_250k = taxpayer_250000 ///
		num_taxpayers_500k = taxpayer_500000 ///
		num_taxpayers_1m = taxpayer_1000000 ///
		num_taxpayers_2m = taxpayer_2000000 ///
		num_taxpayers_5m = taxpayer_5000000 [pw=xs_pers]
		foreach var of varlist num_tax* {
			replace `var' = `var'/1000
		}
		if `def' == 1 {
			export excel "$output\analysis.xlsx", sheet("Liquidity con 5per, flat", modify) firstrow(var) cell(A13)
		}
		if `def' == 2 | `def' == 3 {
			export excel "$output\analysis.xlsx", sheet("Liquidity con 5per, flat`def'", modify) firstrow(var) cell(A13)
		}
	restore

	*Export tax rates
	preserve
		collapse (max) rate_250000 rate_500000 rate_1000000 rate_2000000 rate_5000000 
		if `def' == 1 {
			export excel "$output\analysis.xlsx", sheet("Liquidity con 5per, flat", modify) firstrow(var) cell(A16)
		}
		if `def' ==2 | `def' == 3 {
			export excel "$output\analysis.xlsx", sheet("Liquidity con 5per, flat`def'", modify) firstrow(var) cell(A16)
		}
	restore

	drop liq_con* crit*  rate_* immediate_tax*
}

drop taxpayer_1 taxpayer_2 

****************************************
* Liquidity analysis for an annual tax *
****************************************

*Generate immediate tax liability under different thresholds and define taxpaying population (tax supposed to pay - no avoidance) 
foreach flat_threshold in $thresholds {
	*Rates for annual flat tax - target £10bn
		if `flat_threshold' == 250000 local rate = $frate_an_250
		if `flat_threshold' == 500000 local rate = $frate_an_500
		if `flat_threshold' == 1000000 local rate = $frate_an_1m
		if `flat_threshold' == 2000000 local rate = $frate_an_2m
		if `flat_threshold' == 5000000 local rate = $frate_an_5m
		if `flat_threshold' == 10000000 local rate = $frate_an_10m

	*Immediate tax liability
	g immediate_tax_`flat_threshold' = (immediately_taxable_wealth - `flat_threshold')*`rate' if immediately_taxable_wealth > `flat_threshold'
	replace immediate_tax_`flat_threshold' = 0 if taxpayer_`flat_threshold' == 1 & immediately_taxable_wealth < `flat_threshold' // if only taxed on pension wealth

	*Indicator for whether has an immediate tax liability
	g have_cash2pay_`flat_threshold' = (immediate_tax_`flat_threshold' > 0) if taxpayer_`flat_threshold' == 1

	*Tax rate
	g rate_`flat_threshold' = `rate' if taxpayer_`flat_threshold' == 1
}

*Generate immediate tax liability under progressive taxes (tax supposed to pay - no avoidance)
foreach rates in 1 2{

	local oneoff = 0

	if `rates' == 1 scalar rate_500k = 0
	if `rates' == 1 scalar rate_1m = $prate_an_1m
	if `rates' == 1 scalar rate_2m = $prate_an_2m
	if `rates' == 1 scalar rate_5m = $prate_an_5m
	if `rates' == 1 scalar rate_10m = $prate_an_10m

	if `rates' == 2 scalar rate_500k = 0
	if `rates' == 2 scalar rate_1m = $prate_an_1m
	if `rates' == 2 scalar rate_2m = $prate_an_2m
	if `rates' == 2 scalar rate_5m = $prate_an_5m
	if `rates' == 2 scalar rate_10m = $prate_an_10m

	*Tax due on wealth between £500k and £1m
	if `rates' == 1 {
	g tax_due_500k = 0
	}
	if `rates' == 2 {
	g tax_due_500k = .
	replace tax_due_500k = 0 if immediately_taxable_wealth < 500000
	replace tax_due_500k = (immediately_taxable_wealth - 500000)*rate_500k if immediately_taxable_wealth >= 500000
	replace tax_due_500k = 500000*rate_500k if immediately_taxable_wealth > 1000000
	}
	*Tax due on wealth between £1m and £2m
	g tax_due_1m = .
	replace tax_due_1m = 0 if immediately_taxable_wealth < 1000000
	replace tax_due_1m = (immediately_taxable_wealth - 1000000)*rate_1m if immediately_taxable_wealth >= 1000000
	replace tax_due_1m = 1000000*rate_1m if immediately_taxable_wealth > 2000000
	*Tax due on wealth between £2m and £5m
	g tax_due_2m = .
	replace tax_due_2m = 0 if immediately_taxable_wealth < 2000000
	replace tax_due_2m = (immediately_taxable_wealth - 2000000)*rate_2m if immediately_taxable_wealth >= 2000000
	replace tax_due_2m = 3000000*rate_2m if immediately_taxable_wealth > 5000000
	*Tax due on wealth between £5m and £10m
	g tax_due_5m = .
	replace tax_due_5m = 0 if immediately_taxable_wealth < 5000000
	replace tax_due_5m = (immediately_taxable_wealth - 5000000)*rate_5m if immediately_taxable_wealth >= 5000000
	replace tax_due_5m = 5000000*rate_5m if immediately_taxable_wealth > 10000000
	*Tax due on wealth above £10m
	g tax_due_10m = .
	replace tax_due_10m = 0 if immediately_taxable_wealth < 10000000
	replace tax_due_10m = (immediately_taxable_wealth - 10000000)*rate_10m if immediately_taxable_wealth >= 10000000

	*Immediate tax due
	g immediate_tax_`rates' = tax_due_500k + tax_due_1m + tax_due_2m + tax_due_5m + tax_due_10m
	if `rates' == 1 {
		*Whether a taxpayer
		g taxpayer_`rates' = taxpayer_1000000 
		*Tax rate
		replace immediate_tax_`rates' = 0 if taxpayer_`rates' == 1 & immediately_taxable_wealth < 1000000 // if only taxed on pension wealth
	}
	if `rates' == 2 {
		*Whether a taxpayer
		g taxpayer_`rates' = taxpayer_500000 
		*Tax rate
		replace immediate_tax_`rates' = 0 if taxpayer_`rates' == 1 & immediately_taxable_wealth < 500000 // if only taxed on pension wealth
	}

	if `oneoff' == 1 replace immediate_tax_`rates' = immediate_tax_`rates'/5

	drop tax_due_*
}

foreach def in 3 2 1 {
	if `def' == 1 {
		global c1 0.2 //criteria 1: if tax > x% of net income (MAIN SPEC = 0.2, 20%)
		global c2 0.1 //criteria 2: if tax > x% of net income plus liquid wealth (MAIN SPEC = 0.1, 10%)
	}
	if `def' == 2 {
		global c1 0.4
		global c2 0.2
	}
	if `def' == 3 {
		global c1 0.1
		global c2 0.05
	}
	*Generate whether liquidity constrained under different flat taxes
	foreach flat_threshold in $thresholds { 
		*First criteria
		g criteria1_`flat_threshold' = ((immediate_tax_`flat_threshold'/${incvar}) > $c1) if taxpayer_`flat_threshold' == 1 & !missing($incvar)
		replace criteria1_`flat_threshold' = 0 if immediate_tax_`flat_threshold' == 0 //otherwise set to 1 when income = 0

		*Second criteria
		g criteria2_`flat_threshold' = ((immediate_tax_`flat_threshold'/(${incvar} + liquid_wealth)) > $c2) if taxpayer_`flat_threshold' == 1 & !missing(${incvar}) & !missing(liquid_wealth)
		replace criteria2_`flat_threshold' = 0 if immediate_tax_`flat_threshold' == 0 
		*Indicator for whether liquidity constrained (both criteria met)
		g liq_constrained_flat_`flat_threshold' = (criteria1_`flat_threshold' == 1 & criteria2_`flat_threshold' == 1) if taxpayer_`flat_threshold' == 1 & !missing(criteria1_`flat_threshold') & !missing(criteria2_`flat_threshold')
	}


	*Generate whether liquidity constrained under different progressive taxes
	foreach rates in 1 2 {
		*First criteria
		g criteria1_`rates' = ((immediate_tax_`rates'/${incvar}) > $c1) if taxpayer_`rates' == 1 & !missing(${incvar})
		replace criteria1_`rates' = 0 if immediate_tax_`rates' == 0
		*Second criteria
		g criteria2_`rates' = ((immediate_tax_`rates'/(${incvar} + liquid_wealth)) > $c2) if taxpayer_`rates' == 1 & !missing(${incvar}) & !missing(liquid_wealth)
		replace criteria2_`rates' = 0 if immediate_tax_`rates' == 0
		*Indicator for whether liquidity constrained (both critera met)
		g liq_constrained_prog_`rates' = (criteria1_`rates' == 1 & criteria2_`rates' == 1)  if taxpayer_`rates' == 1 & !missing(criteria1_`rates') & !missing(criteria2_`rates')
	}


	*Percent and number of taxpayers liquidity constrained by band - flat tax here
	preserve 
		collapse (mean) pct_constrained_250k = liq_constrained_flat_250000 ///
		pct_constrained_500k = liq_constrained_flat_500000 ///
		pct_constrained_1m = liq_constrained_flat_1000000 ///
		pct_constrained_2m = liq_constrained_flat_2000000 ///
		pct_constrained_5m = liq_constrained_flat_5000000 ///
		(sum) num_constrained_250k = liq_constrained_flat_250000 ///
		num_constrained_500k = liq_constrained_flat_500000 ///
		num_constrained_1m = liq_constrained_flat_1000000 ///
		num_constrained_2m = liq_constrained_flat_2000000 ///
		num_constrained_5m = liq_constrained_flat_5000000 [pw=xs_pers], by(band_lb)
		foreach var of varlist num_constrained_* {
			replace `var' = `var'/1000
		}
		if `def' == 1 {
			export excel "$output\analysis.xlsx", sheet("Liquidity constrained, flat, an", modify) firstrow(var) cell(A2)
		}
		if `def' == 2 | `def' == 3 {
			export excel "$output\analysis.xlsx", sheet("Liquidity con, flat, an`def'", modify) firstrow(var) cell(A2)
		}
	restore

	*Percent and number of taxpayers liquidity constrained of all taxpayers - flat tax
	preserve 
		collapse (mean) pct_constrained_250k = liq_constrained_flat_250000 ///
		pct_constrained_500k = liq_constrained_flat_500000 ///
		pct_constrained_1m = liq_constrained_flat_1000000 ///
		pct_constrained_2m = liq_constrained_flat_2000000 ///
		pct_constrained_5m = liq_constrained_flat_5000000 ///
		(sum) num_constrained_250k = liq_constrained_flat_250000 ///
		num_constrained_500k = liq_constrained_flat_500000 ///
		num_constrained_1m = liq_constrained_flat_1000000 ///
		num_constrained_2m = liq_constrained_flat_2000000 ///
		num_constrained_5m = liq_constrained_flat_5000000 [pw=xs_pers]
		foreach var of varlist num_constrained_* {
			replace `var' = `var'/1000
		}
		if `def' == 1 {
			export excel "$output\analysis.xlsx", sheet("Liquidity constrained, flat, an", modify) firstrow(var) cell(A10)
		}
		if `def' == 2 | `def' == 3 {
			export excel "$output\analysis.xlsx", sheet("Liquidity con, flat, an`def'", modify) firstrow(var) cell(A10)
		}
	restore

	if `def' == 1 {
	*Percent and number of taxpayers liquidity constrained by band - progressive tax
	preserve
		collapse (mean) pct_constrained_1 = liq_constrained_prog_1 ///
		pct_constrained_2 = liq_constrained_prog_2 (sum) ///
		num_constrained_1 = liq_constrained_prog_1 ///
		num_constrained_2 = liq_constrained_prog_2 [pw=xs_pers], by(band_lb)
		foreach var of varlist num_constrained_* {
			replace `var' = `var'/1000
		}
		export excel "$output\analysis.xlsx", sheet ("Liquidity constrained, prog, an", modify) firstrow(var) cell(A2)
	restore

	*Percent and number of taxpayers liquidity constrained of all taxpayers - progressive tax
	preserve
		collapse (mean) pct_constrained_1 = liq_constrained_prog_1 ///
		pct_constrained_2 = liq_constrained_prog_2 (sum) ///
		num_constrained_1 = liq_constrained_prog_1 ///
		num_constrained_2 = liq_constrained_prog_2 [pw=xs_pers]
		foreach var of varlist num_constrained_* {
			replace `var' = `var'/1000
		}
		export excel "$output\analysis.xlsx", sheet ("Liquidity constrained, prog, an", modify) firstrow(var) cell(A10)
	restore
	}

	*Number of taxpayers total
	preserve
		collapse (sum) num_taxpayers_250k = taxpayer_250000 ///
		num_taxpayers_500k = taxpayer_500000 ///
		num_taxpayers_1m = taxpayer_1000000 ///
		num_taxpayers_2m = taxpayer_2000000 ///
		num_taxpayers_5m = taxpayer_5000000 [pw=xs_pers]
		foreach var of varlist num_taxpa* {
			replace `var' = `var'/1000
		}
		if `def' == 1 {
			export excel "$output\analysis.xlsx", sheet("Liquidity constrained, flat, an", modify) firstrow(var) cell(A13)
			export excel "$output\analysis.xlsx", sheet("Have cash to pay, flat, an", modify) firstrow(var) cell(A13)
		} 
		if `def' == 2 | `def' == 3 {
			export excel "$output\analysis.xlsx", sheet("Liquidity con, flat, an`def'", modify) firstrow(var) cell(A13)
		}
	restore

	*Export tax rates
	preserve
		collapse (max) rate_250000 rate_500000 rate_1000000 rate_2000000 rate_5000000 
		if `def' == 1 {
			export excel "$output\analysis.xlsx", sheet("Liquidity constrained, flat, an", modify) firstrow(var) cell(A16)
		}
		if `def' == 2 | `def' == 3 {
			export excel "$output\analysis.xlsx", sheet("Liquidity con, flat, an`def'", modify) firstrow(var) cell(A16)
		}
	restore

	if `def' == 1 {
		*Percent and number of taxpayers that have cash to pay (tax due on non-pension wealth), by band - flat tax
		preserve
			collapse (mean) pct_cash2pay_250k = have_cash2pay_250000 pct_cash2pay_500k = have_cash2pay_500000 pct_cash2pay_1m = have_cash2pay_1000000 pct_cash2pay_2m = have_cash2pay_2000000 pct_cash2pay_5m = have_cash2pay_5000000 (sum) num_cash2pay_250k = have_cash2pay_250000 num_cash2pay_500k = have_cash2pay_500000 num_cash2pay_1m = have_cash2pay_1000000 num_cash2pay_2m = have_cash2pay_2000000 num_cash2pay_5m = have_cash2pay_5000000 [pw=xs_pers], by(band_lb)
			export excel "$output\analysis.xlsx", sheet("Have cash to pay, flat, an", modify) firstrow(var) cell(A2)
		restore

		*Percent and number of taxpayers that have cash to pay (tax due on non-pension wealth) of all taxpayers - flat tax
		preserve
			collapse (mean) pct_cash2pay_250k = have_cash2pay_250000 pct_cash2pay_500k = have_cash2pay_500000 pct_cash2pay_1m = have_cash2pay_1000000 pct_cash2pay_2m = have_cash2pay_2000000 pct_cash2pay_5m = have_cash2pay_5000000 (sum) num_cash2pay_250k = have_cash2pay_250000 num_cash2pay_500k = have_cash2pay_500000 num_cash2pay_1m = have_cash2pay_1000000 num_cash2pay_2m = have_cash2pay_2000000 num_cash2pay_5m = have_cash2pay_5000000 [pw=xs_pers]
			export excel "$output\analysis.xlsx", sheet("Have cash to pay, flat, an", modify) firstrow(var) cell(A10)
		restore
	}

	if `def' == 2 | `def' == 3 {
		drop liq_const* crit*
	}
}


****************
*MAIN SPEC ONLY*
****************

*Of those liquidity constrained, what is their largest asset? 

*Liquidity constrained by main asset - flat threshold
foreach flat_threshold in $thresholds {
	preserve
	keep if liq_constrained_flat_`flat_threshold' == 1
	g ones = 1
	collapse (sum) ones [pw=xs_pers], by(mainasset)
	export excel "$output\analysis.xlsx", sheet("Comp of liq con, `flat_threshold', an", modify) firstrow(var) cell(A2)
	restore
	preserve
	keep if liq_constrained_flat_`flat_threshold' == 1
	g ones = 1
	collapse (sum) ones [pw=xs_pers]
	export excel "$output\analysis.xlsx", sheet("Comp of liq con, `flat_threshold', an", modify) firstrow(var) cell(A12)
	restore
}

*Liquidity constrained by main asset - progressive
foreach rates in 1 2 {
	preserve
	keep if liq_constrained_prog_`rates' == 1
	g ones = 1
	collapse (sum) ones [pw=xs_pers], by(mainasset)
	export excel "$output\analysis.xlsx", sheet("Comp of liq con, prog`rates', an", modify) firstrow(var) cell(A2)
	restore
	preserve
	keep if liq_constrained_prog_`rates' == 1
	g ones = 1
	collapse (sum) ones [pw=xs_pers]
	export excel "$output\analysis.xlsx", sheet("Comp of liq con, prog`rates', an", modify) firstrow(var) cell(A12)
	restore
}

drop taxpayer_1 taxpayer_2 immediate_tax*  liq_con* crit* have* rate_*

*Generate immediate tax liability for alternative revenue targets
foreach target in 20 30 {
	foreach flat_threshold in $thresholds {

		*Rates for one off flat tax (annualised) - target £250bn before admin costs (after evasion)
		if `target' == 20 {
			if `flat_threshold' == 250000 local rate = 0.0023
			if `flat_threshold' == 500000 local rate = 0.0035
			if `flat_threshold' == 1000000 local rate = 0.0064
			if `flat_threshold' == 2000000 local rate = 0.0120
			if `flat_threshold' == 5000000 local rate = 0.0196
		}
		if `target' == 30 {
			if `flat_threshold' == 250000 local rate = 0.003548
			if `flat_threshold' == 500000 local rate = 0.005336
			if `flat_threshold' == 1000000 local rate = 0.009856
			if `flat_threshold' == 2000000 local rate = 0.019007
			if `flat_threshold' == 5000000 local rate = 0.033079
		}
		*Immediate tax liability
		g immediate_tax_`flat_threshold' = (immediately_taxable_wealth - `flat_threshold')*`rate' if immediately_taxable_wealth > `flat_threshold'
		replace immediate_tax_`flat_threshold' = 0 if taxpayer_`flat_threshold' == 1 & immediately_taxable_wealth < `flat_threshold' // if only taxed on pension wealth
		
		*Generate whether liquidity constrained under different flat taxes		
		*First criteria: immediate tax > 20% net income
		g criteria1_`flat_threshold' = ((immediate_tax_`flat_threshold'/${incvar}) > $c1) if taxpayer_`flat_threshold' == 1 & !missing($incvar)
		replace criteria1_`flat_threshold' = 0 if immediate_tax_`flat_threshold' == 0 //otherwise set to 1 when income = 0

		*Second criteria: immediate tax > 10% net income plus liquid wealth
		g criteria2_`flat_threshold' = ((immediate_tax_`flat_threshold'/(${incvar} + liquid_wealth)) > $c2) if taxpayer_`flat_threshold' == 1 & !missing(${incvar}) & !missing(liquid_wealth)
		replace criteria2_`flat_threshold' = 0 if immediate_tax_`flat_threshold' == 0 
		*Indicator for whether liquidity constrained (both criteria met)
		g liq_constrained_flat_`flat_threshold' = (criteria1_`flat_threshold' == 1 & criteria2_`flat_threshold' == 1) if taxpayer_`flat_threshold' == 1 & !missing(criteria1_`flat_threshold') & !missing(criteria2_`flat_threshold')
		*Tax rate
		g rate_`flat_threshold' = `rate'
	}

	*Percent and number of taxpayers liquidity constrained by band - flat tax
		preserve 
			collapse (mean) pct_constrained_250k = liq_constrained_flat_250000 ///
			pct_constrained_500k = liq_constrained_flat_500000 ///
			pct_constrained_1m = liq_constrained_flat_1000000 ///
			pct_constrained_2m = liq_constrained_flat_2000000 ///
			pct_constrained_5m = liq_constrained_flat_5000000 ///
			(sum) num_constrained_250k = liq_constrained_flat_250000 ///
			num_constrained_500k = liq_constrained_flat_500000 ///
			num_constrained_1m = liq_constrained_flat_1000000 ///
			num_constrained_2m = liq_constrained_flat_2000000 ///
			num_constrained_5m = liq_constrained_flat_5000000 [pw=xs_pers], by(band_lb)
			foreach var of varlist num_constrained_* {
				replace `var' = `var'/1000
			}
			export excel "$output\analysis.xlsx", sheet("Liquidity con, flat `target', an", modify) firstrow(var) cell(A2)
		restore

		*Percent and number of taxpayers liquidity constrained of all taxpayers - flat tax
		preserve 
			collapse (mean) pct_constrained_250k = liq_constrained_flat_250000 ///
			 pct_constrained_500k = liq_constrained_flat_500000 ///
			 pct_constrained_1m = liq_constrained_flat_1000000 ///
			 pct_constrained_2m = liq_constrained_flat_2000000 ///
			 pct_constrained_5m = liq_constrained_flat_5000000 ///
			 (sum) num_constrained_250k = liq_constrained_flat_250000 ///
			 num_constrained_500k = liq_constrained_flat_500000 ///
			 num_constrained_1m = liq_constrained_flat_1000000 ///
			 num_constrained_2m = liq_constrained_flat_2000000 ///
			 num_constrained_5m = liq_constrained_flat_5000000 [pw=xs_pers]
			foreach var of varlist num_constrained_* {
				replace `var' = `var'/1000
			}
			export excel "$output\analysis.xlsx", sheet("Liquidity con, flat `target', an", modify) firstrow(var) cell(A10)
		restore
		*Number of taxpayers total
		preserve
			collapse (sum) num_taxpayers_250k = taxpayer_250000 ///
			num_taxpayers_500k = taxpayer_500000 ///
			num_taxpayers_1m = taxpayer_1000000 ///
			num_taxpayers_2m = taxpayer_2000000 ///
			num_taxpayers_5m = taxpayer_5000000 [pw=xs_pers]
			foreach var of varlist num_tax* {
				replace `var' = `var'/1000
			}			
			export excel "$output\analysis.xlsx", sheet("Liquidity con, flat `target', an", modify) firstrow(var) cell(A13)
		restore
		*Export tax rates
		preserve
			collapse (mean) rate_250000 rate_500000 rate_1000000 rate_2000000 rate_5000000
			export excel "$output\analysis.xlsx", sheet("Liquidity con, flat `target', an", modify) firstrow(var) cell(A16)
		restore

		drop  immediate_tax* criteria* liq_con* rate_*
}


