/*******************************************************************************
Description:		Wealth tax modelling: who pays and how much

Uses: data for analysis defined in step 3.define_sample.do (sample_for_analysis.dta)
*******************************************************************************/

use "$tempdata\sample_for_analysis.dta", clear //restore data to include STRL

foreach flat_threshold in $thresholds {
	*Whether a taxpayer under given threshold
	g taxpayer_`flat_threshold' = (rf_totwlth_ch_pareto > `flat_threshold') 
}

*************************************************
*Total wealth among different groups of taxpayers
*************************************************
foreach flat_threshold in $thresholds {
	*Total wealth among taxpayers
	g taxable_`flat_threshold' = rf_totwlth_ch_pareto if taxpayer_`flat_threshold' == 1
}
preserve
foreach flat_threshold in $thresholds {
	replace taxable_`flat_threshold' = taxable_`flat_threshold'/1e9
}
collapse (sum) taxable_250000 taxable_500000 taxable_1000000 taxable_2000000 taxable_5000000 [pw=xs_pers]
export excel using "$output\analysis.xlsx", sheet("Tax base", modify) firstrow(var) cell(A2)
restore


********************
*** WHO PAYS ? *****
********************

*Tax paid by representative individuals
*Identify those within 10% of a given wealth threshold
foreach min in 750000 1500000 3000000 7500000 15000000 {
g within10pct_`min' = (abs(`min' - rf_totwlth_ch_pareto) < 0.1*`min')
}

*Number of individuals within 10% of representative wealth thresholds, and annual tax rates
preserve
collapse (sum) within10pct* [pweight = xs_pers]
g frate_an_250 = $frate_an_250
g frate_an_500 = $frate_an_500
g frate_an_1m = $frate_an_1m
g frate_an_2m = $frate_an_2m
g frate_an_5m = $frate_an_5m
g frate_an_10m = $frate_an_10m
g prate_an_1m = $prate_an_1m
g prate_an_2m = $prate_an_2m
g prate_an_5m = $prate_an_5m
g prate_an_10m = $prate_an_10m
format %12.0g *
export excel using "$output\representative_individuals.xlsx", sheet("Annual", modify) firstrow(variables) 
restore

*Number of individuals within 10% of representative wealth thresholds, and one-off tax rates
preserve
collapse (sum) within10pct* [pweight = xs_pers]
g prate_one_500 = $prate_one_500/5
g prate_one_1m = $prate_one_1m/5
g prate_one_2m = $prate_one_2m/5
g prate_one_5m = $prate_one_5m/5
g prate_one_10m = $prate_one_10m/5
g prate2_one_500 = $prate2_one_500/5
g prate2_one_1m = $prate2_one_1m/5
g prate2_one_2m = $prate2_one_2m/5
g prate2_one_5m = $prate2_one_5m/5
g prate2_one_10m = $prate2_one_10m/5
g frate_one_500 = $frate_one_500/5
format %12.0g *
export excel using "$output\representative_individuals.xlsx", sheet("Oneoff", modify) firstrow(variables) 
restore


*Redefine agegroups
g age_analysis = agegroup
replace age_analysis = 1 if agegroup_detail <= 4
lab define age_analysis 1 "Under 19" 2 "19-24" 3 "25-34" 4 "35-44" 5 "45-54" 6 "55-64" 7 "65-74" 8 "75+"
lab values age_analysis age_analysis


*Number of taxpayers by age
preserve
g ones = 1
collapse (sum) Ntaxpayers_250k = taxpayer_250000 Ntaxpayers_500k = taxpayer_500000 Ntaxpayers_1m = taxpayer_1000000 Ntaxpayers_2m = taxpayer_2000000 Ntaxpayers_5m = taxpayer_5000000 population = ones [pw=xs_pers], by(age_analysis)
export excel using "$output\analysis.xlsx", firstrow(variables) sheet("Who pays by age", modify) cell(A2)
restore


*Number of taxpayers by region
preserve
collapse (sum) taxpayer_250000 taxpayer_500000 taxpayer_1000000 taxpayer_2000000 taxpayer_5000000  [pw=xs_pers], by(gor)
drop if missing(gor)
foreach flat_threshold in 250000 500000 1000000 2000000 5000000 { 
	egen total_`flat_threshold' = sum(taxpayer_`flat_threshold')
	g double share_`flat_threshold' = taxpayer_`flat_threshold'/total_`flat_threshold'
	drop total_`flat_threshold'
	drop taxpayer_`flat_threshold'
}

*Relabel regions to be consistent with R shapefile (for map)
lab define region 1 "North East (England)" 2  "North West (England)" 4 "Yorkshire and The Humber" 5 "East Midlands (England)" 6 "West Midlands (England)" 7 "East of England" 8 "London" 9 "South East (England)" 10 "South West (England)" 11 "Wales" 12 "Scotland" 
rename gor region
lab values region region
export delimited using "$output\geographic_distribution.csv",  replace //data used for producing map in R
restore


*Number of taxpayers by sex
preserve
g ones = 1
collapse (sum) Ntaxpayers_250k = taxpayer_250000 Ntaxpayers_500k = taxpayer_500000 Ntaxpayers_1m = taxpayer_1000000 Ntaxpayers_2m = taxpayer_2000000 Ntaxpayers_5m = taxpayer_5000000 population = ones [pw=xs_pers], by(sex)
export excel using "$output\analysis.xlsx", firstrow(variables) sheet("Who pays by sex", modify) cell(A2)
restore

*Number of people in each net income group by age
g incgroup_0 = (ind_netinc < 20000)
g incgroup_20000 = (ind_netinc >= 20000 & ind_netinc < 40000)
g incgroup_40000 = (ind_netinc >= 40000 & ind_netinc < 60000)
g incgroup_60000 = (ind_netinc >= 60000 & ind_netinc < 80000)
g incgroup_80000 = (ind_netinc >= 80000 & ind_netinc < 150000)
g incgroup_150000 = (ind_netinc >= 150000 & ind_netinc !=. )
preserve
g ones = 1
collapse (sum) incgroup_0 incgroup_20000 incgroup_40000 incgroup_60000 incgroup_80000 incgroup_150000 population = ones [pw=xs_pers], by(age_analysis)
export excel using "$output\analysis.xlsx", firstrow(var) sheet("Income by age", modify) cell(A2)
export excel using "$output\compare_with_spi.xlsx", firstrow(var) sheet("WAS", modify) cell(A2)
restore


********************
*** HOW MUCH PAID?**
********************


drop if age_analysis == 1 //drop under 19s (unable to just drop under 18s due to how ages are grouped)

*Percentiles
*Add some random noise so that can put people around zero into even bins
g wealth_noisy = rf_totwlth_pareto + ((runiform()-0.5)/1E2) //base percentiles on market wealth rather than chargeable wealth
xtile wth_pctle = wealth_noisy [pweight = xs_pers], n(100)

*Break down top 1%
xtile wth_pctle_top1 = wealth_noisy [pweight = xs_pers], n(1000)

*Generate net income variable that preserves the ratio between income and unadjusted wealth
g ind_netinc_adj = ind_netinc*rf_totwlth_ch_pareto/rf_totwlth_ch
replace ind_netinc_adj = max(0,ind_netinc_adj) if !missing(ind_netinc_adj) //censor few negatives

*Choose income variable ind_netinc or ind_netinc_adj
global incvar ind_netinc_adj

*Income percentiles
g inc_noisy = $incvar + ((runiform()-0.5/1E2))
xtile inc_pctle = inc_noisy [pw=xs_pers], n(100)

************************************
* How much paid? annual wealth tax *
************************************

*Flat tax rates
foreach flat_threshold in $thresholds {
	if `flat_threshold' == 250000 local rate = $frate_an_250
	if `flat_threshold' == 500000 local rate = $frate_an_500
	if `flat_threshold' == 1000000 local rate = $frate_an_1m
	if `flat_threshold' == 2000000 local rate = $frate_an_2m
	if `flat_threshold' == 5000000 local rate = $frate_an_5m
	if `flat_threshold' == 10000000 local rate = $frate_an_10m
*Tax due 
g taxdue_`flat_threshold' = (rf_totwlth_ch_pareto - `flat_threshold')*`rate' if taxpayer_`flat_threshold' == 1
replace taxdue_`flat_threshold' = 0 if taxpayer_`flat_threshold' != 1 

*Average tax rate
g atr_`flat_threshold' = taxdue_`flat_threshold'/rf_totwlth_pareto //tax divided by market value wealth
replace atr_`flat_threshold' = 0 if taxdue_`flat_threshold' == 0

}

*Progressive tax rates
foreach rates in  2 {
	if `rates' == 2 local rate_500k = 0
	if `rates' == 2 local rate_1m = $prate_an_1m
	if `rates' == 2 local rate_2m = $prate_an_2m
	if `rates' == 2 local rate_5m = $prate_an_5m
	if `rates' == 2 local rate_10m = $prate_an_10m
 
*Tax due
g taxdue_500k = (wealth - 500000)*`rate_500k' if wealth >= 500000 & wealth < 1000000
g taxdue_1m = (wealth - 1000000)*`rate_1m' + 500000*`rate_500k' if wealth >= 1000000 & wealth < 2000000
g taxdue_2m = (wealth - 2000000)*`rate_2m' + 1000000*`rate_1m' + 500000*`rate_500k' if wealth >= 2000000 & wealth < 5000000
g taxdue_5m = (wealth - 5000000)*`rate_5m' + 3000000*`rate_2m' + 1000000*`rate_1m' + 500000*`rate_500k' if wealth >= 5000000 & wealth < 10000000
g taxdue_10m = (wealth - 10000000)*`rate_10m' + 5000000*`rate_5m' + 3000000*`rate_2m' + 1000000*`rate_1m' + 500000*`rate_500k' if wealth >= 10000000
recode taxdue* (.=0)
g taxdue_`rates' = taxdue_500k + taxdue_1m + taxdue_2m + taxdue_5m + taxdue_10m

*Average tax rate
g atr_`rates' = taxdue_`rates'/rf_totwlth_pareto
replace atr_`rates' = 0 if taxdue_`rates' == 0

}

*Mean average tax rate by wealth percentile
preserve
collapse (mean) atr_* [pw=xs_pers], by(wth_pctle)
export excel "$output\analysis.xlsx", sheet("Mean ATR by wealth, an", modify) cell(A2) firstrow(var)
restore

*Expanded top percentiles
preserve
keep if wth_pctle == 100
collapse (mean) atr_* [pw=xs_pers], by(wth_pctle_top1)
export excel "$output\analysis.xlsx", sheet("Mean ATR by wealth, an", modify) cell(AA2) firstrow(var)
restore

*Share of taxpayers by income percentile 
preserve 
collapse (mean) taxpayer_* [pw=xs_pers], by(inc_pctle) 
export excel "$output\analysis.xlsx", sheet("Share taxpayer by income", modify) cell(A2) firstrow(var)
restore

drop atr_* taxdue_*

*************************************
* How much paid? One off wealth tax *
*************************************

foreach flat_threshold in $thresholds {
	*Rates for one off flat tax (annualised) - target £250bn
	if `flat_threshold' == 250000 local rate = $frate_one_250/5
	if `flat_threshold' == 500000 local rate = $frate_one_500/5
	if `flat_threshold' == 1000000 local rate = $frate_one_1m/5
	if `flat_threshold' == 2000000 local rate = $frate_one_2m/5
	if `flat_threshold' == 5000000 local rate = $frate_one_5m/5
	if `flat_threshold' == 10000000 local rate = $frate_one_10m/5
	*Tax due
	g taxdue_`flat_threshold' = (rf_totwlth_ch_pareto - `flat_threshold')*`rate' if taxpayer_`flat_threshold' == 1
	replace taxdue_`flat_threshold' = 0 if taxpayer_`flat_threshold' != 1 
	*Average tax rate
	g atr_`flat_threshold' = taxdue_`flat_threshold'/rf_totwlth_pareto //tax divided by market value wealth
	replace atr_`flat_threshold' = 0 if taxdue_`flat_threshold' == 0
}

*Mean average tax rate by wealth percentile
preserve
collapse (mean) atr_* [pw=xs_pers], by(wth_pctle)
export excel "$output\analysis.xlsx", sheet("Mean ATR by wealth, one", modify) cell(A2) firstrow(var)
restore

*Expanded top percentiles
preserve
keep if wth_pctle == 100
collapse (mean) atr_* [pw=xs_pers], by(wth_pctle_top1)
export excel "$output\analysis.xlsx", sheet("Mean ATR by wealth, one", modify) cell(AA2) firstrow(var)
restore


