/*******************************************************************************
Description:		Wealth tax modelling: valuation cost analysis

Uses: data for analysis defined in step 3.define_sample.do (sample_for_analysis.dta)
*******************************************************************************/

****************
*VALUATION COST*
****************

use "$tempdata\sample_for_analysis.dta", clear //keep this here

*Buckets of wealth - using market wealth (rf_totwlth_pareto), not chargeable wealth (rf_totwlth_ch_pareto)
egen buckets = cut(rf_totwlth_pareto), at(0, 250000, 500000, 1000000, 2000000, 5000000, 10000000)
replace buckets = 10000000 if (rf_totwlth_pareto >= 10000000 & rf_totwlth_pareto ~= .)

g count = 1

*Need vehicles marketable wealth for some analysis below:
g rf_vehicles = rf_carvehicles + rf_othvehicles


*Define post-pareto chargeable shares wealth
g rf_shares_ch_pareto = rf_shares_pareto
replace rf_shares_ch_pareto = 0 if rf_shares_pareto < 3000

*Allocate assets to categories of easy/mid/hard to value

*Easy: financial wealth (savings, listed shares & other securities, pensions)
*This includes the share of Pareto adjustment that's attributable to shares (WAS rich only)
*Add in vehicles & numberplates > £3k
*Include only non-DB pensions
g easy_orig = rf_fin_net_ch_pareto + rf_non_db_ch + rf_vehicles_ch + rf_pnumberplate_ch 


*Mid: residential & commercial property; exclude land assets 
*Includes DB pensions
g mid = rf_prop_net_ch - rf_dvlukvalr6_sum_ch - rf_dvlosvalr6_sum_ch + rf_db_pensions_ch

*Hard: shares in private companies, intellectual and other intangible property, unincorporated businesses, land that has ‘hope value’ for development (assume this is DVLUKValW6 (Total value of UK land) & DVLOSValW6 (Total value of overseas land)), and thinly-traded collectibles such as fine art 
g hard_orig = rf_businessassets_ch_pareto + rf_collectnvaluables_ch + rf_dvlukvalr6_sum_ch + rf_dvlosvalr6_sum_ch 



*Exclude STRL

replace easy_orig = . if strl_flag == 1
replace mid = . if strl_flag == 1
replace hard_orig = . if strl_flag == 1

*Re-assign unlisted shares from easy to hard only if person owns only unlisted shares
replace easy_orig = easy_orig - rf_shares_ch_pareto if (own_unlisted_uk_shares == 1 & own_listed_uk_shares ~= 1)
replace hard_orig = hard_orig + rf_shares_ch_pareto if (own_unlisted_uk_shares == 1 & own_listed_uk_shares ~= 1)


*BASE CASE: 
g easy = easy_orig
g hard = hard_orig


*Table:
*Compare chargeable & marketable wealth
*De minimis 3k: What % of all taxpayers report value of one asset type < or > 3k? 
*Split shares: unlisted vs all
*Chargeable
g rf_unlist_shares_ch = rf_shares_ch_pareto if (own_unlisted_uk_shares == 1 & own_listed_uk_shares ~= 1)
replace rf_unlist_shares_ch = 0 if (rf_unlist_shares_ch == . & strl_flag != 1)
g rf_oth_shares_ch = rf_shares_ch_pareto - rf_unlist_shares_ch
*Marketable
g rf_unlist_shares = rf_shares_pareto if (own_unlisted_uk_shares == 1 & own_listed_uk_shares ~= 1)
replace rf_unlist_shares = 0 if (rf_unlist_shares == . & strl_flag != 1)
g rf_oth_shares = rf_shares_pareto - rf_unlist_shares

*Take out financial assets rf_fin_net_pareto rf_fin_net_ch_pareto as these include shares
*Take out shares & replace with unlisted/other shares
g fin_ex_sh = rf_fin_net_pareto - rf_shares_pareto
g fin_ex_sh_ch = rf_fin_net_ch_pareto - rf_shares_ch_pareto
foreach var in fin_ex_sh fin_ex_sh_ch rf_pen rf_pen_ch rf_vehicles rf_vehicles_ch rf_pnumberplate rf_pnumberplate_ch rf_prop_net rf_prop_net_ch rf_dvlukvalr6_sum rf_dvlukvalr6_sum_ch rf_dvlosvalr6_sum rf_dvlosvalr6_sum_ch rf_businessassets_pareto rf_businessassets_ch_pareto rf_collectnvaluables rf_collectnvaluables_ch rf_shares rf_shares_ch rf_db_pensions rf_db_pensions_ch rf_non_db rf_non_db_ch rf_unlist_shares rf_oth_shares {
	g flag_`var' = (`var' > 0 & `var' ~= .)
}

preserve 
drop if strl_flag == 1
collapse (sum) count flag_* [pweight = xs_pers]

export excel "$output\val_analysis.xlsx", sheet("ch_assets", modify) cell(A1) firstrow(var)

restore


*Add average wealth if > 3k
matrix ave_val = J(13,1,.)
local row = 0

*Take out financial assets rf_fin_net_pareto rf_fin_net_ch_pareto as these include shares
*Take out shares & replace with unlisted/other shares
foreach var in  fin_ex_sh rf_pen_ch rf_vehicles_ch rf_pnumberplate_ch rf_prop_net_ch rf_dvlukvalr6_sum_ch rf_dvlosvalr6_sum_ch rf_businessassets_ch_pareto rf_collectnvaluables_ch rf_oth_shares rf_db_pensions_ch rf_non_db_ch rf_unlist_shares {
    local row = `row' + 1
    sum `var' [weight = xs_pers] if (strl_flag ~= 1 & `var' > 0)
	matrix ave_val[`row',1] = r(mean)

} 

matlist ave_val


sum rf_businessassets_ch_pareto [weight = xs_pers] if (strl_flag ~= 1 & rf_businessassets_ch_pareto > 30000)


*Table:
*Distribution of business assets 
foreach min in 0 3000 10000 20000 50000 100000 250000 500000 1000000 2000000 5000000 10000000 {
	g over_`min' = (rf_businessassets_pareto > `min')

}

preserve
drop if strl_flag == 1
collapse (sum) over_* (sum) count [pweight = xs_pers]
format %12.0g *
export excel "$output\val_analysis.xlsx", sheet("bus_dist", modify) cell(A1) firstrow(var)
restore



*Table:
*How many easy/mid/hard?
drop flag_*
foreach type in easy mid hard {
	g flag_`type' = (`type' > 0 & `type' ~= .)
}


preserve 
drop if strl_flag == 1

collapse (sum) count flag_* total = rf_totwlth_pareto easy mid hard [pweight = xs_pers], by(buckets) 

export excel "$output\val_analysis.xlsx", sheet("emh", modify) cell(A1) firstrow(var)

restore


*Table:
*Main assets
g prop_no_land = rf_prop_net_ch - rf_dvlukvalr6_sum_ch - rf_dvlosvalr6_sum_ch 
g land = rf_dvlukvalr6_sum_ch + rf_dvlosvalr6_sum_ch 

egen maxvalue = rowmax(rf_db_pensions_ch rf_non_db_ch prop_no_land land rf_phys_ch rf_businessassets_ch_pareto rf_fin_net_ch_pareto) 

g mainasset = 1 if (prop_no_land == maxvalue & land ~= maxvalue & rf_db_pensions_ch ~= maxvalue & rf_non_db_ch ~= maxvalue & rf_phys_ch ~= maxvalue & rf_businessassets_ch_pareto ~= maxvalue & rf_fin_net_ch_pareto ~= maxvalue)
replace mainasset = 2 if (rf_fin_net_ch_pareto == maxvalue & rf_db_pensions_ch ~= maxvalue & rf_non_db_ch ~= maxvalue & prop_no_land ~= maxvalue & land ~= maxvalue & rf_phys_ch ~= maxvalue & rf_businessassets_ch_pareto ~= maxvalue)
replace mainasset = 3 if (rf_phys_ch == maxvalue & rf_db_pensions_ch ~= maxvalue & rf_non_db_ch ~= maxvalue & prop_no_land ~= maxvalue & land ~= maxvalue & rf_businessassets_ch_pareto ~= maxvalue & rf_fin_net_ch_pareto ~= maxvalue)
replace mainasset = 4 if (rf_businessassets_ch_pareto == maxvalue & rf_db_pensions_ch ~= maxvalue & rf_non_db_ch ~= maxvalue & prop_no_land ~= maxvalue & land ~= maxvalue & rf_phys_ch ~= maxvalue & rf_fin_net_ch_pareto ~= maxvalue)
replace mainasset = 5 if (rf_db_pensions_ch == maxvalue & rf_non_db_ch ~= maxvalue & prop_no_land ~= maxvalue & land ~= maxvalue & rf_phys_ch ~= maxvalue & rf_businessassets_ch_pareto ~= maxvalue & rf_fin_net_ch_pareto ~= maxvalue)
replace mainasset = 6 if (rf_non_db_ch == maxvalue & rf_db_pensions_ch & prop_no_land ~= maxvalue & land ~= maxvalue & rf_phys_ch ~= maxvalue & rf_businessassets_ch_pareto ~= maxvalue & rf_fin_net_ch_pareto ~= maxvalue)
replace mainasset = 7 if (land == maxvalue & rf_db_pensions_ch ~= maxvalue & rf_non_db_ch ~= maxvalue & prop_no_land ~= maxvalue & rf_phys_ch ~= maxvalue & rf_businessassets_ch_pareto ~= maxvalue & rf_fin_net_ch_pareto ~= maxvalue)
replace mainasset = 0 if maxvalue < 0


lab define mainasset 0 "No positive assets" 1 "Property excl. land" 2 "Financial wealth" 3 "Chargeable physical wealth" 4 "Business assets" 5 "DB Pensions" 6 "Non-DB Pensions" 7 "Land"
 
lab values mainasset mainasset


preserve 
drop if strl_flag == 1
keep if flag_hard == 1

collapse (sum) count (mean) prop_no_land rf_fin_net_ch_pareto rf_phys_ch rf_businessassets_ch_pareto rf_db_pensions_ch rf_non_db_ch land [pweight = xs_pers], by(mainasset) 

export excel "$output\val_analysis.xlsx", sheet("mainasset", modify) cell(A1) firstrow(var)

restore



******VALUATION COSTS******


*Chargeable & taxable wealth
drop count

*Min fees
g unlist_shares = rf_shares_ch_pareto if (own_unlisted_uk_shares == 1 & own_listed_uk_shares ~= 1)
recode unlist_shares (. = 0) if strl_flag != 1


foreach rate in 0.001 0.004 0.008 {
	*% of hard-to-value assets
	g val_cost = 2000 + hard*`rate'
	*with a cap at £50k - this will also apply 50k to all STRL people
	replace val_cost = 50000 if val_cost > 50000 
	*not for people with no hard assets
	replace val_cost = 0 if hard == 0 
	
	
	foreach threshold in 250000 500000 1000000 2000000 5000000 10000000 {
		preserve 
		g taxpayers = (rf_totwlth_ch_pareto > `threshold')
		g taxable = (rf_totwlth_ch_pareto - `threshold') if rf_totwlth_ch_pareto > `threshold'
		g valuation = val_cost if rf_totwlth_ch_pareto > `threshold'
		g chargeable = rf_totwlth_ch_pareto if rf_totwlth_ch_pareto > `threshold'
	
		*Aggregate
		collapse (sum) taxpayers valuation chargeable taxable [pweight = xs_pers] 
		
		g threshold = `threshold'


		save "$tempdata\val_cost_`threshold'.dta", replace

		restore
	}
	
	preserve 
	use "$tempdata\val_cost_250000", clear
	append using "$tempdata\val_cost_500000"
	append using "$tempdata\val_cost_1000000"
	append using "$tempdata\val_cost_2000000"
	append using "$tempdata\val_cost_5000000"
	append using "$tempdata\val_cost_10000000"
	
	export excel "$output\val_analysis.xlsx", sheet("val_`rate'", modify) cell(A1) firstrow(var)
	
	restore
	
	drop val_cost*
}
