/*******************************************************************************
Description:		Wealth tax modelling: pareto adjustment
					
Uses:				Clean round 6 data (r6_alt.dta) in $cleanwas
					strl_2020_clean_imputed. Produced by "strl_impute_missing_info_byindividual.do"
*******************************************************************************/

********************
****PERSON LEVEL****
********************
use "$cleanwas\r6_alt.dta", clear

*Total WAS wealth before adding in the STRL
total rf_totwlth [pw = xs_pers] //unadjusted

*********************
* PARETO ADJUSTMENT *
*********************
*We closely follow the method set out in Vermeulen (2018) "How fat is the top tail of the wealth distribution?" The Review of Income and Wealth, 64(2), 357-387.
*Variable names are broadly inline with the mathematical notation used in Vermeulen. 
*See also Advani, Bangham and Leslie (2021) "The UK's wealth distribution and characteristics of high-wealth households". Fiscal studies, 42.

g double N = xs_pers //cross sectional person weight ("N in Vermeulen (2018)")
g double wi = rf_businessplusshares //wealth definition used for Pareot adjustment

keep N wi caser6 personw5 personw6 //keep identifiers to link back to main dataset afterwards.

*Load 2020 STRL
*Note 2020 data is one row per individual named
append using "$tempdata\strl_2020_clean_imputed.dta" 

*Stat for paper: percentage of wealth held by residents in the STRL?
if $using_companies_house == 1 {
	total worth if resident == 1
	scalar resident_wealth = _b[worth]
	total worth 
	scalar resident_share = resident_wealth/_b[worth]
	di resident_share
}

replace wi = worth if strl_flag == 1 //fill in wealth of rich list observations, worth is already divided by number of individuals in the list entry so no dividing here
replace N = 1 if strl_flag == 1 //each obs represents one individual named on the rich list, so weight of one each (only one list year used here so not halving weights)
drop worth

replace wi = wi*690817/742613 if strl_flag == 1 //rescale to match 2017/18 aggregate wealth

*Drop individuals in WAS with wealth above STRL threshold
egen double minstrl = min(wi) if strl_flag==1
egen double strlthreshold = min(minstrl) //assign STRL lower bound to all observations
total wi [pw=N] if strl_flag!=1 & wi >= strlthreshold //wealth among overlapping households
scalar removedwealth = _b[wi]
drop if wi >= strlthreshold & strl_flag!=1 //Remove observations from the WAS which are above the lowest rich list observations (divided rich list wealth beteween 2 adults) 


*Set Pareto threshold (we use £500k)
scalar wmin = 500000 

*Keep observations in the Pareto tail
keep if wi > wmin 

*Number of WAS observations to be adjusted
count if wi > wmin & strl_flag!=1 //number of WAS observations to adjust


******************************
* Plotting the log-log graph *
******************************

*Define complimentary CDF
cumul wi [aw=N], generate(wi_cdf) 
g pct_above = (1-wi_cdf)*100 //complementary CDF of wealth

*Preliminary plot
tw scatter pct_above wi if wi>100000 & pct_above >0.00001 & missing(strl_flag), sort xscale(log) yscale(log) ///
	msize(tiny) msymbol(D) mcolor(blue) ///
	|| scatter pct_above wi if wi>100000 & pct_above >0.00001 & strl_flag==1, sort xscale(log) yscale(log) ///
	msize(tiny) msymbol(A) mcolor(red) ///
	ytitle("Percentage above (log scale)") xtitle("Wealth (log scale)") ///
	graphregion(color(white)) xlabel(,angle(90)) ylabel(,angle(horizontal)) ///
	legend(label(1 "WAS") label(2 "ST Rich List")) ///
	xlabel(100000 (5000000000) 21000000000) ylabel(0 (50) 100) 
graph export "$output\prelim_ecdf.png", as(png) replace

************************
* Implement adjustment *
************************

*Step 1: Sort in descending wealth order and assign each observation their rank in the sample wealth distribution
bys caser6 personw5 personw6 rank wi: g random = runiform()
gsort - wi random
g int i = _n 				// "i" in Vermeulen (2018)
drop random

*Step 2: Define the average weight and average weight of the first (wealthiest) i individuals for each i.
scalar n = _N 				// Number of sample observations
egen Ntotal = total(N) 
scalar Nt = Ntotal 			// Total sum of weights (rich list plus WAS)

gen cumulN = sum(N)
gen Nfi = cumulN/i 			//Cumulative weight up to i divided by rank i. "N_{fi} in Vermeulen (2018)"

*Step 3: run regression to estmate the Pareto index: equation (10) in Vermeulen (2018):
*Regression: ln((i-1/2)(Nfi/Nt)) = C - \alpha ln(wi)
g double depvar = log((i - 0.5)*(Nfi/Nt))
g double ln_wi = log(wi)

qui reg depvar ln_wi

scalar alpha = -(_b[ln_wi])	//defines Pareto index alpha
di "Pareto index: " alpha 	// Vermeulen finds it around 2 when excluding Forbes observations


*Step 4: estimate total wealth in the Pareto tail - what should the wealth of our observations have been according to the fitted Pareto distribution?
g fitted_x = (depvar - _b[_cons])/_b[ln_wi] //fitted log(wealth)
g fitted_exp_x = exp(fitted_x) //fitted wealth (taking exponential)

g weighted_fitted = fitted_exp_x*N
egen total_fitted = total(weighted_fitted)
scalar pareto_wealth = total_fitted

g weighted_wiwas = wi*N if missing(strl_flag)
egen t = total(weighted_wiwas)
scalar svywealth = t

g weighted_wiRL= wi*N if strl_flag !=.
egen totalRL = total(weighted_wiRL)
scalar RLwealth = totalRL

scalar additional_wealth = pareto_wealth - svywealth - totalRL

di "Wealth in tail = " pareto_wealth
di "Wealth that was removed from survey = " removedwealth
di "Wealth in survey = " svywealth
di "Wealth in RL = " totalRL
di "Additional wealth = " additional_wealth 
di "Total amount to add to WAS less overlapping households = " additional_wealth + totalRL 

********************************
* Plot the Pareto distribution *
********************************

egen wmax = max(wi)

*Export Pareto tail data
preserve
keep i wi pct_above N strl_flag
replace strl_flag = 0 if strl_flag !=1
export excel using "$output\pareto_data.xlsx", sheet("data", modify) firstrow(var)
restore

*Plot raw data and best fit line
local wmin = wmin
local wmax = wmax
tw function y = exp(_b[_cons]+_b[ln_wi]*ln(x))*100, range(`wmin' `wmax') xscale(log) yscale(log) lpattern(longdash) ///
	|| scatter pct_above wi if wi>wmin & pct_above >0.00001 & missing(strl_flag), sort xscale(log) yscale(log) ///
	msize(tiny) msymbol(D) mcolor(blue) ///
	|| scatter pct_above wi if wi>wmin & pct_above >0.00001 & strl_flag==1, sort xscale(log) yscale(log) ///
	msize(tiny) msymbol(A) mcolor(red) ///
	ytitle("Percentage above (log scale)") xtitle("Total business wealth (inc. shares) (log scale)") ///
	graphregion(color(white)) xlabel(,angle(90)) ylabel(,angle(horizontal)) ///
	legend(label(1 "Fitted Pareto") label(2 "WAS") label(3 "ST Rich List")) ///
	xlabel(`wmin' (5000000000) `wmax') ylabel(0 (50) 100)  
graph export "$output\paretographwithoutfitted.png", replace

*Plot raw data, best fit line, and predicted values
local wmin = wmin
local wmax = wmax
tw function y = exp(_b[_cons]+_b[ln_wi]*ln(x))*100, range(`wmin' `wmax') xscale(log) yscale(log) lpattern(longdash) ///
	|| scatter pct_above wi if wi>wmin & pct_above >0.00001 & missing(strl_flag), sort xscale(log) yscale(log) ///
	msize(tiny) msymbol(D) mcolor(blue) ///
	|| scatter pct_above wi if wi>wmin & pct_above >0.00001 & strl_flag==1, sort xscale(log) yscale(log) ///
	msize(tiny) msymbol(A)  mcolor(red) ///
	|| scatter pct_above fitted_exp  if wi>wmin & pct_above >0.00001, sort xscale(log) yscale(log) ///
	mcolor(green) msize(tiny) ///
	ytitle("Percentage above (log scale)") xtitle("Total business wealth (inc.shares) (log scale)") ///
	graphregion(color(white)) xlabel(,angle(90)) ylabel(,angle(horizontal)) ///
	xlabel(`wmin' (5000000000) `wmax') ylabel(0 (50) 100) ///
	legend(label(1 "Fitted Pareto") label(2 "WAS") label(3 "ST Rich List"))  legend(label(4 "Predicted values"))
graph export "$output\raw_bestfit_predicted.png", replace

***************************************
* Assign Pareto wealth at micro level *
***************************************
*To generate micro-level adjusted wealth, replace WAS/STRL wealth above the threshold with the predicted value fitted_exp_x 

g wi_adjusted = wi
replace wi_adjusted = fitted_exp_x if wi> wmin 

*Save adjusted top WAS observations 
preserve
keep if strl_flag!=1
g adjusted_flag = 1
save "$tempdata\pareto_adjusted_topwas.dta", replace
restore

*Save adjusted STRL observations
preserve
keep if strl_flag==1
g adjusted_flag = 1
g id_strl = _n
save "$tempdata\pareto_adjusted_topstrl.dta", replace
restore

*Merge adjusted WAS with unadjusted WAS data
use "$cleanwas\r6_alt.dta", clear
merge 1:1 caser6 personw5 personw6 using "$tempdata\pareto_adjusted_topwas.dta", nogen
egen double strl_thresh = min(strlthreshold) //assign STRL lower bound to all observations

*Identify households where one individual overlaps with the STRL 
g byte overlap = rf_businessplusshares >= strl_thresh
gegen hh_overlap = max(overlap), by(caser6)
/*Adjusting equal split wealth:  The issue is that with the equal split series,  
the wealth of overlapping households has been reallocated to their spouse, who we aren't dropping from the data. This means that if we just
drop the individuals whose own wealth exceeds the STRL threshold, we have more wealth in total using the equal split definition than when those
remaining in the sample only had their own wealth. There are two options: assign individually defined wealth rather than equal split wealth
only to those whose spouse is dropped. Alternatively, drop all household members if one overlaps. But we don't want to do this from
the headline estimates so we instead set the spouse's "equal split" wealth to zero, so that when this definition is used, these
individuals are effectively excluded. There isn't much difference between the two options in revenue terms*/
//replace eq_totwlth_ch = rf_totwlth_ch if hh_overlap == 1 //option 1
replace eq_totwlth_ch = 0 if hh_overlap == 1 
drop if overlap == 1 //Remove observations from the WAS which are above the lowest rich list observations 

*Pareto value of business plus shares
g rf_businessplusshares_pareto = rf_businessplusshares
replace rf_businessplusshares_pareto = wi_adjusted if adjusted_flag == 1
lab var rf_businessplusshares_pareto "Pareto adjusted business wealth plus shares"
g rf_businessplusshares_ch_pareto = rf_businessplusshares_ch
replace rf_businessplusshares_ch_pareto = rf_businessplusshares_pareto if adjusted_flag == 1
lab var rf_businessplusshares_ch_pareto "Pareto adjusted business wealth plus shares, chargeable"

*Compare pareto wealth with unadjusted wealth among WAS population
total rf_businessplusshares_pareto [pw=xs_pers] if adjusted_flag == 1
total rf_businessplusshares [pw=xs_pers] if adjusted_flag == 1
g diff = rf_businessplusshares_pareto - rf_businessplusshares if adjusted_flag == 1
total diff [pw=xs_pers] //amount to add to WAS
drop diff 

*Pareto adjustment: split between business assets and shares (for WAS observations) according to raw data share/business asset split
*Note rf_businessplusshares = rf_businessassets + rf_shares
g share_share = rf_shares/(rf_businessplusshares) if adjusted_flag == 1
*Share of adjustment attributable to shares
g pareto_sh = (rf_businessplusshares_pareto - rf_businessplusshares)*share_share if adjusted_flag == 1 //note some of these will be negative where wealth is reduced by Pareto

*Add additional Pareto shares to shares
g rf_shares_pareto = rf_shares
replace rf_shares_pareto = rf_shares + pareto_sh if adjusted_flag == 1
lab var rf_shares_pareto "Pareto adjusted shares (WAS obs)"

*Add additional Pareto shares to financial wealth for Pareto adjusted observations
g rf_fin_net_pareto = rf_fin_net
replace rf_fin_net_pareto = rf_fin_net + pareto_sh if adjusted_flag == 1
lab var rf_fin_net_pareto "Pareto adjusted net financial wealth (WAS obs)"
g rf_fin_net_ch_pareto = rf_fin_net_ch
replace rf_fin_net_ch_pareto = rf_fin_net_ch + pareto_sh if adjusted_flag == 1
g rf_fin_grs_pareto = rf_fin_grs
replace rf_fin_grs_pareto = rf_fin_grs + pareto_sh if adjusted_flag == 1
lab var rf_fin_grs_pareto "Pareto adjusted gross financial wealth (WAS obs)"

*Add additional Pareto business assets to business assets for Pareto adjusted observations
g rf_businessassets_pareto = rf_businessassets 
replace rf_businessassets_pareto = rf_businessplusshares_pareto - rf_shares_pareto if adjusted_flag == 1
lab var rf_businessassets_pareto "Pareto adjusted business assets (WAS obs)"
g rf_businessassets_ch_pareto = rf_businessassets_ch
replace rf_businessassets_ch_pareto = rf_businessassets_ch + (rf_businessplusshares_pareto - rf_businessplusshares)*(1-share_share) if adjusted_flag == 1
lab var rf_businessassets_ch_pareto "Pareto adjusted business assets (WAS obs), chargeable"

*Add additional Pareto business assets across small/large business assets for Pareto adjusted observations
g rf_smallbus_pareto = rf_smallbus
g rf_largebus_pareto = rf_largebus
g share_small = rf_smallbus/(rf_smallbus + rf_largebus)
replace rf_smallbus_pareto = (rf_businessplusshares_pareto - rf_shares_pareto)*share_small if (adjusted_flag == 1 & rf_smallbus > 0 & rf_smallbus ~= .)
replace rf_largebus_pareto = (rf_businessplusshares_pareto - rf_shares_pareto)*(1-share_small) if (adjusted_flag == 1 & rf_largebus > 0 & rf_largebus ~= .)
lab var rf_smallbus_pareto "Pareto adjusted small business assets (WAS obs)"
g rf_smallbus_ch_pareto = rf_smallbus_ch
g rf_largebus_ch_pareto = rf_largebus_ch
replace rf_smallbus_ch_pareto = rf_smallbus_ch + (rf_businessplusshares_pareto - rf_businessplusshares)*(1-share_share)*share_small if adjusted_flag == 1
replace rf_largebus_ch_pareto = rf_largebus_ch + (rf_businessplusshares_pareto - rf_businessplusshares)*(1-share_share)*share_small if adjusted_flag == 1


*Compare Pareto adjusted business assets and pareto adjustedshares with undadjusted businessplusshares
total rf_businessassets_pareto [pw=xs_pers] if adjusted_flag == 1
total rf_shares_pareto [pw=xs_pers] if adjusted_flag == 1
total rf_businessplusshares_pareto [pw=xs_pers] if adjusted_flag == 1
drop pareto_sh share_share 

*Redefine total market wealth with Pareto adjustment
g rf_totwlth_pareto = rf_totwlth 
replace rf_totwlth_pareto = rf_totwlth - rf_businessplusshares + rf_businessassets_pareto + rf_shares_pareto if adjusted_flag == 1
lab var rf_totwlth_pareto "Pareto adjusted market wealth (WAS and STRL)"
g diff = rf_totwlth_pareto - rf_totwlth 
total diff [pw=xs_pers] //check matches amount to add to WAS defined above
drop diff 

*Redefine total chargeable wealth with Pareto adjustment
g rf_totwlth_ch_pareto = rf_totwlth_ch
replace rf_totwlth_ch_pareto = rf_totwlth_ch - rf_businessassets_ch + rf_businessassets_ch_pareto  - rf_fin_net_ch + rf_fin_net_ch_pareto if adjusted_flag == 1
lab var rf_totwlth_ch_pareto "Pareto adjusted chargeable wealth (WAS and STRL)"
g diff = rf_totwlth_ch_pareto - rf_totwlth_ch
total diff [pw=xs_pers] //check matches amount to add to WAS defined above
drop diff 


*Redefine equally split chargeable wealth by splitting Pareto adjustment between main adults
gegen hh_adj_flag = max(adjusted_flag), by(caser6)
g double pareto = rf_totwlth_ch_pareto - rf_totwlth_ch if adjusted_flag == 1
replace pareto = 0 if adjusted_flag != 1
gegen bu_pareto = sum(pareto), by(caser6 mainadultsflag)
g double eq_pareto = pareto if !mainadultsflag
replace eq_pareto = bu_pareto/numadults if mainadultsflag
g double eq_totwlth_ch_pareto = eq_totwlth_ch
replace eq_totwlth_ch_pareto = eq_totwlth_ch + eq_pareto if hh_adj_flag == 1


*Now add rich list observations
append using "$tempdata\pareto_adjusted_topstrl.dta"
replace rf_totwlth_ch_pareto = wi_adjusted if strl_flag == 1
replace rf_totwlth_pareto = wi_adjusted if strl_flag == 1
replace eq_totwlth_ch_pareto = wi_adjusted if strl_flag == 1
replace rf_businessplusshares_pareto = wi_adjusted if strl_flag == 1
replace rf_businessplusshares_ch_pareto = wi_adjusted if strl_flag == 1
replace xs_pers = N if strl_flag==1

*Total market wealth including Pareto adjustment for both WAS and STRL
total rf_totwlth_pareto [pw=xs_pers] 
total rf_totwlth [pw=xs_pers]


*Total wealth after adding in STRL, before Pareto
preserve 
replace rf_totwlth = wi if strl_flag == 1
total rf_totwlth [pw=xs_pers]
restore

*Total chargeable wealth including Pareto adjustment for both WAS and STRL 
total rf_totwlth_ch_pareto [pw=xs_pers]
total rf_totwlth_ch [pw=xs_pers]

preserve 
replace rf_totwlth_ch = 0 if strl_flag == 1
g diff = rf_totwlth_ch_pareto - rf_totwlth_ch
total diff [pw=xs_pers]
restore

*Total Pareto adjusted market wealth 
total rf_totwlth_pareto [pw=xs_pers]
*Total unajusted (WAS) market wealth
total rf_totwlth [pw=xs_pers]
*Total Pareto adjusted chargeable wealth 
total rf_totwlth_ch_pareto [pw=xs_pers]
*Total unadjusted (WAS) chargeable wealth
total rf_totwlth_ch [pw=xs_pers] 

if $using_companies_house == 1 {	
	keep rf_* eq_* ind_* xs_pers strl_flag agegroup* gor sex caser6 personw5 personw6 id_strl rank resident british married adjusted_flag oleft wave own*
}
else {
	keep rf_* eq_* ind_* xs_pers strl_flag agegroup* gor sex caser6 personw5 personw6 id_strl rank married adjusted_flag oleft wave own*
}

recode rf_* ind_* (.=0) if strl_flag == . // don't want survey variables except pareto adjusted to be 0 for STRL observations

*Define total wealth excluding pensions and main homes (pareto adjusted and pareto unadjusted)
g double rf_lesspenhome_pareto = rf_totwlth_pareto - rf_pen - rf_mainhome_net
replace rf_lesspenhome_pareto = rf_totwlth_pareto if strl_flag == 1
lab var rf_lesspenhome_pareto "Pareto adjusted market wealth less pension and main home (WAS and STRL)"
g double rf_lesspenhome_ch_pareto = rf_totwlth_ch_pareto - rf_pen_ch - rf_mainhome_net_ch
replace rf_lesspenhome_ch_pareto = rf_totwlth_ch_pareto if strl_flag == 1
lab var rf_lesspenhome_ch_pareto "Pareto adjusted chargeable wealth less pension and main home (WAS and STRL)"
g double rf_totwlth_contents_ch_pareto = rf_totwlth_ch_pareto + rf_contents
replace rf_totwlth_contents_ch_pareto = rf_totwlth_ch_pareto if strl_flag == 1

save "$tempdata\pareto_adjusted_final.dta", replace
