/*******************************************************************************
Description:		Wealth tax modelling: flat tax one-off banded

Uses: data for analysis defined in step 3.define_sample.do (sample_for_analysis.dta)
*******************************************************************************/

use "$tempdata\sample_for_analysis.dta", clear


****************
**BANDED ONE-OFF**
****************

*Rate 
local rate = $frate_one_500 //for comparison with one-off
	
*Flag one-off
local rate_flag = "once"

local base_flag = "$base_flag"


	
*Matrix for results
matrix once_band = J(2,6,.)
mat coln once_band = individual1_hh2 tight1_wide2 assets taxpayers revenue revenue_quart
*2nd column indicates banding scheme: low & tight or high & wide


****************
*****CALCS*****
****************

*Excel sheet for output
putexcel set "$output\outputs.xlsx", modify sheet("indiv_band`base_flag'`rate_flag'")

*Band thresholds
local tight_thresholds 500000 1000000 2000000 4000000 8000000 16000000 32000000
local wide_thresholds 500000 2000000 5000000 20000000 50000000 200000000
*Number of bands
local ntight : word count `tight_thresholds'
local n_1tight = `ntight' - 1
local nwide : word count `wide_thresholds'
local n_1wide = `nwide' - 1
	
local row = 0
local for_table = 1	//fudge			

*Loop through banding schemes
foreach scheme in tight wide {
	
		local row = `row' + 1

		*Person basis
		matrix once_band[`row',1] = 1
	
		*Banding scheme: 1 = low & tight; 2 = high & wide
		matrix once_band[`row',2] = `for_table'
		
		*Min & max thresholds
		local min_threshold : word 1 of ``scheme'_thresholds'

				
		g band_`scheme' = .
		g `scheme'band_mid = .
		g `scheme'band_quart = .
		forvalues t = 1/`n_1`scheme'' {
			local t1 = `t' + 1
			local l : word `t' of ``scheme'_thresholds'
			local h : word `t1' of ``scheme'_thresholds'
			replace band_`scheme' = `t' if $wealth_var > `l' & $wealth_var <= `h'
			replace `scheme'band_mid = `l' + (`h' - `l')/2 if $wealth_var > `l' & $wealth_var <= `h'
			replace `scheme'band_quart = `l' + (`h' - `l')/4 if $wealth_var > `l' & $wealth_var <= `h'
		}

		replace band_`scheme' = `n`scheme'' if $wealth_var > `h' & $wealth_var ~= .
		*Use midpoint as basis for tax charge 
		replace `scheme'band_mid = `h'*1.5 if $wealth_var > `h' & $wealth_var ~= .
		replace `scheme'band_mid = . if band_`scheme' == .
		*Quarter basis
		replace `scheme'band_quart = `h'*1.25 if $wealth_var > `h' & $wealth_var ~= .
		replace `scheme'band_quart = . if band_`scheme' == .

		*Tax due based on unadjusted wealth
		g tax_due = `scheme'band_mid*`rate'
		replace tax_due = 0 if $wealth_var < `min_threshold'
		g tax_due_q = `scheme'band_quart*`rate'
		replace tax_due_q = 0 if $wealth_var < `min_threshold'
		
		
		sort $wealth_var
		g pers_no = _n
			
		*Save tax due based on each band so that avoidance doesn't affect charge
		forvalues t = 1/`n`scheme'' {
			sum tax_due if band_`scheme' == `t'
			scalar charge_`t' = r(mean)
			scalar charge_q`t' = r(mean)
		}
		*Lower band charge is zero
		scalar charge_0 = 0
		scalar charge_q0 = 0
			
		*Average tax rate
		g atr = tax_due/$wealth_var
		replace atr = 0 if $wealth_var < `min_threshold'

		*keep this for analysis
		g band_unadj_`scheme' = band_`scheme'
		g taxdue_unadj_`scheme' = tax_due
		g atr_unadj_`scheme' = atr

		*Adjust wealth to account for evasion based on average tax rate
		*10% wealth reduction as avoidance 
		*Model as simple tax gap, not elasticity
		g double wealth_adj = 500000 + ($wealth_var - 500000)*0.9
		
		*Assets in tax base (£bn)
		g taxable = wealth_adj - `min_threshold'
		sum taxable [weight=xs_pers] if taxable > 0
		di r(sum)/1000000000 
		matrix once_band[`row',3] = r(sum)/1000000000 //total taxable wealth in billions
		
		*Calculate taxpayers
		matrix once_band[`row',4] = r(sum_w) //weighted sum of observations with taxable wealth
			
		*Wealth for tax
		drop band_`scheme' `scheme'band_mid 
		
		g band_`scheme' = .
		forvalues t = 1/`n_1`scheme'' {
			local t1 = `t' + 1
			local l : word `t' of ``scheme'_thresholds'
			local h : word `t1' of ``scheme'_thresholds'
			replace band_`scheme' = `t' if wealth_adj > `l' & wealth_adj <= `h'
		}
		replace band_`scheme' = `n`scheme'' if wealth_adj > `h' & wealth_adj ~= .
		
		
		*Tax due - update for people who've changed band
		forvalues t = 1/`n`scheme'' {
			replace tax_due = charge_`t' if (band_`scheme' == `t' & band_`scheme' ~= band_unadj_`scheme')
			replace tax_due_q = charge_q`t' if (band_`scheme' == `t' & band_`scheme' ~= band_unadj_`scheme')
		}	
		replace tax_due = 0 if wealth_adj < `min_threshold'
		replace tax_due_q = 0 if wealth_adj < `min_threshold'
		
		
		*Revenue (£bn)
		sum tax_due [weight = xs_pers] if (tax_due > 0 & tax_due ~= .)
		di r(sum)/1000000000
		matrix once_band[`row',5] = r(sum)/1000000000 //total revenue in £billions
		
		sum tax_due_q [weight = xs_pers] if (tax_due_q > 0 & tax_due_q ~= .)
		di r(sum)/1000000000		
		matrix once_band[`row',6] = r(sum)/1000000000 //total revenue in £billions
		
		*Keep for analysis
		g taxdue_adj_`scheme' = tax_due
		g atr_adj_`scheme' = tax_due/$wealth_var
		g wealth_adj_`scheme' = wealth_adj
		
		*Clean up
		drop tax_due tax_due_q atr wealth_adj taxable band_`scheme' pers_no
		
		*Fudge: change scheme type marker from 1 to 2
		local for_table = `for_table' + 1				

}
	
*Output matrix
putexcel A2=matrix(once_band), names 

