/*******************************************************************************
Description:		Wealth tax modelling: progressive annual tax

Uses: data for analysis defined in step 3.define_sample.do (sample_for_analysis.dta)
*******************************************************************************/

use "$tempdata\sample_for_analysis.dta", clear


********************
***INCREASING MARGINAL RATE**
********************
foreach elasticity in 0 7 17 {

	local base_flag = "$base_flag"

	if `elasticity' == 0 { 
		local evasion_flag = "none"
	}
	if `elasticity' == 7 {
		local evasion_flag = "low"
	}
	if `elasticity' == 17 {
		local evasion_flag = "high"
	}


	*Matrix for results
	matrix indiv_incr = J(2,8,.)
	mat coln indiv_incr = individual1_hh2 assets taxpayers revenue rate_1m rate_2m rate_5m rate_10m 

	*Excel sheet for output
	putexcel set "$output\outputs.xlsx", modify sheet("indiv_incr`base_flag' `evasion_flag'")

	********************
	***CALCS**
	********************

	*Start at 1m with rising marginal rates (but not a jump in the average rate) at 2m, 5m, 10m. 

	*Person basis
	matrix indiv_incr[1,1] = 1

	*Rates
	scalar rate_1m = $prate_an_1m
	scalar rate_2m = $prate_an_2m
	scalar rate_5m = $prate_an_5m
	scalar rate_10m = $prate_an_10m
		
	*Average tax rate
	g atr = 0 if $wealth_var < 1000000
	replace atr = (($wealth_var - 1000000)*rate_1m)/$wealth_var if $wealth_var > 1000000 & $wealth_var < 2000000
	replace atr = (($wealth_var - 2000000)*rate_2m + (2000000-1000000)*rate_1m)/$wealth_var if $wealth_var > 2000000 & $wealth_var < 5000000
	replace atr = (($wealth_var - 5000000)*rate_5m + (5000000-2000000)*rate_2m + (2000000-1000000)*rate_1m)/$wealth_var if $wealth_var > 5000000 & $wealth_var < 10000000
	replace atr = (($wealth_var - 10000000)*rate_10m + (10000000-5000000)*rate_5m + (5000000-2000000)*rate_2m + (2000000-1000000)*rate_1m)/$wealth_var if $wealth_var > 10000000


	*Adjust wealth to account for evasion based on average tax rate
	g double evasion = `elasticity'*(atr/0.01)/100
	g double wealth_adj = ${wealth_var}*(1-evasion)

	g mtr = 0 if $wealth_var < 1000000
	replace mtr = rate_1m if $wealth_var > 1000000 & $wealth_var < 2000000
	replace mtr = rate_2m if $wealth_var > 2000000 & $wealth_var < 5000000
	replace mtr = rate_5m if $wealth_var > 5000000 & $wealth_var < 10000000
	replace mtr = rate_10m if $wealth_var > 10000000

	*Assets in tax base (£bn)
	g taxable = wealth_adj - 1000000
	sum taxable [weight = xs_pers] if taxable > 0
	di r(sum)/1000000000
	matrix indiv_incr[1,2] = r(sum)/1000000000
	
	g tax_due_1m = .
	replace tax_due_1m = 0 if wealth_adj < 1000000
	replace tax_due_1m = (wealth_adj - 1000000)*rate_1m if wealth_adj >= 1000000
	replace tax_due_1m = 1000000*rate_1m if wealth_adj > 2000000

	g tax_due_2m = .
	replace tax_due_2m = 0 if wealth_adj < 2000000
	replace tax_due_2m = (wealth_adj - 2000000)*rate_2m if wealth_adj >= 2000000
	replace tax_due_2m = 3000000*rate_2m if wealth_adj > 5000000

	g tax_due_5m = .
	replace tax_due_5m = 0 if wealth_adj < 5000000
	replace tax_due_5m = (wealth_adj - 5000000)*rate_5m if wealth_adj >= 5000000
	replace tax_due_5m = 5000000*rate_5m if wealth_adj > 10000000

	g tax_due_10m = .
	replace tax_due_10m = 0 if wealth_adj < 10000000
	replace tax_due_10m = (wealth_adj - 10000000)*rate_10m if wealth_adj >= 10000000


	*Record rates
	matrix indiv_incr[1,5] = rate_1m //marginal rates above each threshold
	matrix indiv_incr[1,6] = rate_2m
	matrix indiv_incr[1,7] = rate_5m
	matrix indiv_incr[1,8] = rate_10m


	g tax_due = tax_due_1m + tax_due_2m + tax_due_5m + tax_due_10m
	sum tax_due [weight = xs_pers] if (tax_due > 0 & tax_due ~= .)
	matrix indiv_incr[1,3] = r(sum_w) //number of individuals paying tax 


	*Total revenue (£bn)
	sum tax_due [weight = xs_pers] if (tax_due > 0 & tax_due ~= .)
	di r(sum)/1000000000
	matrix indiv_incr[1,4] = r(sum)/1000000000 //total revenue in £billions


	drop tax_due tax_due*m atr wealth_adj evasion taxable mtr

	*Output matrix
	putexcel A2=matrix(indiv_incr), names 
	
}
