
/*******************************************************************************
Description:		Wealth tax modelling: graph plotting thresholds against rates

Uses: data for analysis defined in step 3.define_sample.do (sample_for_analysis.dta)
*******************************************************************************/
set seed 623945731

********************
******SETUP*******
********************
clear all
set mo off, perm
pause on



**********************************************
**PREFERENCES FOR AUTOMATIC REVENUE TARGETTING
**********************************************

global istargetafteradmin = 0 // set to 1 if want revenue target to be after admin costs, 0 otherwise

global targetbn = 30 //set this to desired target in £bn
global target = ${targetbn}*1e9 //ignore this

global closeness = 0.005 //set how close you want to be to the target in £bn
global increment = 0.001 // (%) set what increment you want the rate to go up by in %

global elasticities  0 // list which elasticities you want to run the code for (NO "="). This can be a list, not just a single option
//Note higher revenue target and higher elasticity makes code much longer to run, might want to increase closeness parameter above

global oneoff = 0 //whether it is a one-off tax or not (if select one off it will account for evasion - recall evasion is not done using elasticities for one off)
**********************************************


*Run to where this is saved in revenue_modelling.do
use "$tempdata\sample_for_analysis.dta", clear

*************
* Flat rate *
*************

foreach elasticity in $elasticities { 

	if `elasticity' == 0 {
	local evasion_flag = "none"
	}
	if `elasticity' == 7 {
	local evasion_flag = "low"
	}
	if `elasticity' == 17 {
	local evasion_flag = "high"
	}

	*Matrix for results
	matrix indiv_flatfixed = J(201,8,.)
	mat coln indiv_flatfixed = individual1_hh2 taxthreshold assets taxpayers revenue rate admincost revenue_after_admin
	********************

	********************
	***CALCS***
	********************

	local row = 0


	*Excel sheet for output
	putexcel set "$output\automate.xlsx", modify sheet("flat`base_flag'`evasion_flag'$targetbn")

	foreach flat_threshold in 250000 500000 1000000 2000000 5000000 10000000 { 
		local row = `row' + 1

		*Person basis
		matrix indiv_flatfixed[`row',1] = 1
		
		*Threshold
		matrix indiv_flatfixed[`row',2] = `flat_threshold'
		
		*Wealth above threshold
		g wealthabove = $wealth_var - `flat_threshold' if $wealth_var > `flat_threshold'
		qui total wealthabove [pw=xs_pers]
		scalar totalassets = _b[wealthabove]
		
		*Filers (taxpayers plus with those with wealth 10% below threshold)
		g filer = ($wealth_var > 0.9*`flat_threshold')
		qui total filer [pw=xs_pers]
		scalar admincost = _b[filer]*0.05*2500
		matrix indiv_flatfixed[`row', 7] = admincost
		
		
		*Initial rate 
		if $istargetafteradmin == 0 {
		scalar irate = ${target}/totalassets
		}
		if $istargetafteradmin == 1 & $oneoff == 0 { //create one here for one off which reduces rev by 10%
		scalar irate = (${target} + admincost)/totalassets
		}
		if $istargetafteradmin == 1 & $oneoff == 1 {
		scalar irate = (${target} + admincost)/(0.9*totalassets)
		}
		if $istargetafteradmin == 0 & $oneoff == 1 {
		scalar irate = ${target}/(0.9*totalassets)
		}
		
		local rate = irate

		
		*Initial average tax rate
		g double atr = 0 if $wealth_var < `flat_threshold'
		replace atr = ($wealth_var - `flat_threshold')*`rate'/$wealth_var if $wealth_var > `flat_threshold'
		
		*Adjust wealth to account for evasion  based on average rate
		g double evasion = `elasticity'*(atr/0.01)/100
		g double wealth_adj = ${wealth_var}*(1-evasion)
		
		
		*Tax due
		g double taxdue = `rate'*(wealth_adj - `flat_threshold') if wealth_adj > `flat_threshold'
		qui total taxdue [pw=xs_pers] if taxdue > 0
		scalar revenue = _b[taxdue]
		
		*Solve fixed point problem
		if $istargetafteradmin == 0 & $oneoff == 0 { //code not built for one-off with avoidance
			while $target - revenue > ${closeness}*1e9 { 
				local rate = `rate' + ${increment}/100 //note initial rate will always be too low 

				replace atr = 0 if $wealth_var < `flat_threshold' 
				replace atr = ($wealth_var - `flat_threshold')*`rate'/$wealth_var if $wealth_var > `flat_threshold'
				
				replace evasion = `elasticity'*(atr/0.01)/100
				replace wealth_adj = ${wealth_var}*(1-evasion)
				
				replace taxdue = `rate'*(wealth_adj - `flat_threshold') if wealth_adj > `flat_threshold'
				qui total taxdue [pw=xs_pers] if taxdue > 0
				scalar revenue = _b[taxdue]
			}
		}
	
		if $istargetafteradmin == 1 & $oneoff == 0 {
			while $target + admincost - revenue > ${closeness}*1e9 {
				local rate = `rate' + ${increment}/100 //note initial rate will always be too low 
				
				replace atr = 0 if $wealth_var < `flat_threshold' 
				replace atr = ($wealth_var - `flat_threshold')*`rate'/$wealth_var if $wealth_var > `flat_threshold'
				
				replace evasion = `elasticity'*(atr/0.01)/100
				replace wealth_adj = ${wealth_var}*(1-evasion)
				
				replace taxdue = `rate'*(wealth_adj - `flat_threshold') if wealth_adj > `flat_threshold'
				qui total taxdue [pw=xs_pers] if taxdue > 0
				scalar revenue = _b[taxdue]
			}
		}
	
		*Assets in tax base (£bn)
		g double taxable = wealth_adj - `flat_threshold'
		qui sum taxable [weight=xs_pers] if taxable > 0
		di r(sum)/1e9 
		matrix indiv_flatfixed[`row',3] = r(sum)/1e9 //total taxable wealth in billions
		
		*Calculate taxpayers
		g double tax_due = 0
		replace tax_due = (wealth_adj - `flat_threshold')*`rate' if wealth_adj > `flat_threshold'
		qui sum tax_due [weight=xs_pers] if tax_due > 0 
		matrix indiv_flatfixed[`row',4] = r(sum_w) //number of individuals paying tax 
	
		*Revenue (£bn))
		g double revenue = `rate'*taxable
		qui sum revenue [weight = xs_pers] if taxable > 0
		di r(sum)/1e9
		if $oneoff == 0 {
			matrix indiv_flatfixed[`row',5] = r(sum)/1e9 //total revenue in £billions
		}
		if $oneoff == 1 {
			matrix indiv_flatfixed[`row',5] = r(sum)*0.9/1e9 //total revenue in £billions
		}
		
		*Revenue (£bn) after admin costs
		if $oneoff == 1 {
			matrix indiv_flatfixed[`row', 8] = (0.9*r(sum) - admincost)/1e9
		}
		if $oneoff == 0 {
			matrix indiv_flatfixed[`row', 8] = (r(sum) - admincost)/1e9
		}
		*Rate 
		matrix indiv_flatfixed[`row',6] = `rate'
		
		drop tax_due atr wealth_adj evasion taxable revenue wealthabove taxdue filer
	}

	*Output matrix, low
	putexcel A2=matrix(indiv_flatfixed), names 
}
