/*******************************************************************************
Description:		Effect of exempting assets 	

Uses: data for analysis defined in step 3.define_sample.do (sample_for_analysis.dta)
******************************************************************************/

set seed 623945731

********************
******SETUP*******
********************
clear all
set mo off, perm
pause on

*****************************
**BASED ON WAS AND STRL SAMPLE
******************************

use "$tempdata\sample_for_analysis.dta", clear

*Total wealth
g wealth_total = rf_totwlth_ch_pareto
*Wealth excluding main residence (assume STRL wealth does not include main residence)
g wealth_exmainhome = rf_totwlth_ch_pareto - rf_mainhome_net_ch
replace wealth_exmainhome = rf_totwlth_ch_pareto if strl_flag == 1
*Wealth excluding pensions (assume STRL wealth does not include pensions)
g wealth_expension = rf_totwlth_ch_pareto - rf_pen_ch
replace wealth_expension = rf_totwlth_ch_pareto if strl_flag == 1
*Wealth excluding pensions and main residence
g wealth_exhomepen = rf_totwlth_ch_pareto - rf_mainhome_net_ch - rf_pen_ch
replace wealth_exhomepen = rf_totwlth_ch_pareto if strl_flag == 1
*Wealth excluding business assets (effectively excludes STRL wealth)
g wealth_exbusinessassets = rf_totwlth_ch_pareto - rf_businessassets_ch_pareto
replace wealth_exbusinessassets = rf_totwlth_ch_pareto - rf_businessplusshares_ch_pareto if strl_flag == 1
*Wealth excluding financial assets (assumes STRL wealth does not include other financial assets)
g wealth_exfinancial = rf_totwlth_ch_pareto  - rf_fin_net_ch_pareto
replace wealth_exfinancial = rf_totwlth_ch_pareto if strl_flag == 1
*Wealth excluding physical assets (assumes STRL wealth does not include physical assets)
g wealth_exphysical = rf_totwlth_ch_pareto - rf_phys_ch
replace wealth_exphysical = rf_totwlth_ch_pareto if strl_flag == 1
*Wealth excluding all property including main residence (assumes STRL wealth does not include property)
g wealth_exproperty = rf_totwlth_ch_pareto - rf_prop_net_ch
replace wealth_exproperty = rf_totwlth_ch_pareto if strl_flag == 1

**********************************************************************
* Revenue calculations for a wealth tax with each of the above bases *
**********************************************************************
foreach var in wealth_total wealth_exmainhome wealth_expension wealth_exhomepen wealth_exbusinessassets wealth_exfinancial wealth_exphysical wealth_exproperty { 

	g wealth_var = `var'
	global wealth_var wealth_var

	*************
	* Flat rate *
	*************

	*Set: 
	*thresholds - 250k, 500k, 1m, 2m, 5m, 10m
	global thresholds 250000 500000 1000000 2000000 5000000 10000000


	*Matrix for results
	matrix indiv_flatfixed = J(6,6,.)
	mat coln indiv_flatfixed = individual1_hh2 taxthreshold assets taxpayers revenue rate
	********************

	********************
	***CALCS***
	********************

	local row = 0


	*Excel sheet for output
	putexcel set "$output\different_bases_full_sample.xlsx", modify sheet("`var'")

	foreach flat_threshold in $thresholds { 

		local row = `row' + 1

		*Person basis
		matrix indiv_flatfixed[`row',1] = 1
		
		*Threshold
		matrix indiv_flatfixed[`row',2] = `flat_threshold'
			
		*Rates for raising £280bn (£250bn after evasion under a one-off tax) (share of revenue lost is independent of the rates) 
		local rates = 1
		if `flat_threshold' == 250000 &`rates' == 1 local rate = $frate_one_250
		if `flat_threshold' == 500000 &`rates' == 1 local rate = $frate_one_500
		if `flat_threshold' == 1000000 &`rates' == 1 local rate = $frate_one_1m
		if `flat_threshold' == 2000000 &`rates' == 1 local rate = $frate_one_2m
		if `flat_threshold' == 5000000 &`rates' == 1 local rate = $frate_one_5m
		if `flat_threshold' == 10000000 &`rates' == 1 local rate = $frate_one_10m

		*Average tax rate
		g atr = 0 if $wealth_var < `flat_threshold'
		replace atr = ($wealth_var - `flat_threshold')*`rate'/$wealth_var if $wealth_var > `flat_threshold'
		
		g wealth_adj = $wealth_var
		
		*Assets in tax base (£bn)
		g taxable = wealth_adj - `flat_threshold'
		sum taxable [weight=xs_pers] if taxable > 0
		di r(sum)/1e9
		matrix indiv_flatfixed[`row',3] = r(sum)/1e9 //total taxable wealth in billions
		
		*Calculate taxpayers
		g tax_due = 0
		replace tax_due = (wealth_adj - `flat_threshold')*`rate' if wealth_adj > `flat_threshold'
		sum tax_due [weight=xs_pers] if tax_due > 0 
		matrix indiv_flatfixed[`row',4] = r(sum_w) //number of individuals paying tax 
		
		*Revenue (£bn))
		g double revenue = `rate'*taxable
		sum revenue [weight = xs_pers] if taxable > 0
		di r(sum)/1e9
		matrix indiv_flatfixed[`row',5] = 0.9*(r(sum)/1e9) //total revenue in £billions, after acounting for evasion 
		
		*Rate 
		matrix indiv_flatfixed[`row',6] = `rate'
		
		*Clean up
		drop tax_due atr wealth_adj taxable revenue 
		}

		*Output matrix, low
		putexcel A2=matrix(indiv_flatfixed), names 

	drop wealth_var	
	}	

	
