
/*******************************************************************************
Description:		Wealth tax modelling: amount paid by wealth

Uses:				No data required
*******************************************************************************/
clear 
set obs 2001
g wealth = (_n - 1)*10000


global thresholds 250000 500000 1000000 2000000 5000000 10000000 

*********************
* Annual wealth tax *
*********************

*Flat tax
foreach flat_threshold in $thresholds{
	if `flat_threshold' == 250000 local rate = $frate_an_250
	if `flat_threshold' == 500000 local rate = $frate_an_500
	if `flat_threshold' == 1000000 local rate = $frate_an_1m
	if `flat_threshold' == 2000000 local rate = $frate_an_2m
	if `flat_threshold' == 5000000 local rate = $frate_an_5m
	if `flat_threshold' == 10000000 local rate = $frate_an_10m

	*Tax due
	g taxdue_`flat_threshold' = (wealth - `flat_threshold')*`rate' if wealth > `flat_threshold'
	replace taxdue_`flat_threshold' = 0 if wealth < `flat_threshold'
	*Average tax rate
	g atr_`flat_threshold' = taxdue_`flat_threshold'/wealth 
	replace atr_`flat_threshold' = 0 if taxdue_`flat_threshold' == 0 

	preserve 
	keep taxdue_`flat_threshold' atr_`flat_threshold' wealth
	collapse (sum) atr_`flat_threshold' taxdue_`flat_threshold' , by(wealth)
	export excel "$output\tax_due_by_wealth.xlsx", sheet("Flat, `flat_threshold'", modify) firstrow(var) cell(A1)
	restore
}

*Progressive tax
foreach rates in  2 {
	if `rates' == 2 local rate_500k = 0
	if `rates' == 2 local rate_1m = $prate_an_1m
	if `rates' == 2 local rate_2m = $prate_an_2m
	if `rates' == 2 local rate_5m = $prate_an_5m
	if `rates' == 2 local rate_10m = $prate_an_10m
	 
	*Tax due
	g taxdue_500k = (wealth - 500000)*`rate_500k' if wealth >= 500000 & wealth < 1000000
	g taxdue_1m = (wealth - 1000000)*`rate_1m' + 500000*`rate_500k' if wealth >= 1000000 & wealth < 2000000
	g taxdue_2m = (wealth - 2000000)*`rate_2m' + 1000000*`rate_1m' + 500000*`rate_500k' if wealth >= 2000000 & wealth < 5000000
	g taxdue_5m = (wealth - 5000000)*`rate_5m' + 3000000*`rate_2m' + 1000000*`rate_1m' + 500000*`rate_500k' if wealth >= 5000000 & wealth < 10000000
	g taxdue_10m = (wealth - 10000000)*`rate_10m' + 5000000*`rate_5m' + 3000000*`rate_2m' + 1000000*`rate_1m' + 500000*`rate_500k' if wealth >= 10000000
	recode taxdue* (.=0)
	g taxdue_`rates' = taxdue_500k + taxdue_1m + taxdue_2m + taxdue_5m + taxdue_10m
	*Average tax rate
	g atr_`rates' = taxdue_`rates'/wealth
	replace atr_`rates' = 0 if taxdue_`rates' == 0

	preserve
	keep atr_`rates' taxdue_`rates' wealth
	collapse (sum) atr_`rates' taxdue_`rates', by(wealth)
	export excel "$output\tax_due_by_wealth.xlsx", sheet("Prog, `rates'", modify) firstrow(var) cell(A1)
	restore
}

drop taxdue* atr*

**********************
* One off wealth tax *
**********************

*Generate tax liability under different thresholds and define taxpaying population
foreach flat_threshold in $thresholds {
	local taxtype = 1
	if `taxtype' == 1 {
		*Rates for one off flat tax (annualised) - target £250bn after evasion
		if `flat_threshold' == 250000 local rate = $frate_one_250/5
		if `flat_threshold' == 500000 local rate = $frate_one_500/5
		if `flat_threshold' == 1000000 local rate = $frate_one_1m/5
		if `flat_threshold' == 2000000 local rate = $frate_one_2m/5
		if `flat_threshold' == 5000000 local rate = $frate_one_5m/5
		if `flat_threshold' == 10000000 local rate = $frate_one_10m/5
	}
	*Tax due
	g taxdue_`flat_threshold' = (wealth - `flat_threshold')*`rate' if wealth > `flat_threshold'
	replace taxdue_`flat_threshold' = 0 if wealth < `flat_threshold'
	*Average tax rate
	g atr_`flat_threshold' = taxdue_`flat_threshold'/wealth 
	replace atr_`flat_threshold' = 0 if taxdue_`flat_threshold' == 0 

	preserve 
	keep taxdue_`flat_threshold' atr_`flat_threshold' wealth
	collapse (sum) atr_`flat_threshold' taxdue_`flat_threshold' , by(wealth)
	export excel "$output\tax_due_by_wealth.xlsx", sheet("Flat, `flat_threshold' oneoff", modify) firstrow(var) cell(A1)
	restore
}

*Generate tax liability under progressive taxes 
foreach rates in 1 2 {

	local oneoff = 1

	*Rates - these are annualised by tax liability by 5
	if `rates' == 1 scalar rate_500k = $prate_one_500
	if `rates' == 1 scalar rate_1m = $prate_one_1m
	if `rates' == 1 scalar rate_2m = $prate_one_2m
	if `rates' == 1 scalar rate_5m = $prate_one_5m
	if `rates' == 1 scalar rate_10m = $prate_one_10m

	if `rates' == 2 scalar rate_500k = $prate2_one_500
	if `rates' == 2 scalar rate_1m = $prate2_one_1m
	if `rates' == 2 scalar rate_2m = $prate2_one_2m
	if `rates' == 2 scalar rate_5m = $prate2_one_5m
	if `rates' == 2 scalar rate_10m = $prate2_one_10m

	*Tax due on each band of wealth
	if `rates' == 1 {
	g tax_due_500k = 0
	}
	if `rates' == 2 {
	g tax_due_500k = .
	replace tax_due_500k = 0 if wealth < 500000
	replace tax_due_500k = (wealth - 500000)*rate_500k if wealth >= 500000
	replace tax_due_500k = 500000*rate_500k if wealth > 1000000
	}

	g tax_due_1m = .
	replace tax_due_1m = 0 if wealth < 1000000
	replace tax_due_1m = (wealth - 1000000)*rate_1m if wealth >= 1000000
	replace tax_due_1m = 1000000*rate_1m if wealth > 2000000

	g tax_due_2m = .
	replace tax_due_2m = 0 if wealth < 2000000
	replace tax_due_2m = (wealth - 2000000)*rate_2m if wealth >= 2000000
	replace tax_due_2m = 3000000*rate_2m if wealth > 5000000

	g tax_due_5m = .
	replace tax_due_5m = 0 if wealth < 5000000
	replace tax_due_5m = (wealth - 5000000)*rate_5m if wealth >= 5000000
	replace tax_due_5m = 5000000*rate_5m if wealth > 10000000

	g tax_due_10m = .
	replace tax_due_10m = 0 if wealth < 10000000
	replace tax_due_10m = (wealth - 10000000)*rate_10m if wealth >= 10000000

	*Tax due
	g taxdue_`rates' = tax_due_500k + tax_due_1m + tax_due_2m + tax_due_5m + tax_due_10m
	if `rates' == 1 {
	replace taxdue_`rates' = 0 if wealth < 1000000 
	}
	if `rates' == 2 {
	replace taxdue_`rates' = 0 if  wealth < 500000 
	}

	if `oneoff' == 1 replace taxdue_`rates' = taxdue_`rates'/5

	drop tax_due_*

	*Average tax rate
	g atr_`rates' = taxdue_`rates'/wealth
	replace atr_`rates' = 0 if taxdue_`rates' == 0

	preserve
	keep atr_`rates' taxdue_`rates' wealth
	collapse (sum) atr_`rates' taxdue_`rates', by(wealth)
	export excel "$output\tax_due_by_wealth.xlsx", sheet("Prog, `rates' oneoff", modify) firstrow(var) cell(A1)
	restore
}
